-- Dijkstra's Code --
-- Ported for Lord of the Rings Online by Paul Pritsis aka Radicus Hood (Landroval)


-- EdgeVal == 1 ; Swift Travel
-- EdgeVal == 2 ; Slow Travel
-- EdgeVal == 3 ; Walk


-- Error 122 - Missing Node and Edge
-- Error 100 - Missing Node
-- Error 101 - Missing value for distance eg. 1, 2, 3
-- Error 96 - No Comma at end of line in TableData.lua
-- Error 95 - Duplicate Node
-- Error 93 - No Speed Specified in NewEdge
-- Error 85 - Missing Destination in NewEdge
-- Error 61 - Incorrect NewNode Spelling or Source in NewEdge
-- Error 59 - Incorrect Destination in NewEdge
-- attempt to index field '?' (a nil value) - missing NewEdge

Nodes = {};
NodesIndex = {};
Edges = {};
StartNode = nil;

push = table.insert;insert = table.insert;

local function NewNode(name)
	node = {};
	node.name = name;
	node.Pre = nil;
	node.Dist = -1;
	node.vis = false;
	push(Nodes,node);
	NodesIndex[name] = #Nodes;
end

local function NewEdge(Node1,Node2,EdgeVal)
	edge = {};
	edge.N1 = Node1;
	edge.N2 = Node2;
	edge.Dist = EdgeVal;
	push(Edges,edge);
end

local function SetStartNode(name)
	Nodes[NodesIndex[name]].Dist = 0;
	StartNode = name;
end

local function EdgeConnectsNodes(E,N1,N2)
	return E.N1 == N1 and E.N2 == N2 or E.N1 == N2 and E.N2 == N1;
end

local function GetDistance(N1,N2)
	for i=1,#Edges,1 do
		if EdgeConnectsNodes(Edges[i],N1,N2) then
			return Edges[i].Dist;
		end
	end
	return -1;
end

local function GetNumOfUnVisNodes()
	local NOUVN = 0;
	for i=1,#Nodes,1 do
		if not Nodes[i].vis then
			NOUVN = NOUVN + 1;
		end
	end
	return NOUVN;
end

local function GetAllAdjcentNodes(N,AdjNodes)
	for i=1,#Edges,1 do
--		Turbine.Shell.WriteLine(N);
		if Edges[i].N1 == N and not Nodes[NodesIndex[Edges[i].N2]].vis then
			push(AdjNodes,Edges[i].N2);
		elseif Edges[i].N2 == N and not Nodes[NodesIndex[Edges[i].N1]].vis then
			push(AdjNodes,Edges[i].N1);
		end
	end
end

local function VisitClosestNode()
	local index=0;
	local Dist=0;
	for i=1,#Nodes,1 do
		if not Nodes[i].vis and Nodes[i].Dist >= 0 then
			Dist = Nodes[i].Dist;
			index=i;
			break;
		end
	end
	for i=1,#Nodes,1 do
		if Nodes[i].Dist < Dist and not Nodes[i].vis and Nodes[i].Dist >= 0 then
			Dist = Nodes[i].Dist;
			index = i;
		end
	end
	Nodes[index].vis = true;
	return index;
end

local function Dijkstras()
	while GetNumOfUnVisNodes()>0 do
		local ClosetsNode = Nodes[VisitClosestNode()];
		local MyAdjNodes = {};
		GetAllAdjcentNodes(ClosetsNode.name,MyAdjNodes);
		for i=1,#MyAdjNodes,1  do
			local Distance = ClosetsNode.Dist + GetDistance(ClosetsNode.name,MyAdjNodes[i]);
			local AdjNode = Nodes[NodesIndex[MyAdjNodes[i]]];
			if AdjNode.Dist >= 0 then
				if Distance < AdjNode.Dist then
					AdjNode.Dist = Distance;
					AdjNode.Pre = ClosetsNode.name;
				end
			else
				AdjNode.Dist = Distance;
				AdjNode.Pre = ClosetsNode.name;
			end
		end
	end
end

local function GetPathTo(N,Path)
	local CN = N;
	while CN~=StartNode do
		local Temp = CN;
		insert(Path,1,Temp);
		CN = Nodes[NodesIndex[CN]].Pre;
	end
	insert(Path,1,StartNode);
end


--
function FindRoute(s,d)

-- Angmar Nodes & Paths
NewNode("Angmar: Aughaire (0.2S, 39.3W) Stable");
NewNode("Angmar: Gabilshathur (3.6S, 26.6W) Stable");
NewNode("Angmar: Gath Forthnir (10.4N, 24.0W) Stable");
NewNode("Angmar: Iorelen's Camp (10.6N, 15.5W) Stable");
NewEdge("Angmar: Iorelen's Camp (10.6N, 15.5W) Stable", "Angmar: Aughaire (0.2S, 39.3W) Stable", 1);
NewEdge("Angmar: Iorelen's Camp (10.6N, 15.5W) Stable", "Angmar: Gabilshathur (3.6S, 26.6W) Stable", 1);
NewEdge("Angmar: Iorelen's Camp (10.6N, 15.5W) Stable", "Angmar: Gath Forthnir (10.4N, 24.0W) Stable", 1);
NewEdge("Angmar: Aughaire (0.2S, 39.3W) Stable", "North Downs: Esteldin (9.7S, 42.1W) Stable", 2);
NewEdge("Angmar: Aughaire (0.2S, 39.3W) Stable", "Angmar: Gabilshathur (3.6S, 26.6W) Stable", 1);
NewEdge("Angmar: Aughaire (0.2S, 39.3W) Stable", "Angmar: Gath Forthnir (10.4N, 24.0W) Stable", 1);
NewEdge("Angmar: Gabilshathur (3.6S, 26.6W) Stable", "Angmar: Aughaire (0.2S, 39.3W) Stable", 1);
NewEdge("Angmar: Gabilshathur (3.6S, 26.6W) Stable", "Angmar: Gath Forthnir (10.4N, 24.0W) Stable", 1);
NewEdge("Angmar: Gath Forthnir (10.4N, 24.0W) Stable", "Angmar: Aughaire (0.2S, 39.3W) Stable", 1);
NewEdge("Angmar: Gath Forthnir (10.4N, 24.0W) Stable", "North Downs: Esteldin (9.7S, 42.1W) Stable", 1);
NewEdge("Angmar: Gath Forthnir (10.4N, 24.0W) Stable", "Angmar: Gabilshathur (3.6S, 26.6W) Stable", 1);
NewEdge("Angmar: Gath Forthnir (10.4N, 24.0W) Stable", "Trollshaws: Rivendell (29.3S, 6.4W) Stable", 1);
NewEdge("Angmar: Gath Forthnir (10.4N, 24.0W) Stable", "Forochel: Suri-kyla (19.1N, 70.8W) Stable", 1);
-- Angmar Campsites & Horns
NewNode("Angmar: Carn Dum (11.4N, 33.7W) Camp/Horn");
NewEdge("Angmar: Gath Forthnir (10.4N, 24.0W) Stable", "Angmar: Carn Dum (11.4N, 33.7W) Camp/Horn", 3);
NewNode("Angmar: Eastern Malenhad (2.7N, 26.5W) Camp");
NewEdge("Angmar: Gabilshathur (3.6S, 26.6W) Stable", "Angmar: Eastern Malenhad (2.7N, 26.5W) Camp", 3);
NewNode("Angmar: Fail-a-Khro (2.5N, 37.3W) Camp");
NewEdge("Angmar: Aughaire (0.2S, 39.3W) Stable", "Angmar: Fail-a-Khro (2.5N, 37.3W) Camp", 3);
NewNode("Angmar: Gorothlad (4.1N, 21.7W) Camp/Horn");
NewEdge("Angmar: Gath Forthnir (10.4N, 24.0W) Stable", "Angmar: Gorothlad (4.1N, 21.7W) Camp/Horn", 3);
NewNode("Angmar: Iorelen's Camp (10.8N, 15.5W) Camp/Horn");
NewEdge("Angmar: Gath Forthnir (10.4N, 24.0W) Stable", "Angmar: Iorelen's Camp (10.8N, 15.5W) Camp/Horn", 3);
NewNode("Angmar: Maethad (1.7S, 33.3W) Camp");
NewEdge("Angmar: Gabilshathur (3.6S, 26.6W) Stable", "Angmar: Maethad (1.7S, 33.3W) Camp", 3);
NewNode("Angmar: Myrkworth (6.9N, 25.8W) Camp");
NewEdge("Angmar: Gath Forthnir (10.4N, 24.0W) Stable", "Angmar: Myrkworth (6.9N, 25.8W) Camp", 3);
NewNode("Angmar: Tarmunn Sursa (12.2N, 32.0W) Camp/Horn");
NewEdge("Angmar: Gath Forthnir (10.4N, 24.0W) Stable", "Angmar: Tarmunn Sursa (12.2N, 32.0W) Camp/Horn", 3);
NewNode("Angmar: Urugarth (10.0N, 32.6W) Camp/Horn");
NewEdge("Angmar: Gath Forthnir (10.4N, 24.0W) Stable", "Angmar: Urugarth (10.0N, 32.6W) Camp/Horn", 3);
-- Angmar Milestones
NewNode("Angmar: Aughaire (0.1N, 39.9W) Milestone");
NewEdge("Angmar: Aughaire (0.2S, 39.3W) Stable", "Angmar: Aughaire (0.1N, 39.9W) Milestone", 3);
NewNode("Angmar: Gath Forthnir (10.9N, 23.9W) Milestone");
NewEdge("Angmar: Gath Forthnir (10.4N, 24.0W) Stable", "Angmar: Gath Forthnir (10.9N, 23.9W) Milestone", 3);
NewNode("Angmar: Gabilshathur (3.5S, 26.5W) Milestone");
NewEdge("Angmar: Gabilshathur (3.6S, 26.6W) Stable", "Angmar: Gabilshathur (3.5S, 26.5W) Milestone", 3);
NewNode("Angmar: Imlad Balchorth (6.8N, 25.9W) Milestone");
NewEdge("Angmar: Gath Forthnir (10.4N, 24.0W) Stable", "Angmar: Imlad Balchorth (6.8N, 25.9W) Milestone", 3);
NewNode("Angmar: Tarmunn Sursa - Carn Dum (12.1N, 31.8W) Milestone");
NewEdge("Angmar: Gath Forthnir (10.4N, 24.0W) Stable", "Angmar: Tarmunn Sursa - Carn Dum (12.1N, 31.8W) Milestone", 3);

-- Anorien (After Battle) Nodes & Paths
NewNode("Anorien After Battle: Osgiliath (63.0S, 6.5W) Stable");
NewNode("Anorien After Battle: Aragorn's Pavailion (65.6S, 14.8W) Stable");
NewNode("Anorien After Battle: Minas Tirith (65.6S, 16.9W) Stable");
NewEdge("Anorien After Battle: Osgiliath (63.0S, 6.5W) Stable", "Western Gondor: Dol Amroth (75.5S, 72.5W) Stable", 1);
NewEdge("Anorien After Battle: Osgiliath (63.0S, 6.5W) Stable", "Bree-land: South Bree (31.9S, 50.4W) Stable", 1);
NewEdge("Anorien After Battle: Osgiliath (63.0S, 6.5W) Stable", "Anorien After Battle: Aragorn's Pavailion (65.6S, 14.8W) Stable", 1);
NewEdge("Anorien After Battle: Osgiliath (63.0S, 6.5W) Stable", "Anorien After Battle: Aragorn's Pavailion (65.6S, 14.8W) Stable", 2);
NewEdge("Anorien After Battle: Osgiliath (63.0S, 6.5W) Stable", "Anorien After Battle: Minas Tirith (65.6S, 16.9W) Stable", 1);
NewEdge("Anorien After Battle: Osgiliath (63.0S, 6.5W) Stable", "Anorien After Battle: Minas Tirith (65.6S, 16.9W) Stable", 2);
NewEdge("Anorien After Battle: Osgiliath (63.0S, 6.5W) Stable", "Dunland: Galtrev (80.0S, 16.7W) Stable", 1);
NewEdge("Anorien After Battle: Osgiliath (63.0S, 6.5W) Stable", "West Rohan: Aldburg (68.7S, 63.9W) Stable", 1);
NewEdge("Anorien After Battle: Osgiliath (63.0S, 6.5W) Stable", "Moria: Twenty-first Hall (5.7S, 105.3W) Stable", 1);
NewEdge("Anorien After Battle: Osgiliath (63.0S, 6.5W) Stable", "Old Anorien: Minas Tirith Main Gate (65.8S, 16.8W) Stable", 1);
NewEdge("Anorien After Battle: Aragorn's Pavailion (65.6S, 14.8W) Stable", "Anorien After Battle: Minas Tirith (65.6S, 16.9W) Stable", 1);
NewEdge("Anorien After Battle: Aragorn's Pavailion (65.6S, 14.8W) Stable", "Anorien After Battle: Minas Tirith (65.6S, 16.9W) Stable", 2);
NewEdge("Anorien After Battle: Aragorn's Pavailion (65.6S, 14.8W) Stable", "Anorien After Battle: Osgiliath (63.0S, 6.5W) Stable", 1);
NewEdge("Anorien After Battle: Aragorn's Pavailion (65.6S, 14.8W) Stable", "Anorien After Battle: Osgiliath (63.0S, 6.5W) Stable", 2);
NewEdge("Anorien After Battle: Aragorn's Pavailion (65.6S, 14.8W) Stable", "The Wastes: Camp of the Host (41.0S, 10.5W) Stable", 1);
NewEdge("Anorien After Battle: Aragorn's Pavailion (65.6S, 14.8W) Stable", "The Wastes: Camp of the Host (41.0S, 10.5W) Stable", 2);
NewEdge("Anorien After Battle: Aragorn's Pavailion (65.6S, 14.8W) Stable", "North Ithilien: Henneth Annun (48.4S, 6.9W) Stable", 1);
NewEdge("Anorien After Battle: Aragorn's Pavailion (65.6S, 14.8W) Stable", "North Ithilien: Henneth Annun (48.4S, 6.9W) Stable", 2);
-- Milestones
NewNode("Anorien After Battle: Aragorn's Pavailion (65.5S, 14.7W) Milestone");
NewNode("Anorien After Battle: Minas Tirith (65.4S, 16.8W) Milestone");
NewNode("Anorien After Battle: Osgiliath (62.9S, 7.2W) Milestone");
NewNode("Anorien After Battle: Minas Tirith (65.7S, 16.4W) Horn");
NewEdge("Anorien After Battle: Aragorn's Pavailion (65.6S, 14.8W) Stable", "Anorien After Battle: Aragorn's Pavailion (65.5S, 14.7W) Milestone", 3);
NewEdge("Anorien After Battle: Minas Tirith (65.6S, 16.9W) Stable", "Anorien After Battle: Minas Tirith (65.4S, 16.8W) Milestone", 3);
NewEdge("Anorien After Battle: Osgiliath (63.0S, 6.5W) Stable", "Anorien After Battle: Osgiliath (62.9S, 7.2W) Milestone", 3)
NewEdge("Anorien After Battle: Minas Tirith (65.6S, 16.9W) Stable", "Anorien After Battle: Minas Tirith (65.7S, 16.4W) Horn", 2)

-- Bree-land Nodes & Paths
NewNode("Bree-land: Adso's Camp (29.2S, 56.6W) Stable");
NewNode("Bree-land: Buckland (32.9S, 61.8W) Stable");
NewNode("Bree-land: Combe (28,6S, 49.5W) Stable");
NewNode("Bree-land: Hengstacer Farm (22.3S, 52.3W) Stable");
NewNode("Bree-land: Searadan's Cabin (25.6S, 52,9W) Stable");
NewNode("Bree-land: South Bree (31.9S, 50.4W) Stable");
NewNode("Bree-land: West Bree (29,5S, 52.6W) Stable");
NewEdge("Bree-land: Adso's Camp (29.2S, 56.6W) Stable", "Bree-land: West Bree (29,5S, 52.6W) Stable", 2);
NewEdge("Bree-land: Buckland (32.9S, 61.8W) Stable", "Bree-land: Adso's Camp (29.2S, 56.6W) Stable", 2);
NewEdge("Bree-land: Buckland (32.9S, 61.8W) Stable", "Bree-land: West Bree (29,5S, 52.6W) Stable", 2);
NewEdge("Bree-land: Buckland (32.9S, 61.8W) Stable", "Shire: Stock (32.1S, 64.1W) Stable", 2);
NewEdge("Bree-land: Combe (28,6S, 49.5W) Stable", "Ered Luin: Celondim (28.1S, 92.4W) Stable", 1);
NewEdge("Bree-land: Combe (28,6S, 49.5W) Stable", "Shire: Michel Delving (34.2S, 75.5W) Stable", 1);
NewEdge("Bree-land: Combe (28,6S, 49.5W) Stable", "Bree-land: South Bree (31.9S, 50.4W) Stable", 2);
NewEdge("Bree-land: Combe (28,6S, 49.5W) Stable", "Ered Luin: Thorin's Gate (15.0S, 103.6W) Stable", 1);
NewEdge("Bree-land: Hengstacer Farm (22.3S, 52.3W) Stable", "North Downs: Trestlebridge (18.0S, 53.6W) Stable", 2);
NewEdge("Bree-land: Hengstacer Farm (22.3S, 52.3W) Stable", "Bree-land: West Bree (29,5S, 52.6W) Stable", 2);
NewEdge("Bree-land: Hengstacer Farm (22.3S, 52.3W) Stable", "Bree-land: Searadan's Cabin (25.6S, 52,9W) Stable", 2);
NewEdge("Bree-land: Searadan's Cabin (25.6S, 52,9W) Stable", "Lone Lands: Candaith's Encampment (30.1S, 37.9W) Stable", 2);
NewEdge("Bree-land: South Bree (31.9S, 50.4W) Stable", "Ered Luin: Celondim (28.1S, 92.4W) Stable", 1);
NewEdge("Bree-land: South Bree (31.9S, 50.4W) Stable", "Bree-land: Combe (28,6S, 49.5W) Stable", 2);
NewEdge("Bree-land: South Bree (31.9S, 50.4W) Stable", "Ettenmoors: Glan Vraig (21.S, 13.4W) Stable", 1);
NewEdge("Bree-land: South Bree (31.9S, 50.4W) Stable", "Dunland: Galtrev (80.0S, 16.7W) Stable", 1);
NewEdge("Bree-land: South Bree (31.9S, 50.4W) Stable", "Enedwaith: Lhanuch (66.9S, 16.9W) Stable", 1);
NewEdge("Bree-land: South Bree (31.9S, 50.4W) Stable", "Shire: Michel Delving (34.2S, 75.5W) Stable", 1);
NewEdge("Bree-land: South Bree (31.9S, 50.4W) Stable", "Lone Lands: Ost Guruth (32.1S, 29.8W) Stable", 1);
NewEdge("Bree-land: South Bree (31.9S, 50.4W) Stable", "Trollshaws: Rivendell (29.3S, 6.4W) Stable", 1);
NewEdge("Bree-land: South Bree (31.9S, 50.4W) Stable", "Great River: Stangard (25.6W, 63.5W) Stable", 1);
NewEdge("Bree-land: South Bree (31.9S, 50.4W) Stable", "Lone Lands: The Forsakken Inn (34.4S, 40.6W) Stable", 2);
NewEdge("Bree-land: South Bree (31.9S, 50.4W) Stable", "Ered Luin: Thorin's Gate (15.0S, 103.6W) Stable", 1);
NewEdge("Bree-land: South Bree (31.9S, 50.4W) Stable", "Bree-land: West Bree (29,5S, 52.6W) Stable", 1);
NewEdge("Bree-land: South Bree (31.9S, 50.4W) Stable", "Western Gondor: Dol Amroth (75.5S, 72.5W) Stable", 1);
NewEdge("Bree-land: West Bree (29,5S, 52.6W) Stable", "Bree-land: Adso's Camp (29.2S, 56.6W) Stable", 2);
NewEdge("Bree-land: West Bree (29,5S, 52.6W) Stable", "Bree-land: Buckland (32.9S, 61.8W) Stable", 2);
NewEdge("Bree-land: West Bree (29,5S, 52.6W) Stable", "Ered Luin: Celondim (28.1S, 92.4W) Stable", 1);
NewEdge("Bree-land: West Bree (29,5S, 52.6W) Stable", "North Downs: Esteldin (9.7S, 42.1W) Stable", 1);
NewEdge("Bree-land: West Bree (29,5S, 52.6W) Stable", "Bree-land: Hengstacer Farm (22.3S, 52.3W) Stable", 2);
NewEdge("Bree-land: West Bree (29,5S, 52.6W) Stable", "Shire: Hobbiton (31.5S, 71.2W) Stable", 2);
NewEdge("Bree-land: West Bree (29,5S, 52.6W) Stable", "Shire: Michel Delving (34.2S, 75.5W) Stable", 1);
NewEdge("Bree-land: West Bree (29,5S, 52.6W) Stable", "Evendim: Ost Forod (8.2S, 64.3W) Stable", 1);
NewEdge("Bree-land: West Bree (29,5S, 52.6W) Stable", "Bree-land: South Bree (31.9S, 50.4W) Stable", 1);
NewEdge("Bree-land: West Bree (29,5S, 52.6W) Stable", "Forochel: Suri-kyla (19.1N, 70.8W) Stable", 1);
NewEdge("Bree-land: West Bree (29,5S, 52.6W) Stable", "Ered Luin: Thorin's Gate (15.0S, 103.6W) Stable", 1);
NewEdge("Bree-land: West Bree (29,5S, 52.6W) Stable", "Evendim: Tinnudir (12.4S, 67.2W) Stable", 1);
NewEdge("Bree-land: West Bree (29,5S, 52.6W) Stable", "North Downs: Trestlebridge (18.0S, 53.6W) Stable", 2);
-- Bree-land Campsites & Horns
NewNode("Bree-land: Southern Bree-fields (28.2S, 54.3W) Camp");
NewEdge("Bree-land: Adso's Camp (29.2S, 56.6W) Stable", "Bree-land: Southern Bree-fields (28.2S, 54.3W) Camp", 3);
NewNode("Bree-land: The Great Barrow (33.7S, 55.5W) Camp/Horn");
NewEdge("Bree-land: Adso's Camp (29.2S, 56.6W) Stable", "Bree-land: The Great Barrow (33.7S, 55.5W) Camp/Horn", 3);
NewNode("Bree-land: The Horsefields (23.8S, 52.7W) Camp");
NewEdge("Bree-land: Hengstacer Farm (22.3S, 52.3W) Stable", "Bree-land: The Horsefields (23.8S, 52.7W) Camp", 3);
-- Bree-land Milestones
NewNode("Bree-land: Archet (25.1S, 48.9W) Milestone");
NewEdge("Bree-land: Combe (28,6S, 49.5W) Stable", "Bree-land: Archet (25.1S, 48.9W) Milestone", 3);
NewNode("Bree-land: Bree - South Gate (32.1S, 50.3W) Milestone");
NewEdge("Bree-land: South Bree (31.9S, 50.4W) Stable", "Bree-land: Bree - South Gate (32.1S, 50.3W) Milestone", 3);
NewNode("Bree-land: Bree - Prancing Pony (29.8S, 51.3W) Milestone");
NewEdge("Bree-land: West Bree (29,5S, 52.6W) Stable", "Bree-land: Bree - Prancing Pony (29.8S, 51.3W) Milestone", 3);
NewNode("Bree-land: Bree - West Gate (29.2S, 53.9W) Milestone");
NewEdge("Bree-land: West Bree (29,5S, 52.6W) Stable", "Bree-land: Bree - West Gate (29.2S, 53.9W) Milestone", 3);
NewNode("Bree-land: Homesteads (34.8S, 53.9W) Milestone");
NewEdge("Bree-land: South Bree (31.9S, 50.4W) Stable", "Bree-land: Homesteads (34.8S, 53.9W) Milestone", 3);
NewNode("Bree-land: Buckland (33.3S, 62.7W) Milestone");
NewEdge("Bree-land: Adso's Camp (29.2S, 56.6W) Stable", "Bree-land: Buckland (33.3S, 62.7W) Milestone", 3);
NewNode("Bree-land: Combe (28.5S, 49.4W) Milestone");
NewEdge("Bree-land: Combe (28,6S, 49.5W) Stable", "Bree-land: Combe (28.5S, 49.4W) Milestone", 3);

--Central Gondor Nodes & Paths
NewNode("Central Gondor: Ethring (72.2S, 50.1W) Stable");
NewNode("Central Gondor: Linhir (80.8S, 45.8W) Stable");
NewNode("Central Gondor: East Pelargir (82.8S, 31.6W) Stable");
NewNode("Central Gondor: West Pelargir (83.0S, 34.8W) Stable");
NewNode("Central Gondor: Ost Anglebed (79.1S, 39.0W) Stable");
NewEdge("Central Gondor: Ethring (72.2S, 50.1W) Stable", "Western Gondor: Calembel (67.2S, 55.1W) Stable", 1);
NewEdge("Central Gondor: Ethring (72.2S, 50.1W) Stable", "Western Gondor: Calembel (67.2S, 55.1W) Stable", 2);
NewEdge("Central Gondor: Ethring (72.2S, 50.1W) Stable", "Central Gondor: Linhir (80.8S, 45.8W) Stable", 1);
NewEdge("Central Gondor: Ethring (72.2S, 50.1W) Stable", "Central Gondor: Linhir (80.8S, 45.8W) Stable", 2);
NewEdge("Central Gondor: Ethring (72.2S, 50.1W) Stable", "Central Gondor: West Pelargir (83.0S, 34.8W) Stable", 1);
NewEdge("Central Gondor: Ethring (72.2S, 50.1W) Stable", "Central Gondor: West Pelargir (83.0S, 34.8W) Stable", 2);
NewEdge("Central Gondor: Ethring (72.2S, 50.1W) Stable", "Western Gondor: Dol Amroth (75.5S, 72.5W) Stable", 1);
NewEdge("Central Gondor: Linhir (80.8S, 45.8W) Stable", "Central Gondor: Ethring (72.2S, 50.1W) Stable", 1);
NewEdge("Central Gondor: Linhir (80.8S, 45.8W) Stable", "Central Gondor: Ethring (72.2S, 50.1W) Stable", 2);
NewEdge("Central Gondor: Linhir (80.8S, 45.8W) Stable", "Central Gondor: West Pelargir (83.0S, 34.8W) Stable", 1);
NewEdge("Central Gondor: Linhir (80.8S, 45.8W) Stable", "Central Gondor: West Pelargir (83.0S, 34.8W) Stable", 2);
NewEdge("Central Gondor: Linhir (80.8S, 45.8W) Stable", "Western Gondor: Dol Amroth (75.5S, 72.5W) Stable", 1);
NewEdge("Central Gondor: West Pelargir (83.0S, 34.8W) Stable", "Central Gondor: Ethring (72.2S, 50.1W) Stable", 1);
NewEdge("Central Gondor: West Pelargir (83.0S, 34.8W) Stable", "Central Gondor: Ethring (72.2S, 50.1W) Stable", 2);
NewEdge("Central Gondor: West Pelargir (83.0S, 34.8W) Stable", "Central Gondor: Linhir (80.8S, 45.8W) Stable", 1);
NewEdge("Central Gondor: West Pelargir (83.0S, 34.8W) Stable", "Central Gondor: Linhir (80.8S, 45.8W) Stable", 2);
NewEdge("Central Gondor: West Pelargir (83.0S, 34.8W) Stable", "Western Gondor: Dol Amroth (75.5S, 72.5W) Stable", 1);
NewEdge("Central Gondor: West Pelargir (83.0S, 34.8W) Stable", "Central Gondor: Ost Anglebed (79.1S, 39.0W) Stable", 1);
NewEdge("Central Gondor: West Pelargir (83.0S, 34.8W) Stable", "Central Gondor: Ost Anglebed (79.1S, 39.0W) Stable", 2);
NewEdge("Central Gondor: West Pelargir (83.0S, 34.8W) Stable", "Western Gondor: Calembel (67.2S, 55.1W) Stable", 1);
NewEdge("Central Gondor: West Pelargir (83.0S, 34.8W) Stable", "Western Gondor: Dol Amroth (75.5S, 72.5W) Stable", 1);
NewEdge("Central Gondor: West Pelargir (83.0S, 34.8W) Stable", "Western Gondor: Morlad (56.9S, 67.5W) Stable", 1);
NewEdge("Central Gondor: West Pelargir (83.0S, 34.8W) Stable", "Western Gondor: Tadrent (74.0S, 62.4W) Stable", 1);
NewEdge("Central Gondor: East Pelargir (82.8S, 31.6W) Stable", "Central Gondor: West Pelargir (83.0S, 34.8W) Stable", 1);
NewEdge("Central Gondor: East Pelargir (82.8S, 31.6W) Stable", "Central Gondor: West Pelargir (83.0S, 34.8W) Stable", 2);
NewEdge("Central Gondor: East Pelargir (82.8S, 31.6W) Stable", "Eastern Gondor: Arnach (76.3S, 24.4W) Stable", 1);
NewEdge("Central Gondor: East Pelargir (82.8S, 31.6W) Stable", "Eastern Gondor: Arnach (76.3S, 24.4W) Stable", 2);
NewEdge("Central Gondor: East Pelargir (82.8S, 31.6W) Stable", "Eastern Gondor: Bar-Hurin (73.5S, 12.2W) Stable", 1);
NewEdge("Central Gondor: East Pelargir (82.8S, 31.6W) Stable", "Eastern Gondor: Faramir's Lookout (65.0S, 6.1W) Stable", 1);
NewEdge("Central Gondor: East Pelargir (82.8S, 31.6W) Stable", "Eastern Gondor: Glaniath (81.0S, 298W) Stable", 1);
NewEdge("Central Gondor: East Pelargir (82.8S, 31.6W) Stable", "Eastern Gondor: Glaniath (81.0S, 298W) Stable", 2);
NewEdge("Central Gondor: East Pelargir (82.8S, 31.6W) Stable", "Western Gondor: Dol Amroth (75.5S, 72.5W) Stable", 1);
-- Central Gondor Campsites
NewNode("Central Gondor: West Pelargir (83.6S, 39.9W) Camp");
NewNode("Central Gondor: Dor-En-Ernil (82.9S, 52.2W) Camp");
NewEdge("Central Gondor: West Pelargir (83.6S, 39.9W) Camp", "Central Gondor: West Pelargir (83.0S, 34.8W) Stable", 2);
NewEdge("Central Gondor: Dor-En-Ernil (82.9S, 52.2W) Camp", "Central Gondor: Linhir (80.8S, 45.8W) Stable", 2);
-- Central Gondor Milestones
NewNode("Central Gondor: Pelargir (83.6S, 34.0W) Milestone");
NewEdge("Central Gondor: Pelargir (83.6S, 34.0W) Milestone", "Central Gondor: West Pelargir (83.0S, 34.8W) Stable", 2);
NewNode("Central Gondor: Ost Anglebed (79.3S, 39.1W) Milestone");
NewEdge("Central Gondor: Ost Anglebed (79.3S, 39.1W) Milestone", "Central Gondor: Ost Anglebed (79.1S, 39.0W) Stable", 2);
NewNode("Central Gondor: Linhir (80.7S, 45.7W) Milestone");
NewEdge("Central Gondor: Linhir (80.7S, 45.7W) Milestone", "Central Gondor: Linhir (80.8S, 45.8W) Stable", 2);
NewNode("Central Gondor: Ethring (72.0S, 50.2W) Milestone");
NewEdge("Central Gondor: Ethring (72.0S, 50.2W) Milestone", "Central Gondor: Ethring (72.2S, 50.1W) Stable", 2);

-- Eastern Gondor Paths & Nodes
NewNode("Eastern Gondor: Arnach (76.3S, 24.4W) Stable");
NewNode("Eastern Gondor: Bar-Hurin (73.5S, 12.2W) Stable");
NewNode("Eastern Gondor: Faramir's Lookout (65.0S, 6.1W) Stable");
NewNode("Eastern Gondor: Glaniath (81.0S, 298W) Stable");
NewEdge("Eastern Gondor: Arnach (76.3S, 24.4W) Stable", "Central Gondor: East Pelargir (82.8S, 31.6W) Stable", 1);
NewEdge("Eastern Gondor: Arnach (76.3S, 24.4W) Stable", "Central Gondor: East Pelargir (82.8S, 31.6W) Stable", 2);
NewEdge("Eastern Gondor: Arnach (76.3S, 24.4W) Stable", "Eastern Gondor: Bar-Hurin (73.5S, 12.2W) Stable", 1);
NewEdge("Eastern Gondor: Arnach (76.3S, 24.4W) Stable", "Eastern Gondor: Faramir's Lookout (65.0S, 6.1W) Stable", 1);
NewEdge("Eastern Gondor: Arnach (76.3S, 24.4W) Stable", "Eastern Gondor: Glaniath (81.0S, 298W) Stable", 1);
NewEdge("Eastern Gondor: Arnach (76.3S, 24.4W) Stable", "Eastern Gondor: Glaniath (81.0S, 298W) Stable", 2);
NewEdge("Eastern Gondor: Arnach (76.3S, 24.4W) Stable", "Western Gondor: Dol Amroth (75.5S, 72.5W) Stable", 1);
NewEdge("Eastern Gondor: Bar-Hurin (73.5S, 12.2W) Stable", "Central Gondor: East Pelargir (82.8S, 31.6W) Stable", 1);
NewEdge("Eastern Gondor: Bar-Hurin (73.5S, 12.2W) Stable", "Eastern Gondor: Arnach (76.3S, 24.4W) Stable", 1);
NewEdge("Eastern Gondor: Bar-Hurin (73.5S, 12.2W) Stable", "Eastern Gondor: Faramir's Lookout (65.0S, 6.1W) Stable", 1);
NewEdge("Eastern Gondor: Bar-Hurin (73.5S, 12.2W) Stable", "Eastern Gondor: Faramir's Lookout (65.0S, 6.1W) Stable", 2);
NewEdge("Eastern Gondor: Bar-Hurin (73.5S, 12.2W) Stable", "Eastern Gondor: Glaniath (81.0S, 298W) Stable", 1);
NewEdge("Eastern Gondor: Bar-Hurin (73.5S, 12.2W) Stable", "Western Gondor: Dol Amroth (75.5S, 72.5W) Stable", 1);
NewEdge("Eastern Gondor: Faramir's Lookout (65.0S, 6.1W) Stable", "Eastern Gondor: Arnach (76.3S, 24.4W) Stable", 1);
NewEdge("Eastern Gondor: Faramir's Lookout (65.0S, 6.1W) Stable", "Eastern Gondor: Arnach (76.3S, 24.4W) Stable", 2);
NewEdge("Eastern Gondor: Faramir's Lookout (65.0S, 6.1W) Stable", "Eastern Gondor: Bar-Hurin (73.5S, 12.2W) Stable", 1);
NewEdge("Eastern Gondor: Faramir's Lookout (65.0S, 6.1W) Stable", "Eastern Gondor: Bar-Hurin (73.5S, 12.2W) Stable", 2);
NewEdge("Eastern Gondor: Faramir's Lookout (65.0S, 6.1W) Stable", "Eastern Gondor: Glaniath (81.0S, 298W) Stable", 1);
NewEdge("Eastern Gondor: Faramir's Lookout (65.0S, 6.1W) Stable", "Western Gondor: Dol Amroth (75.5S, 72.5W) Stable", 1);
NewEdge("Eastern Gondor: Glaniath (81.0S, 298W) Stable", "Central Gondor: East Pelargir (82.8S, 31.6W) Stable", 1);
NewEdge("Eastern Gondor: Glaniath (81.0S, 298W) Stable", "Central Gondor: East Pelargir (82.8S, 31.6W) Stable", 2);
NewEdge("Eastern Gondor: Glaniath (81.0S, 298W) Stable", "Eastern Gondor: Arnach (76.3S, 24.4W) Stable", 1);
NewEdge("Eastern Gondor: Glaniath (81.0S, 298W) Stable", "Eastern Gondor: Arnach (76.3S, 24.4W) Stable", 2);
NewEdge("Eastern Gondor: Glaniath (81.0S, 298W) Stable", "Eastern Gondor: Bar-Hurin (73.5S, 12.2W) Stable", 1);
NewEdge("Eastern Gondor: Glaniath (81.0S, 298W) Stable", "Eastern Gondor: Faramir's Lookout (65.0S, 6.1W) Stable", 1);
NewEdge("Eastern Gondor: Glaniath (81.0S, 298W) Stable", "Western Gondor: Dol Amroth (75.5S, 72.5W) Stable", 1);
-- Eastern Gondor Campsites
NewNode("Eastern Gondor: Harlond (73.9, 21.6W) Camp");
NewNode("Eastern Gondor: Osgiliath (62.7S, 8.8W) Camp/Horn");
NewNode("Eastern Gondor: Upper Lebennin (81.9S, 26.5W) Camp");
NewEdge("Eastern Gondor: Harlond (73.9, 21.6W) Camp", "Eastern Gondor: Arnach (76.3S, 24.4W) Stable", 2);
NewEdge("Eastern Gondor: Osgiliath (62.7S, 8.8W) Camp/Horn", "Eastern Gondor: Faramir's Lookout (65.0S, 6.1W) Stable", 2);
NewEdge("Eastern Gondor: Upper Lebennin (81.9S, 26.5W) Camp", "Eastern Gondor: Glaniath (81.0S, 298W) Stable", 2);
-- Eastern Gondor Milestones
NewNode("Eastern Gondor: Tumladen (77.5S, 29.2W) Milestone");
NewEdge("Eastern Gondor: Tumladen (77.5S, 29.2W) Milestone", "Eastern Gondor: Glaniath (81.0S, 298W) Stable", 2);
NewNode("Eastern Gondor: Glaniath (80.7S, 29.6W) Milestone");
NewEdge("Eastern Gondor: Glaniath (80.7S, 29.6W) Milestone", "Eastern Gondor: Glaniath (81.0S, 298W) Stable", 2);
NewNode("Eastern Gondor: Bar Hurin (73.5S, 12.2W) Milestone");
NewEdge("Eastern Gondor: Bar Hurin (73.5S, 12.2W) Milestone", "Eastern Gondor: Bar-Hurin (73.5S, 12.2W) Stable", 2);
NewNode("Eastern Gondor: Faramir's Lookout (65.1S, 6.1W) Milestone");
NewEdge("Eastern Gondor: Faramir's Lookout (65.1S, 6.1W) Milestone",  "Eastern Gondor: Faramir's Lookout (65.0S, 6.1W) Stable", 2);




-- Dunland Nodes & Paths
NewNode("Dunland: Avardin (83.5S, 20.4W) Stable");
NewNode("Dunland: Barnavon (84.7S, 16.3W) Stable");
NewNode("Dunland: Echad Naeglanc (77.3S, 15.8W) Stable");
NewNode("Dunland: Galtrev (80.0S, 16.7W) Stable");
NewNode("Dunland: Lhan Rhos (86.8S, 23.0W) Stable");
NewNode("Dunland: Lhan Tarren (75.3S, 22.4W) Stable");
NewNode("Dunland: Rohirrim Scout-camp (80.9S, 10.6W) Stable");
NewNode("Dunland: Tal Methedras Gate (78.3S, 11.2W) Stable");
NewNode("Dunland: Wulf's Cleft Overlook (87.7S, 16.2W) Stable");
NewEdge("Dunland: Avardin (83.5S, 20.4W) Stable", "Dunland: Galtrev (80.0S, 16.7W) Stable", 1);
NewEdge("Dunland: Avardin (83.5S, 20.4W) Stable", "Dunland: Lhan Rhos (86.8S, 23.0W) Stable", 1);
NewEdge("Dunland: Barnavon (84.7S, 16.3W) Stable", "Dunland: Galtrev (80.0S, 16.7W) Stable", 1);
NewEdge("Dunland: Barnavon (84.7S, 16.3W) Stable", "Dunland: Lhan Rhos (86.8S, 23.0W) Stable", 1);
NewEdge("Dunland: Barnavon (84.7S, 16.3W) Stable", "Dunland: Rohirrim Scout-camp (80.9S, 10.6W) Stable", 1);
NewEdge("Dunland: Barnavon (84.7S, 16.3W) Stable", "Dunland: Wulf's Cleft Overlook (87.7S, 16.2W) Stable", 1);
NewEdge("Dunland: Echad Naeglanc (77.3S, 15.8W) Stable", "Dunland: Galtrev (80.0S, 16.7W) Stable", 1);
NewEdge("Dunland: Echad Naeglanc (77.3S, 15.8W) Stable", "Enedwaith: Harndirion (69.4S, 13.7W) Stable", 1);
NewEdge("Dunland: Echad Naeglanc (77.3S, 15.8W) Stable", "Dunland: Lhan Tarren (75.3S, 22.4W) Stable", 1);
NewEdge("Dunland: Galtrev (80.0S, 16.7W) Stable", "Dunland: Avardin (83.5S, 20.4W) Stable", 1);
NewEdge("Dunland: Galtrev (80.0S, 16.7W) Stable", "Dunland: Barnavon (84.7S, 16.3W) Stable", 1);
NewEdge("Dunland: Galtrev (80.0S, 16.7W) Stable", "Nan Curunir: Dagoras' Camp (84.9S, 3.4W) Stable", 1);
NewEdge("Dunland: Galtrev (80.0S, 16.7W) Stable", "Dunland: Echad Naeglanc (77.3S, 15.8W) Stable", 1);
NewEdge("Dunland: Galtrev (80.0S, 16.7W) Stable", "Gap of Rohan: Forthbrond (86.9S, 7.5W) Stable", 1);
NewEdge("Dunland: Galtrev (80.0S, 16.7W) Stable", "Gap of Rohan: Grimbold's Camp (87.8S, 3.9W) Stable", 1);
NewEdge("Dunland: Galtrev (80.0S, 16.7W) Stable", "Lothlorien: Inner Caras Galadhon (15.1S, 68.2W) Stable", 1);
NewEdge("Dunland: Galtrev (80.0S, 16.7W) Stable", "Dunland: Lhan Tarren (75.3S, 22.4W) Stable", 1);
NewEdge("Dunland: Galtrev (80.0S, 16.7W) Stable", "Dunland: Lhan Rhos (86.8S, 23.0W) Stable", 1);
NewEdge("Dunland: Galtrev (80.0S, 16.7W) Stable", "Enedwaith: Lhanuch (66.9S, 16.9W) Stable", 1);
NewEdge("Dunland: Galtrev (80.0S, 16.7W) Stable", "Dunland: Rohirrim Scout-camp (80.9S, 10.6W) Stable", 1);
NewEdge("Dunland: Galtrev (80.0S, 16.7W) Stable", "Bree-land: South Bree (31.9S, 50.4W) Stable", 1);
NewEdge("Dunland: Galtrev (80.0S, 16.7W) Stable", "Dunland: Tal Methedras Gate (78.3S, 11.2W) Stable", 1);
NewEdge("Dunland: Galtrev (80.0S, 16.7W) Stable", "Moria: Twenty-first Hall (5.7S, 105.3W) Stable", 1);
NewEdge("Dunland: Lhan Rhos (86.8S, 23.0W) Stable", "Dunland: Avardin (83.5S, 20.4W) Stable", 1);
NewEdge("Dunland: Lhan Rhos (86.8S, 23.0W) Stable", "Dunland: Barnavon (84.7S, 16.3W) Stable", 1);
NewEdge("Dunland: Lhan Rhos (86.8S, 23.0W) Stable", "Dunland: Galtrev (80.0S, 16.7W) Stable", 1);
NewEdge("Dunland: Lhan Tarren (75.3S, 22.4W) Stable", "Enedwaith: Echad Daervunn (66.6S, 21.5W) Stable", 1);
NewEdge("Dunland: Lhan Tarren (75.3S, 22.4W) Stable", "Dunland: Echad Naeglanc (77.3S, 15.8W) Stable", 1);
NewEdge("Dunland: Lhan Tarren (75.3S, 22.4W) Stable", "Dunland: Galtrev (80.0S, 16.7W) Stable", 1);
NewEdge("Dunland: Rohirrim Scout-camp (80.9S, 10.6W) Stable", "Dunland: Barnavon (84.7S, 16.3W) Stable", 1);
NewEdge("Dunland: Rohirrim Scout-camp (80.9S, 10.6W) Stable", "Gap of Rohan: Forthbrond (86.9S, 7.5W) Stable", 1);
NewEdge("Dunland: Rohirrim Scout-camp (80.9S, 10.6W) Stable", "Dunland: Galtrev (80.0S, 16.7W) Stable", 1);
NewEdge("Dunland: Tal Methedras Gate (78.3S, 11.2W) Stable", "Dunland: Galtrev (80.0S, 16.7W) Stable", 1);
NewEdge("Dunland: Wulf's Cleft Overlook (87.7S, 16.2W) Stable", "Dunland: Barnavon (84.7S, 16.3W) Stable", 1);
-- Dunland Campsites & Horns
NewNode("Dunland: Barnavon (84.8S, 16.7W) Camp/Horn");
NewEdge("Dunland: Barnavon (84.7S, 16.3W) Stable", "Dunland: Barnavon (84.8S, 16.7W) Camp/Horn", 3);
NewNode("Dunland: Dunbog (85.7S, 21.6W) Camp/Horn");
NewEdge("Dunland: Lhan Rhos (86.8S, 23.0W) Stable", "Dunland: Dunbog (85.7S, 21.6W) Camp/Horn", 3);
NewNode("Dunland: Echad Naeglanc (77.3S, 15.8W) Camp/Horn");
NewEdge("Dunland: Echad Naeglanc (77.3S, 15.8W) Stable", "Dunland: Echad Naeglanc (77.3S, 15.8W) Camp/Horn", 3);
NewNode("Dunland: Gravenwood (83.2S, 14.5W) Camp/Horn");
NewEdge("Dunland: Rohirrim Scout-camp (80.9S, 10.6W) Stable", "Dunland: Gravenwood (83.2S, 14.5W) Camp/Horn", 3);
NewNode("Dunland: Starkmoor (82.9S, 21.3W) Camp/Horn");
NewEdge("Dunland: Avardin (83.5S, 20.4W) Stable", "Dunland: Starkmoor (82.9S, 21.3W) Camp/Horn", 3);
NewNode("Dunland: Tal Methedras (78.3S, 11.2W) Camp/Horn");
NewEdge("Dunland: Tal Methedras Gate (78.3S, 11.2W) Stable", "Dunland: Tal Methedras (78.3S, 11.2W) Camp/Horn", 3);
-- Dunland Milestones
NewNode("Dunland: Avardin (83.5W, 20.4W) Milestone");
NewEdge("Dunland: Avardin (83.5S, 20.4W) Stable", "Dunland: Avardin (83.5W, 20.4W) Milestone", 3);
NewNode("Dunland: Barnavon (84.7S, 16.3) Milestone");
NewEdge("Dunland: Barnavon (84.7S, 16.3W) Stable", "Dunland: Barnavon (84.7S, 16.3) Milestone", 3);
NewNode("Dunland: Echad Naeglanc (77.3S, 15.8W) Milestone");
NewEdge("Dunland: Echad Naeglanc (77.3S, 15.8W) Stable", "Dunland: Echad Naeglanc (77.3S, 15.8W) Milestone", 3);
NewNode("Dunland: Galtrev (79.9S, 16.7W) Milestone");
NewEdge("Dunland: Galtrev (80.0S, 16.7W) Stable", "Dunland: Galtrev (79.9S, 16.7W) Milestone", 3);
NewNode("Dunland: Lhan Rhos (86.6S, 23.0W) Milestone");
NewEdge("Dunland: Lhan Rhos (86.8S, 23.0W) Stable", "Dunland: Lhan Rhos (86.6S, 23.0W) Milestone", 3);
NewNode("Dunland: Lhan Tarren (75.3S, 22.4W) Milestone");
NewEdge("Dunland: Lhan Tarren (75.3S, 22.4W) Stable", "Dunland: Lhan Tarren (75.3S, 22.4W) Milestone", 3);
NewNode("Dunland: Rohirrim Scout-camp (80.9S, 10.6W) Milestone");
NewEdge("Dunland: Rohirrim Scout-camp (80.9S, 10.6W) Stable", "Dunland: Rohirrim Scout-camp (80.9S, 10.6W) Milestone", 3);
NewNode("Dunland: Tal Methedras Gate (78.3S, 11.2W) Milestone");
NewEdge("Dunland: Tal Methedras Gate (78.3S, 11.2W) Stable", "Dunland: Tal Methedras Gate (78.3S, 11.2W) Milestone", 3);

-- East Rohan Nodes & Paths
NewNode("East Rohan: Cliving (43.3S, 56.6W) Stable");
NewNode("East Rohan: Eaworth (47.7S, 63.6W) Stable");
NewNode("East Rohan: East Wall Camp (52.2S, 51.3W) Stable");
NewNode("East Rohan: Elthengels (48.9S, 52.9W) Stable");
NewNode("East Rohan: Faldham (54.8S, 57.2W) Stable");
NewNode("East Rohan: Floodwend (45.3S, 48.2W) Stable");
NewNode("East Rohan: Garsfeld (54.7S, 61.8W) Stable");
NewNode("East Rohan: Harwick (39.0S, 52.3W) Stable");
NewNode("East Rohan: Hytbold (57.3S, 55.4W) Stable");
NewNode("East Rohan: Parth Galen (58.7S, 47.8W) Stable");
NewNode("East Rohan: Snowbourn (60.5S, 61.3W) Stable");
NewNode("East Rohan: Thornhope (42.5S, 67.5W) Stable");
NewNode("East Rohan: Walstow (61.8S, 54.5W) Stable");
NewEdge("East Rohan: Cliving (43.3S, 56.6W) Stable", "East Rohan: Eaworth (47.7S, 63.6W) Stable", 1);
NewEdge("East Rohan: Cliving (43.3S, 56.6W) Stable", "East Rohan: Elthengels (48.9S, 52.9W) Stable", 1);
NewEdge("East Rohan: Cliving (43.3S, 56.6W) Stable", "East Rohan: Hytbold (57.3S, 55.4W) Stable", 1);
NewEdge("East Rohan: Cliving (43.3S, 56.6W) Stable", "East Rohan: Faldham (54.8S, 57.2W) Stable", 1);
NewEdge("East Rohan: Cliving (43.3S, 56.6W) Stable", "East Rohan: Harwick (39.0S, 52.3W) Stable", 1);
NewEdge("East Rohan: Cliving (43.3S, 56.6W) Stable", "East Rohan: Parth Galen (58.7S, 47.8W) Stable", 1);
NewEdge("East Rohan: Cliving (43.3S, 56.6W) Stable", "East Rohan: Snowbourn (60.5S, 61.3W) Stable", 1);
NewEdge("East Rohan: East Wall Camp (52.2S, 51.3W) Stable", "East Rohan: Elthengels (48.9S, 52.9W) Stable", 1);
NewEdge("East Rohan: East Wall Camp (52.2S, 51.3W) Stable", "East Rohan: Floodwend (45.3S, 48.2W) Stable", 1);
NewEdge("East Rohan: East Wall Camp (52.2S, 51.3W) Stable", "East Rohan: Parth Galen (58.7S, 47.8W) Stable", 1);
NewEdge("East Rohan: Eaworth (47.7S, 63.6W) Stable", "East Rohan: Cliving (43.3S, 56.6W) Stable", 1);
NewEdge("East Rohan: Eaworth (47.7S, 63.6W) Stable", "East Rohan: Hytbold (57.3S, 55.4W) Stable", 1);
NewEdge("East Rohan: Eaworth (47.7S, 63.6W) Stable", "East Rohan: Garsfeld (54.7S, 61.8W) Stable", 1);
NewEdge("East Rohan: Eaworth (47.7S, 63.6W) Stable", "East Rohan: Harwick (39.0S, 52.3W) Stable", 1);
NewEdge("East Rohan: Eaworth (47.7S, 63.6W) Stable", "East Rohan: Parth Galen (58.7S, 47.8W) Stable", 1);
NewEdge("East Rohan: Eaworth (47.7S, 63.6W) Stable", "East Rohan: Snowbourn (60.5S, 61.3W) Stable", 1);
NewEdge("East Rohan: Eaworth (47.7S, 63.6W) Stable", "East Rohan: Thornhope (42.5S, 67.5W) Stable", 1);
NewEdge("East Rohan: Elthengels (48.9S, 52.9W) Stable", "East Rohan: Cliving (43.3S, 56.6W) Stable", 1);
NewEdge("East Rohan: Elthengels (48.9S, 52.9W) Stable", "East Rohan: Hytbold (57.3S, 55.4W) Stable", 1);
NewEdge("East Rohan: Elthengels (48.9S, 52.9W) Stable", "East Rohan: East Wall Camp (52.2S, 51.3W) Stable", 1);
NewEdge("East Rohan: Elthengels (48.9S, 52.9W) Stable", "East Rohan: Faldham (54.8S, 57.2W) Stable", 1);
NewEdge("East Rohan: Elthengels (48.9S, 52.9W) Stable", "East Rohan: Floodwend (45.3S, 48.2W) Stable", 1);
NewEdge("East Rohan: Elthengels (48.9S, 52.9W) Stable", "East Rohan: Harwick (39.0S, 52.3W) Stable", 1);
NewEdge("East Rohan: Elthengels (48.9S, 52.9W) Stable", "East Rohan: Parth Galen (58.7S, 47.8W) Stable", 1);
NewEdge("East Rohan: Faldham (54.8S, 57.2W) Stable", "East Rohan: Cliving (43.3S, 56.6W) Stable", 1);
NewEdge("East Rohan: Faldham (54.8S, 57.2W) Stable", "East Rohan: Elthengels (48.9S, 52.9W) Stable", 1);
NewEdge("East Rohan: Faldham (54.8S, 57.2W) Stable", "East Rohan: Hytbold (57.3S, 55.4W) Stable", 1);
NewEdge("East Rohan: Faldham (54.8S, 57.2W) Stable", "East Rohan: Garsfeld (54.7S, 61.8W) Stable", 1);
NewEdge("East Rohan: Faldham (54.8S, 57.2W) Stable", "East Rohan: Snowbourn (60.5S, 61.3W) Stable", 1);
NewEdge("East Rohan: Faldham (54.8S, 57.2W) Stable", "East Rohan: Walstow (61.8S, 54.5W) Stable", 1);
NewEdge("East Rohan: Floodwend (45.3S, 48.2W) Stable", "East Rohan: East Wall Camp (52.2S, 51.3W) Stable", 1);
NewEdge("East Rohan: Floodwend (45.3S, 48.2W) Stable", "East Rohan: Elthengels (48.9S, 52.9W) Stable", 1);
NewEdge("East Rohan: Floodwend (45.3S, 48.2W) Stable", "East Rohan: Harwick (39.0S, 52.3W) Stable", 1);
NewEdge("East Rohan: Floodwend (45.3S, 48.2W) Stable", "East Rohan: Parth Galen (58.7S, 47.8W) Stable", 1);
NewEdge("East Rohan: Garsfeld (54.7S, 61.8W) Stable", "East Rohan: Eaworth (47.7S, 63.6W) Stable", 1);
NewEdge("East Rohan: Garsfeld (54.7S, 61.8W) Stable", "East Rohan: Hytbold (57.3S, 55.4W) Stable", 1);
NewEdge("East Rohan: Garsfeld (54.7S, 61.8W) Stable", "East Rohan: Faldham (54.8S, 57.2W) Stable", 1);
NewEdge("East Rohan: Garsfeld (54.7S, 61.8W) Stable", "East Rohan: Snowbourn (60.5S, 61.3W) Stable", 1);
NewEdge("East Rohan: Garsfeld (54.7S, 61.8W) Stable", "East Rohan: Walstow (61.8S, 54.5W) Stable", 1);
NewEdge("East Rohan: Harwick (39.0S, 52.3W) Stable", "East Rohan: Cliving (43.3S, 56.6W) Stable", 1);
NewEdge("East Rohan: Harwick (39.0S, 52.3W) Stable", "East Rohan: Eaworth (47.7S, 63.6W) Stable", 1); 
NewEdge("East Rohan: Harwick (39.0S, 52.3W) Stable", "East Rohan: Elthengels (48.9S, 52.9W) Stable", 1);
NewEdge("East Rohan: Harwick (39.0S, 52.3W) Stable", "East Rohan: Floodwend (45.3S, 48.2W) Stable", 1);
NewEdge("East Rohan: Harwick (39.0S, 52.3W) Stable", "East Rohan: Hytbold (57.3S, 55.4W) Stable", 1);
NewEdge("East Rohan: Harwick (39.0S, 52.3W) Stable", "East Rohan: Parth Galen (58.7S, 47.8W) Stable", 1);
NewEdge("East Rohan: Harwick (39.0S, 52.3W) Stable", "East Rohan: Snowbourn (60.5S, 61.3W) Stable", 1);
NewEdge("East Rohan: Harwick (39.0S, 52.3W) Stable", "Great River: Stangard (25.6W, 63.5W) Stable", 1);
NewEdge("East Rohan: Hytbold (57.3S, 55.4W) Stable", "East Rohan: Cliving (43.3S, 56.6W) Stable", 1);
NewEdge("East Rohan: Hytbold (57.3S, 55.4W) Stable", "East Rohan: Eaworth (47.7S, 63.6W) Stable", 1);
NewEdge("East Rohan: Hytbold (57.3S, 55.4W) Stable", "East Rohan: Elthengels (48.9S, 52.9W) Stable", 1);
NewEdge("East Rohan: Hytbold (57.3S, 55.4W) Stable", "East Rohan: Faldham (54.8S, 57.2W) Stable", 1);
NewEdge("East Rohan: Hytbold (57.3S, 55.4W) Stable", "East Rohan: Garsfeld (54.7S, 61.8W) Stable", 1);
NewEdge("East Rohan: Hytbold (57.3S, 55.4W) Stable", "East Rohan: Harwick (39.0S, 52.3W) Stable", 1);
NewEdge("East Rohan: Hytbold (57.3S, 55.4W) Stable", "East Rohan: Snowbourn (60.5S, 61.3W) Stable", 1);
NewEdge("East Rohan: Hytbold (57.3S, 55.4W) Stable", "East Rohan: Walstow (61.8S, 54.5W) Stable", 1);
NewEdge("East Rohan: Parth Galen (58.7S, 47.8W) Stable", "East Rohan: Cliving (43.3S, 56.6W) Stable", 1);
NewEdge("East Rohan: Parth Galen (58.7S, 47.8W) Stable", "East Rohan: Eaworth (47.7S, 63.6W) Stable", 1);
NewEdge("East Rohan: Parth Galen (58.7S, 47.8W) Stable", "East Rohan: Elthengels (48.9S, 52.9W) Stable", 1);
NewEdge("East Rohan: Parth Galen (58.7S, 47.8W) Stable", "East Rohan: East Wall Camp (52.2S, 51.3W) Stable", 1);
NewEdge("East Rohan: Parth Galen (58.7S, 47.8W) Stable", "East Rohan: Floodwend (45.3S, 48.2W) Stable", 1);
NewEdge("East Rohan: Parth Galen (58.7S, 47.8W) Stable", "East Rohan: Harwick (39.0S, 52.3W) Stable", 1);
NewEdge("East Rohan: Parth Galen (58.7S, 47.8W) Stable", "East Rohan: Snowbourn (60.5S, 61.3W) Stable", 1);
NewEdge("East Rohan: Parth Galen (58.7S, 47.8W) Stable", "East Rohan: Walstow (61.8S, 54.5W) Stable", 1);
NewEdge("East Rohan: Snowbourn (60.5S, 61.3W) Stable", "East Rohan: Cliving (43.3S, 56.6W) Stable", 1);
NewEdge("East Rohan: Snowbourn (60.5S, 61.3W) Stable", "East Rohan: Eaworth (47.7S, 63.6W) Stable", 1);
NewEdge("East Rohan: Snowbourn (60.5S, 61.3W) Stable", "East Rohan: Hytbold (57.3S, 55.4W) Stable", 1);
NewEdge("East Rohan: Snowbourn (60.5S, 61.3W) Stable", "East Rohan: Faldham (54.8S, 57.2W) Stable", 1);
NewEdge("East Rohan: Snowbourn (60.5S, 61.3W) Stable", "East Rohan: Garsfeld (54.7S, 61.8W) Stable", 1);
NewEdge("East Rohan: Snowbourn (60.5S, 61.3W) Stable", "East Rohan: Harwick (39.0S, 52.3W) Stable", 1);
NewEdge("East Rohan: Snowbourn (60.5S, 61.3W) Stable", "East Rohan: Parth Galen (58.7S, 47.8W) Stable", 1);
NewEdge("East Rohan: Snowbourn (60.5S, 61.3W) Stable", "East Rohan: Walstow (61.8S, 54.5W) Stable", 1);
NewEdge("East Rohan: Snowbourn (60.5S, 61.3W) Stable", "Lothlorien: Inner Caras Galadhon (15.1S, 68.2W) Stable", 1);
NewEdge("East Rohan: Snowbourn (60.5S, 61.3W) Stable", "Bree-land: South Bree (31.9S, 50.4W) Stable", 1);
NewEdge("East Rohan: Snowbourn (60.5S, 61.3W) Stable", "Moria: Twenty-first Hall (5.7S, 105.3W) Stable", 1);
NewEdge("East Rohan: Snowbourn (60.5S, 61.3W) Stable", "Great River: Stangard (25.6W, 63.5W) Stable", 1);
NewEdge("East Rohan: Thornhope (42.5S, 67.5W) Stable", "East Rohan: Eaworth (47.7S, 63.6W) Stable", 1);
NewEdge("East Rohan: Walstow (61.8S, 54.5W) Stable", "East Rohan: Hytbold (57.3S, 55.4W) Stable", 1);
NewEdge("East Rohan: Walstow (61.8S, 54.5W) Stable", "East Rohan: Faldham (54.8S, 57.2W) Stable", 1);
NewEdge("East Rohan: Walstow (61.8S, 54.5W) Stable", "East Rohan: Garsfeld (54.7S, 61.8W) Stable", 1);
NewEdge("East Rohan: Walstow (61.8S, 54.5W) Stable", "East Rohan: Parth Galen (58.7S, 47.8W) Stable", 1);
NewEdge("East Rohan: Walstow (61.8S, 54.5W) Stable", "East Rohan: Snowbourn (60.5S, 61.3W) Stable", 1);
-- East Rohan Campsites
NewNode("East Rohan: Caddabrand's Camp (51.4S, 55.8W) Camp");
NewNode("East Rohan: Harwick (39.7S, 52.5W) Camp");
NewEdge("East Rohan: Caddabrand's Camp (51.4S, 55.8W) Camp", "East Rohan: Elthengels (48.9S, 52.9W) Stable", 2);
NewEdge("East Rohan: Harwick (39.7S, 52.5W) Camp", "East Rohan: Harwick (39.0S, 52.3W) Stable", 2);
-- East Rohan Milestones
NewNode("East Rohan: Cliving (43.4S, 56.5W) Milestone");
NewEdge("East Rohan: Cliving (43.4S, 56.5W) Milestone", "East Rohan: Cliving (43.3S, 56.6W) Stable", 2);
NewNode("East Rohan: East Wall Camp (52.0S, 51.2W) Milestone");
NewEdge("East Rohan: East Wall Camp (52.0S, 51.2W) Milestone", "East Rohan: East Wall Camp (52.2S, 51.3W) Stable", 2);
NewNode("East Rohan: Eaworth (47.7S, 63.6W) Milestone");
NewEdge("East Rohan: Eaworth (47.7S, 63.6W) Milestone", "East Rohan: Eaworth (47.7S, 63.6W) Stable", 2);
NewNode("East Rohan: Elthengels (48.9S, 52.4W) Milestone");
NewEdge("East Rohan: Elthengels (48.9S, 52.4W) Milestone", "East Rohan: Elthengels (48.9S, 52.9W) Stable", 2);
NewNode("East Rohan: Faldham (54.5S, 57.3W) Milestone");
NewEdge("East Rohan: Faldham (54.5S, 57.3W) Milestone", "East Rohan: Faldham (54.8S, 57.2W) Stable", 2);
NewNode("East Rohan: Floodwend (45.5S, 48.2W) Milestone");
NewEdge("East Rohan: Floodwend (45.5S, 48.2W) Milestone", "East Rohan: Floodwend (45.3S, 48.2W) Stable", 2);
NewNode("East Rohan: Harwick (39.2S, 52.3W) Milestone");
NewEdge("East Rohan: Harwick (39.2S, 52.3W) Milestone", "East Rohan: Harwick (39.0S, 52.3W) Stable", 2);
NewNode("East Rohan: Hytbold (57.4S, 55.4W) Milestone");
NewEdge("East Rohan: Hytbold (57.4S, 55.4W) Milestone", "East Rohan: Hytbold (57.3S, 55.4W) Stable", 2);
NewNode("East Rohan: Garsfeld (54.7S, 61.7W) Milestone");
NewEdge("East Rohan: Garsfeld (54.7S, 61.7W) Milestone", "East Rohan: Garsfeld (54.7S, 61.8W) Stable", 2);
NewNode("East Rohan: Langhold (36.2S, 53.5W) Milestone");
NewEdge("East Rohan: Langhold (36.2S, 53.5W) Milestone", "East Rohan: Harwick (39.0S, 52.3W) Stable", 2);
NewNode("East Rohan: Parth Galen (58.7S, 47.7W) Milestone");
NewEdge("East Rohan: Parth Galen (58.7S, 47.7W) Milestone", "East Rohan: Parth Galen (58.7S, 47.8W) Stable", 2);
NewNode("East Rohan: Snowbourne (60.6S, 61.7W) Milestone");
NewEdge("East Rohan: Snowbourne (60.6S, 61.7W) Milestone", "East Rohan: Snowbourn (60.5S, 61.3W) Stable", 2);
NewNode("East Rohan: Thornhope (42.5S, 67.5W) Milestone");
NewEdge("East Rohan: Thornhope (42.5S, 67.5W) Milestone", "East Rohan: Thornhope (42.5S, 67.5W) Stable", 2)
-- East Rohan Places of Interest
NewNode("East Rohan: The Argonath (51.3S, 48.0W)");
NewEdge("East Rohan: East Wall Camp (52.2S, 51.3W) Stable", "East Rohan: The Argonath (51.3S, 48.0W)", 2);

-- Enedwaith Nodes & Paths
NewNode("Enedwaith: Echad Daervunn (66.6S, 21.5W) Stable");
NewNode("Enedwaith: Echad Dagoras (58.5S, 14.5W) Stable");
NewNode("Enedwaith: Harndirion (69.4S, 13.7W) Stable");
NewNode("Enedwaith: Lhanuch (66.9S, 16.9W) Stable");
NewNode("Enedwaith: Maur Tulhau (62.9S, 23.2W) Stable");
NewEdge("Enedwaith: Echad Daervunn (66.6S, 21.5W) Stable", "Enedwaith: Echad Dagoras (58.5S, 14.5W) Stable", 1);
NewEdge("Enedwaith: Echad Daervunn (66.6S, 21.5W) Stable", "Enedwaith: Harndirion (69.4S, 13.7W) Stable", 1);
NewEdge("Enedwaith: Echad Daervunn (66.6S, 21.5W) Stable", "Dunland: Lhan Tarren (75.3S, 22.4W) Stable", 1);
NewEdge("Enedwaith: Echad Daervunn (66.6S, 21.5W) Stable", "Enedwaith: Lhanuch (66.9S, 16.9W) Stable", 1);
NewEdge("Enedwaith: Echad Daervunn (66.6S, 21.5W) Stable", "Enedwaith: Maur Tulhau (62.9S, 23.2W) Stable", 1);
NewEdge("Enedwaith: Echad Dagoras (58.5S, 14.5W) Stable", "Enedwaith: Harndirion (69.4S, 13.7W) Stable", 1);
NewEdge("Enedwaith: Echad Dagoras (58.5S, 14.5W) Stable", "Enedwaith: Echad Daervunn (66.6S, 21.5W) Stable", 1);
NewEdge("Enedwaith: Echad Dagoras (58.5S, 14.5W) Stable", "Eregion: Echad Dunann (50.6S, 7.8W) Stable", 1);
NewEdge("Enedwaith: Echad Dagoras (58.5S, 14.5W) Stable", "Eregion: Echad Mirobel (52.3S, 17.0W) Stable", 1);
NewEdge("Enedwaith: Echad Dagoras (58.5S, 14.5W) Stable", "Enedwaith: Lhanuch (66.9S, 16.9W) Stable", 1);
NewEdge("Enedwaith: Echad Dagoras (58.5S, 14.5W) Stable", "Enedwaith: Maur Tulhau (62.9S, 23.2W) Stable", 1);
NewEdge("Enedwaith: Harndirion (69.4S, 13.7W) Stable", "Enedwaith: Echad Daervunn (66.6S, 21.5W) Stable", 1);
NewEdge("Enedwaith: Harndirion (69.4S, 13.7W) Stable", "Enedwaith: Echad Dagoras (58.5S, 14.5W) Stable", 1);
NewEdge("Enedwaith: Harndirion (69.4S, 13.7W) Stable", "Dunland: Echad Naeglanc (77.3S, 15.8W) Stable", 1);
NewEdge("Enedwaith: Harndirion (69.4S, 13.7W) Stable", "Enedwaith: Lhanuch (66.9S, 16.9W) Stable", 1);
NewEdge("Enedwaith: Harndirion (69.4S, 13.7W) Stable", "Enedwaith: Maur Tulhau (62.9S, 23.2W) Stable", 1);
NewEdge("Enedwaith: Lhanuch (66.9S, 16.9W) Stable", "Enedwaith: Echad Dagoras (58.5S, 14.5W) Stable", 1);
NewEdge("Enedwaith: Lhanuch (66.9S, 16.9W) Stable", "Enedwaith: Echad Daervunn (66.6S, 21.5W) Stable", 1);
NewEdge("Enedwaith: Lhanuch (66.9S, 16.9W) Stable", "Dunland: Galtrev (80.0S, 16.7W) Stable", 1);
NewEdge("Enedwaith: Lhanuch (66.9S, 16.9W) Stable", "Enedwaith: Harndirion (69.4S, 13.7W) Stable", 1);
NewEdge("Enedwaith: Lhanuch (66.9S, 16.9W) Stable", "Lothlorien: Inner Caras Galadhon (15.1S, 68.2W) Stable", 1);
NewEdge("Enedwaith: Lhanuch (66.9S, 16.9W) Stable", "Enedwaith: Maur Tulhau (62.9S, 23.2W) Stable", 1);
NewEdge("Enedwaith: Lhanuch (66.9S, 16.9W) Stable", "Trollshaws: Rivendell (29.3S, 6.4W) Stable", 1);
NewEdge("Enedwaith: Lhanuch (66.9S, 16.9W) Stable", "Bree-land: South Bree (31.9S, 50.4W) Stable", 1);
NewEdge("Enedwaith: Maur Tulhau (62.9S, 23.2W) Stable", "Enedwaith: Echad Dagoras (58.5S, 14.5W) Stable", 1);
NewEdge("Enedwaith: Maur Tulhau (62.9S, 23.2W) Stable", "Enedwaith: Echad Daervunn (66.6S, 21.5W) Stable", 1);
NewEdge("Enedwaith: Maur Tulhau (62.9S, 23.2W) Stable", "Enedwaith: Harndirion (69.4S, 13.7W) Stable", 1);
NewEdge("Enedwaith: Maur Tulhau (62.9S, 23.2W) Stable", "Enedwaith: Lhanuch (66.9S, 16.9W) Stable", 1);
-- Enedwaith Campsites & Horns
NewNode("Enedwaith: Echad Daervunn (66.6S, 21.5W) Camp/Horn");
NewEdge("Enedwaith: Echad Daervunn (66.6S, 21.5W) Stable", "Enedwaith: Echad Daervunn (66.6S, 21.5W) Camp/Horn", 3);
NewNode("Enedwaith: Echad Idhrenfair (63.5S, 21.5W) Camp/Horn");
NewEdge("Enedwaith: Maur Tulhau (62.9S, 23.2W) Stable", "Enedwaith: Echad Idhrenfair (63.5S, 21.5W) Camp/Horn", 3);
NewNode("Enedwaith: Harndirion (69.4S, 13.8W) Camp/Horn");
NewEdge("Enedwaith: Harndirion (69.4S, 13.7W) Stable", "Enedwaith: Harndirion (69.4S, 13.8W) Camp/Horn", 3);
NewNode("Enedwaith: Lich Bluffs (74.0S, 19.3W) Camp/Horn");
NewEdge("Enedwaith: Harndirion (69.4S, 13.7W) Stable", "Enedwaith: Lich Bluffs (74.0S, 19.3W) Camp/Horn", 3);
NewNode("Enedwaith: Nar's Peak (65.7S, 8.6W) Camp/Horn");
NewEdge("Enedwaith: Harndirion (69.4S, 13.7W) Stable", "Enedwaith: Nar's Peak (65.7S, 8.6W) Camp/Horn", 3);
-- Enedwaith Milestones
NewNode("Enedwaith: Echad Dagoras (58.5S, 14.6W) Milestone");
NewEdge("Enedwaith: Echad Dagoras (58.5S, 14.5W) Stable", "Enedwaith: Echad Dagoras (58.5S, 14.6W) Milestone", 1);
NewNode("Enedwaith: Harndirion (69.3S, 17.2W) Milestone");
NewEdge("Enedwaith: Harndirion (69.4S, 13.7W) Stable", "Enedwaith: Harndirion (69.3S, 17.2W) Milestone", 3);
NewNode("Enedwaith: Lhanuch (66.5S, 17.2W) Milestone");
NewEdge("Enedwaith: Lhanuch (66.9S, 16.9W) Stable", "Enedwaith: Lhanuch (66.5S, 17.2W) Milestone", 3);
NewNode("Enedwaith: Maur Tulhau (62.9S, 23.2W) Milestone");
NewEdge("Enedwaith: Maur Tulhau (62.9S, 23.2W) Stable", "Enedwaith: Maur Tulhau (62.9S, 23.2W) Milestone", 3);
NewNode("Enedwaith: Nar's Peak (65.7S, 8.6W) Milestone");
NewEdge("Enedwaith: Nar's Peak (65.7S, 8.6W) Camp/Horn", "Enedwaith: Nar's Peak (65.7S, 8.6W) Milestone", 3);

-- Ered Luin Paths
NewNode("Ered Luin: Celondim (28.1S, 92.4W) Stable");
NewNode("Ered Luin: Duillond (24.6S, 93.1W) Stable");
NewNode("Ered Luin: Gondamon (20.4S, 97.0W) Stable");
NewNode("Ered Luin: Noglond (19.4S, 100.6W) Stable");
NewNode("Ered Luin: Thorin's Gate (15.0S, 103.6W) Stable");
NewNode("Ered Luin: Thrasi's Lodge (21.6S, 94.1W) Stable");
NewEdge("Ered Luin: Celondim (28.1S, 92.4W) Stable", "Bree-land: Combe (28,6S, 49.5W) Stable", 1);
NewEdge("Ered Luin: Celondim (28.1S, 92.4W) Stable", "Ered Luin: Duillond (24.6S, 93.1W) Stable", 2);
NewEdge("Ered Luin: Celondim (28.1S, 92.4W) Stable", "Shire: Michel Delving (34.2S, 75.5W) Stable", 1);
NewEdge("Ered Luin: Celondim (28.1S, 92.4W) Stable", "Ered Luin: Thorin's Gate (15.0S, 103.6W) Stable", 1);
NewEdge("Ered Luin: Celondim (28.1S, 92.4W) Stable", "Bree-land: West Bree (29,5S, 52.6W) Stable", 1);
NewEdge("Ered Luin: Duillond (24.6S, 93.1W) Stable", "Ered Luin: Celondim (28.1S, 92.4W) Stable", 2);
NewEdge("Ered Luin: Duillond (24.6S, 93.1W) Stable", "Ered Luin: Gondamon (20.4S, 97.0W) Stable", 2);
NewEdge("Ered Luin: Duillond (24.6S, 93.1W) Stable", "Shire: Needlehole (27.9S, 76.1W) Stable", 2);
NewEdge("Ered Luin: Duillond (24.6S, 93.1W) Stable", "Ered Luin: Thorin's Gate (15.0S, 103.6W) Stable", 2);
NewEdge("Ered Luin: Duillond (24.6S, 93.1W) Stable", "Ered Luin: Thrasi's Lodge (21.6S, 94.1W) Stable", 2);
NewEdge("Ered Luin: Gondamon (20.4S, 97.0W) Stable", "Ered Luin: Duillond (24.6S, 93.1W) Stable", 2);
NewEdge("Ered Luin: Gondamon (20.4S, 97.0W) Stable", "Ered Luin: Noglond (19.4S, 100.6W) Stable", 2);
NewEdge("Ered Luin: Gondamon (20.4S, 97.0W) Stable", "Ered Luin: Thorin's Gate (15.0S, 103.6W) Stable", 2);
NewEdge("Ered Luin: Gondamon (20.4S, 97.0W) Stable", "Ered Luin: Thrasi's Lodge (21.6S, 94.1W) Stable", 2);
NewEdge("Ered Luin: Noglond (19.4S, 100.6W) Stable", "Ered Luin: Gondamon (20.4S, 97.0W) Stable", 2);
NewEdge("Ered Luin: Noglond (19.4S, 100.6W) Stable", "Ered Luin: Thorin's Gate (15.0S, 103.6W) Stable", 2);
NewEdge("Ered Luin: Thorin's Gate (15.0S, 103.6W) Stable", "Ered Luin: Celondim (28.1S, 92.4W) Stable", 1);
NewEdge("Ered Luin: Thorin's Gate (15.0S, 103.6W) Stable", "Bree-land: Combe (28,6S, 49.5W) Stable", 1);
NewEdge("Ered Luin: Thorin's Gate (15.0S, 103.6W) Stable", "Ettenmoors: Glan Vraig (21.S, 13.4W) Stable", 1);
NewEdge("Ered Luin: Thorin's Gate (15.0S, 103.6W) Stable", "Ered Luin: Duillond (24.6S, 93.1W) Stable", 2);
NewEdge("Ered Luin: Thorin's Gate (15.0S, 103.6W) Stable", "Ered Luin: Gondamon (20.4S, 97.0W) Stable", 2);
NewEdge("Ered Luin: Thorin's Gate (15.0S, 103.6W) Stable", "Shire: Michel Delving (34.2S, 75.5W) Stable", 1);
NewEdge("Ered Luin: Thorin's Gate (15.0S, 103.6W) Stable", "Ered Luin: Noglond (19.4S, 100.6W) Stable", 2);
NewEdge("Ered Luin: Thorin's Gate (15.0S, 103.6W) Stable", "Bree-land: West Bree (29,5S, 52.6W) Stable", 1);
NewEdge("Ered Luin: Thrasi's Lodge (21.6S, 94.1W) Stable", "Ered Luin: Duillond (24.6S, 93.1W) Stable", 2);
NewEdge("Ered Luin: Thrasi's Lodge (21.6S, 94.1W) Stable", "Ered Luin: Gondamon (20.4S, 97.0W) Stable", 2);
-- Ered Luin Campsite & Horns
NewNode("Ered Luin: Falathlorn (24.3S, 93.7W) Camp");
NewEdge("Ered Luin: Duillond (24.6S, 93.1W) Stable", "Ered Luin: Falathlorn (24.3S, 93.7W) Camp", 3);
NewNode("Ered Luin: Treasure Field Base Camp (18.7S, 98.2W) Camp/Horn");
NewEdge("Ered Luin: Gondamon (20.4S, 97.0W) Stable", "Ered Luin: Treasure Field Base Camp (18.7S, 98.2W) Camp/Horn", 3);
NewNode("Ered Luin: Vale of Thrain (19.1S, 101.7W) Camp");
NewEdge("Ered Luin: Noglond (19.4S, 100.6W) Stable", "Ered Luin: Vale of Thrain (19.1S, 101.7W) Camp", 3);
-- Ered Luin Milestones
NewNode("Ered Luin: Celondim (28.3S, 92.1W) Milestone");
NewEdge("Ered Luin: Celondim (28.1S, 92.4W) Stable","Ered Luin: Celondim (28.3S, 92.1W) Milestone", 3);
NewNode("Ered Luin: Duillond (24.3S, 93.2W) Milestone");
NewEdge("Ered Luin: Duillond (24.6S, 93.1W) Stable", "Ered Luin: Duillond (24.3S, 93.2W) Milestone", 3);
NewNode("Ered Luin: Gondamon (20.2S, 97.0W) Milestone");
NewEdge("Ered Luin: Gondamon (20.4S, 97.0W) Stable", "Ered Luin: Gondamon (20.2S, 97.0W) Milestone", 3);
NewNode("Ered Luin: Falathlorn Homesteads (24.9S, 90.7W) Milestone");
NewEdge("Ered Luin: Duillond (24.6S, 93.1W) Stable", "Ered Luin: Falathlorn Homesteads (24.9S, 90.7W) Milestone", 3);
NewNode("Ered Luin: Thorin's Hall (13.8S, 103.2W) Milestone");
NewEdge("Ered Luin: Thorin's Gate (15.0S, 103.6W) Stable", "Ered Luin: Thorin's Hall (13.8S, 103.2W) Milestone", 3);
NewNode("Ered Luin: Thorin's Hall Homesteads (15.7S, 104.8W) Milestone");
NewEdge("Ered Luin: Thorin's Gate (15.0S, 103.6W) Stable", "Ered Luin: Thorin's Hall Homesteads (15.7S, 104.8W) Milestone", 3)

-- Ered Mithrin Nodes & Paths
NewNode("Ered Mithrin: Dom Goru (33.1N, 38.6W) Stable");
NewNode("Ered Mithrin: Skarhald (34.7N, 45.4W) Stable");
NewNode("Ered Mithrin: Skarhald (34.3N, 45.2W) Milestone");
NewEdge("Ered Mithrin: Dom Goru (33.1N, 38.6W) Stable", "Eryn Lasgalen: Dale (24.0N, 26.1W) Stable", 1);
NewEdge("Ered Mithrin: Dom Goru (33.1N, 38.6W) Stable", "Eryn Lasgalen: Dale (24.0N, 26.1W) Stable", 2);
NewEdge("Ered Mithrin: Dom Goru (33.1N, 38.6W) Stable", "Eryn Lasgalen: Erebor (29.1N, 25.7W) Stable", 1);
NewEdge("Ered Mithrin: Dom Goru (33.1N, 38.6W) Stable", "Eryn Lasgalen: Erebor (29.1N, 25.7W) Stable", 2);
NewEdge("Ered Mithrin: Dom Goru (33.1N, 38.6W) Stable", "Iron Hills: Hammerstead (30.9N, 12.1W) Stable", 1);
NewEdge("Ered Mithrin: Dom Goru (33.1N, 38.6W) Stable", "Iron Hills: Hammerstead (30.9N, 12.1W) Stable", 2);
NewEdge("Ered Mithrin: Dom Goru (33.1N, 38.6W) Stable", "Iron Hills: Jarnfast (28.4N, 3.7W) Stable", 1);
NewEdge("Ered Mithrin: Dom Goru (33.1N, 38.6W) Stable", "Iron Hills: Jarnfast (28.4N, 3.7W) Stable", 2);
NewEdge("Ered Mithrin: Dom Goru (33.1N, 38.6W) Stable", "Iron Hills: Skald's Drop (21.1N, 15.7W) Stable", 1);
NewEdge("Ered Mithrin: Dom Goru (33.1N, 38.6W) Stable", "Iron Hills: Skald's Drop (21.1N, 15.7W) Stable", 2);
NewEdge("Ered Mithrin: Skarhald (34.7N, 45.4W) Stable", "Ered Mithrin: Skarhald (34.3N, 45.2W) Milestone", 3);
NewEdge("Ered Mithrin: Skarhald (34.7N, 45.4W) Stable", "Bree-land: South Bree (31.9S, 50.4W) Stable", 1);
NewEdge("Ered Mithrin: Skarhald (34.7N, 45.4W) Stable", "Dunland: Galtrev (80.0S, 16.7W) Stable", 1);
NewEdge("Ered Mithrin: Skarhald (34.7N, 45.4W) Stable", "Moria: Twenty-first Hall (5.7S, 105.3W) Stable", 1);
NewEdge("Ered Mithrin: Skarhald (34.7N, 45.4W) Stable", "Old Anorien: Minas Tirith Main Gate (65.8S, 16.8W) Stable", 1);
NewEdge("Ered Mithrin: Skarhald (34.7N, 45.4W) Stable", "West Rohan: Aldburg (68.7S, 63.9W) Stable", 1);
NewEdge("Ered Mithrin: Skarhald (34.7N, 45.4W) Stable", "Eryn Lasgalen: Dale (24.0N, 26.1W) Stable", 1);
NewEdge("Ered Mithrin: Skarhald (34.7N, 45.4W) Stable", "Eryn Lasgalen: Dale (24.0N, 26.1W) Stable", 2);
NewEdge("Ered Mithrin: Skarhald (34.7N, 45.4W) Stable", "Eryn Lasgalen: Erebor (29.1N, 25.7W) Stable", 1);
NewEdge("Ered Mithrin: Skarhald (34.7N, 45.4W) Stable", "Eryn Lasgalen: Erebor (29.1N, 25.7W) Stable", 2);
NewEdge("Ered Mithrin: Skarhald (34.7N, 45.4W) Stable", "Ered Mithrin: Dom Goru (33.1N, 38.6W) Stable", 1);
NewEdge("Ered Mithrin: Skarhald (34.7N, 45.4W) Stable", "Ered Mithrin: Dom Goru (33.1N, 38.6W) Stable", 2);
NewEdge("Ered Mithrin: Skarhald (34.7N, 45.4W) Stable", "Iron Hills: Hammerstead (30.9N, 12.1W) Stable", 1);
NewEdge("Ered Mithrin: Skarhald (34.7N, 45.4W) Stable", "Iron Hills: Hammerstead (30.9N, 12.1W) Stable", 2);
NewEdge("Ered Mithrin: Skarhald (34.7N, 45.4W) Stable", "Iron Hills: Jarnfast (28.4N, 3.7W) Stable", 1);
NewEdge("Ered Mithrin: Skarhald (34.7N, 45.4W) Stable", "Iron Hills: Jarnfast (28.4N, 3.7W) Stable", 2);
NewEdge("Ered Mithrin: Skarhald (34.7N, 45.4W) Stable", "Iron Hills: Jarnfast (28.4N, 3.7W) Stable", 1);
NewEdge("Ered Mithrin: Skarhald (34.7N, 45.4W) Stable", "Iron Hills: Jarnfast (28.4N, 3.7W) Stable", 2);
NewEdge("Ered Mithrin: Skarhald (34.7N, 45.4W) Stable", "Iron Hills: Skald's Drop (21.1N, 15.7W) Stable", 1);
NewEdge("Ered Mithrin: Skarhald (34.7N, 45.4W) Stable", "Iron Hills: Skald's Drop (21.1N, 15.7W) Stable", 2);
NewEdge("Ered Mithrin: Skarhald (34.7N, 45.4W) Stable", "Western Gondor: Dol Amroth (75.5S, 72.5W) Stable", 1);

-- Eregion Nodes & Paths
NewNode("Eregion: Echad Dunann (50.6S, 7.8W) Stable");
NewNode("Eregion: Echad Eregion (47.0S, 12.6W) Stable");
NewNode("Eregion: Echad Mirobel (52.3S, 17.0W) Stable");
NewNode("Eregion: Gwingris (40.2S, 16.0W) Stable");
NewNode("The Walls of Moria (52.1S, 4.0W)");
NewEdge("Eregion: Echad Dunann (50.6S, 7.8W) Stable", "Enedwaith: Echad Dagoras (58.5S, 14.5W) Stable", 1);
NewEdge("Eregion: Echad Dunann (50.6S, 7.8W) Stable", "Eregion: Echad Eregion (47.0S, 12.6W) Stable", 1);
NewEdge("Eregion: Echad Dunann (50.6S, 7.8W) Stable", "Eregion: Echad Mirobel (52.3S, 17.0W) Stable", 1);
NewEdge("Eregion: Echad Dunann (50.6S, 7.8W) Stable", "Eregion: Gwingris (40.2S, 16.0W) Stable", 1)
NewEdge("Eregion: Echad Dunann (50.6S, 7.8W) Stable", "Trollshaws: Rivendell (29.3S, 6.4W) Stable", 1);
NewEdge("Eregion: Echad Dunann (50.6S, 7.8W) Stable", "The Walls of Moria (52.1S, 4.0W)", 1);
NewEdge("Eregion: Echad Eregion (47.0S, 12.6W) Stable", "Trollshaws: Echad Candelleth (36.8S, 14.3W) Stable", 2);
NewEdge("Eregion: Echad Eregion (47.0S, 12.6W) Stable", "Eregion: Echad Dunann (50.6S, 7.8W) Stable", 1);
NewEdge("Eregion: Echad Eregion (47.0S, 12.6W) Stable", "Eregion: Gwingris (40.2S, 16.0W) Stable", 1);
NewEdge("Eregion: Echad Eregion (47.0S, 12.6W) Stable", "Eregion: Echad Mirobel (52.3S, 17.0W) Stable", 1);
NewEdge("Eregion: Echad Eregion (47.0S, 12.6W) Stable", "Trollshaws: Rivendell (29.3S, 6.4W) Stable", 1);
NewEdge("Eregion: Echad Mirobel (52.3S, 17.0W) Stable", "Eregion: Echad Eregion (47.0S, 12.6W) Stable", 1);
NewEdge("Eregion: Echad Mirobel (52.3S, 17.0W) Stable", "Enedwaith: Echad Dagoras (58.5S, 14.5W) Stable", 1);
NewEdge("Eregion: Echad Mirobel (52.3S, 17.0W) Stable", "Eregion: Echad Dunann (50.6S, 7.8W) Stable", 1);
NewEdge("Eregion: Echad Mirobel (52.3S, 17.0W) Stable", "Eregion: Gwingris (40.2S, 16.0W) Stable", 1);
NewEdge("Eregion: Echad Mirobel (52.3S, 17.0W) Stable", "Trollshaws: Rivendell (29.3S, 6.4W) Stable", 1);
NewEdge("Eregion: Gwingris (40.2S, 16.0W) Stable", "Trollshaws: Echad Candelleth (36.8S, 14.3W) Stable", 2);
NewEdge("Eregion: Gwingris (40.2S, 16.0W) Stable", "Eregion: Echad Dunann (50.6S, 7.8W) Stable", 1);
NewEdge("Eregion: Gwingris (40.2S, 16.0W) Stable", "Eregion: Echad Eregion (47.0S, 12.6W) Stable", 1);
NewEdge("Eregion: Gwingris (40.2S, 16.0W) Stable", "Eregion: Echad Mirobel (52.3S, 17.0W) Stable", 1);
NewEdge("Eregion: Gwingris (40.2S, 16.0W) Stable", "Trollshaws: Rivendell (29.3S, 6.4W) Stable", 1);
NewEdge("The Walls of Moria (52.1S, 4.0W)", "Durin's Door Exit (51.9S, 3.4W)", 1);
-- Eregion Campsites & Horns
NewNode("Eregion: Burnt Tor (49.1S, 9.3W) Camp");
NewEdge("Eregion: Echad Dunann (50.6S, 7.8W) Stable", "Eregion: Burnt Tor (49.1S, 9.3W) Camp", 3);
NewNode("Eregion: Mirobel (52.3S, 17.1W) Camp/Horn");
NewEdge("Eregion: Echad Mirobel (52.3S, 17.0W) Stable", "Eregion: Mirobel (52.3S, 17.1W) Camp/Horn", 3);
NewNode("Eregion: Pend Eregion (41.4S, 11.1W) Camp");
NewEdge("Eregion: Gwingris (40.2S, 16.0W) Stable", "Eregion: Pend Eregion (41.4S, 11.1W) Camp", 3);
-- Eregion Milestones
NewNode("Eregion: Echad Dunann (50.5S, 7.8W) Milestone");
NewEdge("Eregion: Echad Dunann (50.6S, 7.8W) Stable", "Eregion: Echad Dunann (50.5S, 7.8W) Milestone", 3);
NewNode("Eregion: Echad Eregion (46.9S, 12.5W) Milestone");
NewEdge("Eregion: Echad Eregion (47.0S, 12.6W) Stable", "Eregion: Echad Eregion (46.9S, 12.5W) Milestone", 3);
NewNode("Eregion: Echad Mirobel (52.5S, 16.7W) Milestone");
NewEdge("Eregion: Echad Eregion (47.0S, 12.6W) Stable", "Eregion: Echad Mirobel (52.5S, 16.7W) Milestone", 3);
NewNode("Eregion: Gwingris (40.0S, 16.2W) Milestone");
NewEdge("Eregion: Gwingris (40.2S, 16.0W) Stable", "Eregion: Gwingris (40.0S, 16.2W) Milestone", 3);

-- Eryn Lasgalen Nodes & Paths
NewNode("Eryn Lasgalen: Tham Taerdol (12.1N, 46.1W) Stable");
NewNode("Eryn Lasgalen: Tham Taerdol (12.2N, 46.2W) Milestone");
NewNode("Eryn Lasgalen: Dale (24.0N, 26.1W) Stable");
NewNode("Eryn Lasgalen: Dale (25.1N, 25.8W) Milestone");
NewNode("Eryn Lasgalen: Dale East (24.1N, 24.9W) Milestone");
NewNode("Eryn Lasgalen: Erebor (29.1N, 25.7W) Stable");
NewNode("Eryn Lasgalen: Erebor (29.0N, 25.7W) Milestone");
NewNode("Eryn Lasgalen: Felegoth (20.3N, 36.9W) Stable");
NewNode("Eryn Lasgalen: Felegoth (20.3N, 36.7W) Milestone");
NewNode("Eryn Lasgalen: Lake-Town (17.2N, 27.9W) Stable");
NewNode("Eryn Lasgalen: Lake-Town (17.2N, 27.3W) Milestone");
NewNode("Eryn Lasgalen: Loeglond (15.2N, 32.4W) Milestone");
NewNode("Eryn Lasgalen: Ruins of Dol Guldur (12.1N, 46.1W) Horse");
NewEdge("Eryn Lasgalen: Tham Taerdol (12.1N, 46.1W) Stable", "Eryn Lasgalen: Ruins of Dol Guldur (12.1N, 46.1W) Horse", 3);
NewEdge("Eryn Lasgalen: Tham Taerdol (12.1N, 46.1W) Stable", "Eryn Lasgalen: Tham Taerdol (12.2N, 46.2W) Milestone", 3);
NewEdge("Eryn Lasgalen: Tham Taerdol (12.1N, 46.1W) Stable", "Eryn Lasgalen: Dale (24.0N, 26.1W) Stable", 1);
NewEdge("Eryn Lasgalen: Tham Taerdol (12.1N, 46.1W) Stable", "Eryn Lasgalen: Dale (24.0N, 26.1W) Stable", 2);
NewEdge("Eryn Lasgalen: Tham Taerdol (12.1N, 46.1W) Stable", "Eryn Lasgalen: Erebor (29.1N, 25.7W) Stable", 1);
NewEdge("Eryn Lasgalen: Tham Taerdol (12.1N, 46.1W) Stable", "Eryn Lasgalen: Erebor (29.1N, 25.7W) Stable", 2);
NewEdge("Eryn Lasgalen: Tham Taerdol (12.1N, 46.1W) Stable", "Eryn Lasgalen: Felegoth (20.3N, 36.9W) Stable", 1);
NewEdge("Eryn Lasgalen: Tham Taerdol (12.1N, 46.1W) Stable", "Eryn Lasgalen: Felegoth (20.3N, 36.9W) Stable", 2);
NewEdge("Eryn Lasgalen: Tham Taerdol (12.1N, 46.1W) Stable", "Eryn Lasgalen: Lake-Town (17.2N, 27.9W) Stable", 1);
NewEdge("Eryn Lasgalen: Tham Taerdol (12.1N, 46.1W) Stable", "Eryn Lasgalen: Lake-Town (17.2N, 27.9W) Stable", 2);
NewEdge("Eryn Lasgalen: Dale (24.0N, 26.1W) Stable", "Eryn Lasgalen: Dale (25.1N, 25.8W) Milestone", 3);
NewEdge("Eryn Lasgalen: Dale (24.0N, 26.1W) Stable", "Eryn Lasgalen: Dale East (24.1N, 24.9W) Milestone", 3);
NewEdge("Eryn Lasgalen: Erebor (29.1N, 25.7W) Stable", "Eryn Lasgalen: Erebor (29.0N, 25.7W) Milestone", 3);
NewEdge("Eryn Lasgalen: Felegoth (20.3N, 36.9W) Stable", "Eryn Lasgalen: Felegoth (20.3N, 36.7W) Milestone", 3);
NewEdge("Eryn Lasgalen: Lake-Town (17.2N, 27.9W) Stable", "Eryn Lasgalen: Lake-Town (17.2N, 27.3W) Milestone", 3);
NewEdge("Eryn Lasgalen: Lake-Town (17.2N, 27.9W) Stable", "Eryn Lasgalen: Loeglond (15.2N, 32.4W) Milestone", 3);
NewEdge("Eryn Lasgalen: Lake-Town (17.2N, 27.9W) Stable", "Bree-land: South Bree (31.9S, 50.4W) Stable", 1);
NewEdge("Eryn Lasgalen: Dale (24.0N, 26.1W) Stable", "Bree-land: South Bree (31.9S, 50.4W) Stable", 1);
NewEdge("Eryn Lasgalen: Dale (24.0N, 26.1W) Stable", "Dunland: Galtrev (80.0S, 16.7W) Stable", 1);
NewEdge("Eryn Lasgalen: Dale (24.0N, 26.1W) Stable", "Moria: Twenty-first Hall (5.7S, 105.3W) Stable", 1);
NewEdge("Eryn Lasgalen: Dale (24.0N, 26.1W) Stable", "Old Anorien: Minas Tirith Main Gate (65.8S, 16.8W) Stable", 1);
NewEdge("Eryn Lasgalen: Dale (24.0N, 26.1W) Stable", "West Rohan: Aldburg (68.7S, 63.9W) Stable", 1);
NewEdge("Eryn Lasgalen: Dale (24.0N, 26.1W) Stable", "Eryn Lasgalen: Erebor (29.1N, 25.7W) Stable", 1);
NewEdge("Eryn Lasgalen: Dale (24.0N, 26.1W) Stable", "Eryn Lasgalen: Erebor (29.1N, 25.7W) Stable", 2);
NewEdge("Eryn Lasgalen: Dale (24.0N, 26.1W) Stable", "Eryn Lasgalen: Felegoth (20.3N, 36.9W) Stable", 1);
NewEdge("Eryn Lasgalen: Dale (24.0N, 26.1W) Stable", "Eryn Lasgalen: Felegoth (20.3N, 36.9W) Stable", 2);
NewEdge("Eryn Lasgalen: Dale (24.0N, 26.1W) Stable", "Eryn Lasgalen: Lake-Town (17.2N, 27.9W) Stable", 1);
NewEdge("Eryn Lasgalen: Dale (24.0N, 26.1W) Stable", "Eryn Lasgalen: Lake-Town (17.2N, 27.9W) Stable", 2);
NewEdge("Eryn Lasgalen: Dale (24.0N, 26.1W) Stable", "Eryn Lasgalen: Tham Taerdol (12.1N, 46.1W) Stable", 1);
NewEdge("Eryn Lasgalen: Dale (24.0N, 26.1W) Stable", "Eryn Lasgalen: Tham Taerdol (12.1N, 46.1W) Stable", 2);
NewEdge("Eryn Lasgalen: Dale (24.0N, 26.1W) Stable", "Western Gondor: Dol Amroth (75.5S, 72.5W) Stable", 1);

-- Paths Ettenmoors
NewNode("Ettenmoors: Glan Vraig (21.S, 13.4W) Stable");
NewEdge("Ettenmoors: Glan Vraig (21.S, 13.4W) Stable", "Shire: Michel Delving (34.2S, 75.5W) Stable", 1);
NewEdge("Ettenmoors: Glan Vraig (21.S, 13.4W) Stable", "Trollshaws: Rivendell (29.3S, 6.4W) Stable", 1);
NewEdge("Ettenmoors: Glan Vraig (21.S, 13.4W) Stable", "Bree-land: South Bree (31.9S, 50.4W) Stable", 1);
NewEdge("Ettenmoors: Glan Vraig (21.S, 13.4W) Stable", "Ered Luin: Thorin's Gate (15.0S, 103.6W) Stable", 1);
 
-- Evendim Nodes & Paths
NewNode("Evendim: Annuminas (19.1S, 70.9W) Stable");
NewNode("Evendim: Dwaling (20.8S, 64.7SW) Stable");
NewNode("Evendim: High King's Crossing (13.8S, 64.0W) Stable");
NewNode("Evendim: Men Erain (15.4S, 66.3W) Boat");
NewNode("Evendim: Oatbarton (23.2S, 67.3W) Stable");
NewNode("Evendim: Ost Forod (8.2S, 64.3W) Stable");
NewNode("Evendim: The Eavespires (6.0S, 71.8W) Boat");
NewNode("Evendim: Tinnudir (12.4S, 67.2W) Stable");
NewNode("Evendim: Tinnudir (12.6S, 67.6W) Boat");
NewNode("Evendim: Tyl Ruinen (12.9S, 70.7W) Boat");
NewEdge("Evendim: Annuminas (19.1S, 70.9W) Stable", "Evendim: Tinnudir (12.4S, 67.2W) Stable", 1);
NewEdge("Evendim: Dwaling (20.8S, 64.7SW) Stable", "Evendim: High King's Crossing (13.8S, 64.0W) Stable", 1);
NewEdge("Evendim: Dwaling (20.8S, 64.7SW) Stable", "Evendim: Ost Forod (8.2S, 64.3W) Stable", 1);
NewEdge("Evendim: Dwaling (20.8S, 64.7SW) Stable", "Evendim: Tinnudir (12.4S, 67.2W) Stable", 1);
NewEdge("Evendim: High King's Crossing (13.8S, 64.0W) Stable", "Evendim: Dwaling (20.8S, 64.7SW) Stable", 1);
NewEdge("Evendim: High King's Crossing (13.8S, 64.0W) Stable", "Evendim: Oatbarton (23.2S, 67.3W) Stable", 1);
NewEdge("Evendim: High King's Crossing (13.8S, 64.0W) Stable", "Evendim: Ost Forod (8.2S, 64.3W) Stable", 1);
NewEdge("Evendim: High King's Crossing (13.8S, 64.0W) Stable", "Evendim: Tinnudir (12.4S, 67.2W) Stable", 1);
NewEdge("Evendim: Men Erain (15.4S, 66.3W) Boat", "Evendim: Tinnudir (12.6S, 67.6W) Boat", 1);
NewEdge("Evendim: Men Erain (15.4S, 66.3W) Boat", "Evendim: The Eavespires (6.0S, 71.8W) Boat", 1);
NewEdge("Evendim: Men Erain (15.4S, 66.3W) Boat", "Evendim: Tyl Ruinen (12.9S, 70.7W) Boat", 1);
NewEdge("Evendim: Oatbarton (23.2S, 67.3W) Stable", "Shire: Brockenborings (27.5S, 68.1W) Stable", 2);
NewEdge("Evendim: Oatbarton (23.2S, 67.3W) Stable", "Evendim: Dwaling (20.8S, 64.7SW) Stable", 1);
NewEdge("Evendim: Oatbarton (23.2S, 67.3W) Stable", "Evendim: High King's Crossing (13.8S, 64.0W) Stable", 1);
NewEdge("Evendim: Oatbarton (23.2S, 67.3W) Stable", "Evendim: Ost Forod (8.2S, 64.3W) Stable", 1);
NewEdge("Evendim: Oatbarton (23.2S, 67.3W) Stable", "Evendim: Tinnudir (12.4S, 67.2W) Stable", 1);
NewEdge("Evendim: Ost Forod (8.2S, 64.3W) Stable", "Evendim: High King's Crossing (13.8S, 64.0W) Stable", 1);
NewEdge("Evendim: Ost Forod (8.2S, 64.3W) Stable", "Forochel: Kauppa-kohta (2.6N, 58.0W) Stable", 2);
NewEdge("Evendim: Ost Forod (8.2S, 64.3W) Stable", "Forochel: Pynti-peldot (11.3N, 69.4W) Stable", 1);
NewEdge("Evendim: Ost Forod (8.2S, 64.3W) Stable", "Forochel: Suri-kyla (19.1N, 70.8W) Stable", 1);
NewEdge("Evendim: Ost Forod (8.2S, 64.3W) Stable", "Evendim: Tinnudir (12.4S, 67.2W) Stable", 1);
NewEdge("Evendim: Ost Forod (8.2S, 64.3W) Stable", "North Downs: Trestlebridge (18.0S, 53.6W) Stable", 2);
NewEdge("Evendim: Ost Forod (8.2S, 64.3W) Stable", "Bree-land: West Bree (29,5S, 52.6W) Stable", 1);
NewEdge("Evendim: Tinnudir (12.4S, 67.2W) Stable", "Evendim: Annuminas (19.1S, 70.9W) Stable", 1);
NewEdge("Evendim: Tinnudir (12.4S, 67.2W) Stable", "Evendim: Dwaling (20.8S, 64.7SW) Stable", 1);
NewEdge("Evendim: Tinnudir (12.4S, 67.2W) Stable", "North Downs: Esteldin (9.7S, 42.1W) Stable", 1);
NewEdge("Evendim: Tinnudir (12.4S, 67.2W) Stable", "Evendim: High King's Crossing (13.8S, 64.0W) Stable", 1);
NewEdge("Evendim: Tinnudir (12.4S, 67.2W) Stable", "Shire: Michel Delving (34.2S, 75.5W) Stable", 1);
NewEdge("Evendim: Tinnudir (12.4S, 67.2W) Stable", "Evendim: Oatbarton (23.2S, 67.3W) Stable", 1);
NewEdge("Evendim: Tinnudir (12.4S, 67.2W) Stable", "Evendim: Ost Forod (8.2S, 64.3W) Stable", 1);
NewEdge("Evendim: Tinnudir (12.4S, 67.2W) Stable", "Evendim: Tinnudir (12.6S, 67.6W) Boat", 1);
NewEdge("Evendim: Tinnudir (12.4S, 67.2W) Stable", "North Downs: Trestlebridge (18.0S, 53.6W) Stable", 2);
NewEdge("Evendim: Tinnudir (12.4S, 67.2W) Stable", "Bree-land: West Bree (29,5S, 52.6W) Stable", 1);
NewEdge("Evendim: Tinnudir (12.6S, 67.6W) Boat", "Evendim: Men Erain (15.4S, 66.3W) Boat", 1);
NewEdge("Evendim: Tinnudir (12.6S, 67.6W) Boat", "Evendim: The Eavespires (6.0S, 71.8W) Boat", 1);
NewEdge("Evendim: Tinnudir (12.6S, 67.6W) Boat", "Evendim: Tinnudir (12.4S, 67.2W) Stable", 1);
NewEdge("Evendim: Tinnudir (12.6S, 67.6W) Boat", "Evendim: Tyl Ruinen (12.9S, 70.7W) Boat", 1);
NewEdge("Evendim: The Eavespires (6.0S, 71.8W) Boat", "Evendim: Men Erain (15.4S, 66.3W) Boat", 1);
NewEdge("Evendim: The Eavespires (6.0S, 71.8W) Boat", "Evendim: Tinnudir (12.6S, 67.6W) Boat", 1);
NewEdge("Evendim: The Eavespires (6.0S, 71.8W) Boat", "Evendim: Tyl Ruinen (12.9S, 70.7W) Boat", 1);
NewEdge("Evendim: Tyl Ruinen (12.9S, 70.7W) Boat", "Evendim: Men Erain (15.4S, 66.3W) Boat", 1);
NewEdge("Evendim: Tyl Ruinen (12.9S, 70.7W) Boat", "Evendim: The Eavespires (6.0S, 71.8W) Boat", 1);
NewEdge("Evendim: Tyl Ruinen (12.9S, 70.7W) Boat", "Evendim: Tinnudir (12.6S, 67.6W) Boat", 1);
-- Evendim Campsites & Horns
NewNode("Evendim: Annuminas (19.1S, 70.9W) Camp/Horn");
NewEdge("Evendim: Annuminas (19.1S, 70.9W) Stable", "Evendim: Annuminas (19.1S, 70.9W) Camp/Horn", 3);
NewNode("Evendim: Barandalf (15.8S, 63.2W) Camp");
NewEdge("Evendim: High King's Crossing (13.8S, 64.0W) Stable", "Evendim: Barandalf (15.8S, 63.2W) Camp", 3);
NewNode("Evendim: Bullroarer's Sward (23.4S, 67.9W) Camp/Horn");
NewEdge("Evendim: Oatbarton (23.2S, 67.3W) Stable", "Evendim: Bullroarer's Sward (23.4S, 67.9W) Camp/Horn", 3);
NewNode("Evendim: Northern Emyn Uial (6.2S, 74.7W) Camp");
NewEdge("Evendim: The Eavespires (6.0S, 71.8W) Boat", "Evendim: Northern Emyn Uial (6.2S, 74.7W) Camp", 3);
-- Evendim Milestones
NewNode("Evendim: Annuminas (19.1S, 71.0W) Milestone");
NewEdge("Evendim: Annuminas (19.1S, 70.9W) Stable", "Evendim: Annuminas (19.1S, 71.0W) Milestone", 3);
NewNode("Evendim: Glass Blower's Camp (23.2S, 67.3W)");
NewEdge("Evendim: Oatbarton (23.2S, 67.3W) Stable", "Evendim: Glass Blower's Camp (23.2S, 67.3W)", 2);
NewNode("Evendim: High King's Crossing (13.9S, 64.1W) Milestone");
NewEdge("Evendim: High King's Crossing (13.8S, 64.0W) Stable", "Evendim: High King's Crossing (13.9S, 64.1W) Milestone", 3);
NewNode("Evendim: Ost Forod (7.4S, 64.3W) Milestone");
NewEdge("Evendim: Ost Forod (8.2S, 64.3W) Stable", "Evendim: Ost Forod (7.4S, 64.3W) Milestone", 3);
NewNode("Evendim: Tinnudir (12.6S, 67.2W) Milestone");
NewEdge("Evendim: Tinnudir (12.4S, 67.2W) Stable", "Evendim: Tinnudir (12.6S, 67.2W) Milestone", 3);
NewNode("Evendim: The Eavespires (6.1S, 71.8W) Milestone");
NewEdge("Evendim: The Eavespires (6.0S, 71.8W) Boat", "Evendim: The Eavespires (6.1S, 71.8W) Milestone", 3);

-- Far Anorien Nodes & Paths
NewNode("Far Anorien: Ost Rimmon (46.8S, 36.4W) Stable");
NewEdge("Far Anorien: Ost Rimmon (46.8S, 36.4W) Stable", "Far Anorien: War-Stead of the Rohirrim (45.1S, 29.2W) Stable", 1);
NewEdge("Far Anorien: Ost Rimmon (46.8S, 36.4W) Stable", "Far Anorien: War-Stead of the Rohirrim (45.1S, 29.2W) Stable", 2);
NewEdge("Far Anorien: Ost Rimmon (46.8S, 36.4W) Stable", "Old Anorien: Minas Tirith Main Gate (65.8S, 16.8W) Stable", 1);
NewEdge("Far Anorien: Ost Rimmon (46.8S, 36.4W) Stable", "West Rohan: Aldburg (68.7S, 63.9W) Stable", 2);

NewNode("Far Anorien: War-Stead of the Rohirrim (45.1S, 29.2W) Stable");
NewEdge("Far Anorien: War-Stead of the Rohirrim (45.1S, 29.2W) Stable", "Old Anorien: Minas Tirith Main Gate (65.8S, 16.8W) Stable", 1);
NewEdge("Far Anorien: War-Stead of the Rohirrim (45.1S, 29.2W) Stable", "Far Anorien: Ost Rimmon (46.8S, 36.4W) Stable", 1);
NewEdge("Far Anorien: War-Stead of the Rohirrim (45.1S, 29.2W) Stable", "Far Anorien: Ost Rimmon (46.8S, 36.4W) Stable", 2);
NewNode("Far Anorien: War-Stead of the Rohirrim (45.5S, 27.3W) Milestone");
NewEdge("Far Anorien: War-Stead of the Rohirrim (45.1S, 29.2W) Stable", "Far Anorien: War-Stead of the Rohirrim (45.5S, 27.3W) Milestone", 3);
NewNode("Far Anorien: War-Stead of the Rohirrim (45.6S, 27.3W) Camp");
NewEdge("Far Anorien: War-Stead of the Rohirrim (45.1S, 29.2W) Stable", "Far Anorien: War-Stead of the Rohirrim (45.6S, 27.3W) Camp", 3);


-- Forochel Nodes & Paths
NewNode("Forochel: Kauppa-kohta (2.6N, 58.0W) Stable");
NewNode("Forochel: Kuru-leiri (19.5N, 83.7W) Stable");
NewNode("Forochel: Pynti-peldot (11.3N, 69.4W) Stable");
NewNode("Forochel: Suri-kyla (19.1N, 70.8W) Stable");
NewNode("Forochel: Zigilgund (9.6N, 81.1W) Stable");
NewEdge("Forochel: Kauppa-kohta (2.6N, 58.0W) Stable", "Evendim: Ost Forod (8.2S, 64.3W) Stable", 1);
NewEdge("Forochel: Kauppa-kohta (2.6N, 58.0W) Stable", "Forochel: Pynti-peldot (11.3N, 69.4W) Stable", 2);
NewEdge("Forochel: Kuru-leiri (19.5N, 83.7W) Stable", "Forochel: Suri-kyla (19.1N, 70.8W) Stable", 1);
NewEdge("Forochel: Pynti-peldot (11.3N, 69.4W) Stable", "Forochel: Kauppa-kohta (2.6N, 58.0W) Stable", 2);
NewEdge("Forochel: Pynti-peldot (11.3N, 69.4W) Stable", "Evendim: Ost Forod (8.2S, 64.3W) Stable", 1);
NewEdge("Forochel: Pynti-peldot (11.3N, 69.4W) Stable", "Forochel: Suri-kyla (19.1N, 70.8W) Stable", 2);
NewEdge("Forochel: Pynti-peldot (11.3N, 69.4W) Stable", "Forochel: Zigilgund (9.6N, 81.1W) Stable", 2);
NewEdge("Forochel: Suri-kyla (19.1N, 70.8W) Stable", "Angmar: Gath Forthnir (10.4N, 24.0W) Stable", 1);
NewEdge("Forochel: Suri-kyla (19.1N, 70.8W) Stable", "Forochel: Kuru-leiri (19.5N, 83.7W) Stable", 1);
NewEdge("Forochel: Suri-kyla (19.1N, 70.8W) Stable", "Evendim: Ost Forod (8.2S, 64.3W) Stable", 1);
NewEdge("Forochel: Suri-kyla (19.1N, 70.8W) Stable", "Forochel: Pynti-peldot (11.3N, 69.4W) Stable", 2);
NewEdge("Forochel: Suri-kyla (19.1N, 70.8W) Stable", "Trollshaws: Rivendell (29.3S, 6.4W) Stable", 1);
NewEdge("Forochel: Suri-kyla (19.1N, 70.8W) Stable", "Bree-land: West Bree (29,5S, 52.6W) Stable", 1);
NewEdge("Forochel: Suri-kyla (19.1N, 70.8W) Stable", "Forochel: Zigilgund (9.6N, 81.1W) Stable", 1);
NewEdge("Forochel: Zigilgund (9.6N, 81.1W) Stable", "Forochel: Pynti-peldot (11.3N, 69.4W) Stable", 2);
NewEdge("Forochel: Zigilgund (9.6N, 81.1W) Stable", "Forochel: Suri-kyla (19.1N, 70.8W) Stable", 1);
-- Forochel Campsites & Horns
NewNode("Forochel: Ita-ma (7.4N, 75.4W) Camp");
NewEdge("Forochel: Zigilgund (9.6N, 81.1W) Stable", "Forochel: Ita-ma (7.4N, 75.4W) Camp", 3);
NewNode("Forochel: Ja-rannit (19.5N, 73.7W) Camp/Horn");
NewEdge("Forochel: Suri-kyla (19.1N, 70.8W) Stable", "Forochel: Ja-rannit (19.5N, 73.7W) Camp/Horn", 3);
NewNode("Forochel: Ja-rannit (17,5N, 64.5W) Camp");
NewEdge("Forochel: Suri-kyla (19.1N, 70.8W) Stable", "Forochel: Ja-rannit (17,5N, 64.5W) Camp", 3);
NewNode("Forochel: Kuru-leiri (19.5N, 83.7W) Camp");
NewEdge("Forochel: Kuru-leiri (19.5N, 83.7W) Stable", "Forochel: Kuru-leiri (19.5N, 83.7W) Camp", 3);
-- Forochel Milestones
NewNode("Forochel: Kauppa-kohta (3.0N, 58.0W) Milestone");
NewEdge("Forochel: Kauppa-kohta (2.6N, 58.0W) Stable", "Forochel: Kauppa-kohta (3.0N, 58.0W) Milestone", 3);
NewNode("Forochel: Kuru-leiri (19.5N, 83.8W) Milestone");
NewEdge("Forochel: Kuru-leiri (19.5N, 83.7W) Stable", "Forochel: Kuru-leiri (19.5N, 83.8W) Milestone", 3);
NewNode("Forochel: Pynti-peldot (11.3N, 69.8W) Milestone");
NewEdge("Forochel: Pynti-peldot (11.3N, 69.4W) Stable", "Forochel: Pynti-peldot (11.3N, 69.8W) Milestone", 3);
NewNode("Forochel: Suri-kyla (19.1N, 70.9W) Milestone");
NewEdge("Forochel: Suri-kyla (19.1N, 70.8W) Stable", "Forochel: Suri-kyla (19.1N, 70.9W) Milestone", 3);
NewNode("Forochel: Zigilgund (9.5N, 81.1W) Milestone");
NewEdge("Forochel: Zigilgund (9.6N, 81.1W) Stable", "Forochel: Zigilgund (9.5N, 81.1W) Milestone", 3);

-- Gap of Rohan Nodes & Paths
NewNode("Gap of Rohan: Forthbrond (86.9S, 7.5W) Stable");
NewNode("Gap of Rohan: Grimbold's Camp (87.8S, 3.9W) Stable");
NewEdge("Gap of Rohan: Forthbrond (86.9S, 7.5W) Stable", "Dunland: Galtrev (80.0S, 16.7W) Stable", 1);
NewEdge("Gap of Rohan: Forthbrond (86.9S, 7.5W) Stable", "Gap of Rohan: Grimbold's Camp (87.8S, 3.9W) Stable", 1);
NewEdge("Gap of Rohan: Forthbrond (86.9S, 7.5W) Stable", "Dunland: Rohirrim Scout-camp (80.9S, 10.6W) Stable", 1);
NewEdge("Gap of Rohan: Grimbold's Camp (87.8S, 3.9W) Stable", "Nan Curunir: Dagoras' Camp (84.9S, 3.4W) Stable", 1);
NewEdge("Gap of Rohan: Grimbold's Camp (87.8S, 3.9W) Stable", "Gap of Rohan: Forthbrond (86.9S, 7.5W) Stable", 1);
NewEdge("Gap of Rohan: Grimbold's Camp (87.8S, 3.9W) Stable", "Dunland: Galtrev (80.0S, 16.7W) Stable", 1);
-- Gap of Rohan Campsites & Horns
NewNode("Gap of Rohan: Forthbrond (87.2S, 7.4W) Camp/Horn");
NewEdge("Gap of Rohan: Forthbrond (86.9S, 7.5W) Stable", "Gap of Rohan: Forthbrond (87.2S, 7.4W) Camp/Horn", 3);
NewNode("Gap of Rohan: Grimbold's Camp (87.8S, 3.9W) Camp/Horn");
NewEdge("Gap of Rohan: Grimbold's Camp (87.8S, 3.9W) Stable", "Gap of Rohan: Grimbold's Camp (87.8S, 3.9W) Camp/Horn", 3);
-- Gap of Rohan Milestones
NewNode("Gap of Rohan: Forthbrond (86.9S, 7.6W) Milestone");
NewEdge("Gap of Rohan: Forthbrond (86.9S, 7.5W) Stable", "Gap of Rohan: Forthbrond (86.9S, 7.6W) Milestone", 3);
NewNode("Gap of Rohan: Grimbold's Cap (87.8S, 3.9W) Milestone");
NewEdge("Gap of Rohan: Grimbold's Camp (87.8S, 3.9W) Stable", "Gap of Rohan: Grimbold's Cap (87.8S, 3.9W) Milestone", 3);

-- Paths Great River
NewNode("Great River: Brown Lands (31.2S, 52.0W) Stable");
NewNode("Great River: Parth Celebrant (26.6S, 53.3W) Stable");
NewNode("Great River: Rushgore (29.2S, 55.2W) Stable");
NewNode("Great River: Stangard (25.6W, 63.5W) Stable");
NewNode("Great River: Thinglad (21.4S, 63.4W) Stable");
NewNode("Great River: Wailing Hills (25.6S, 67.0W) Stable");
NewEdge("Great River: Brown Lands (31.2S, 52.0W) Stable", "Great River: Parth Celebrant (26.6S, 53.3W) Stable", 1);
NewEdge("Great River: Brown Lands (31.2S, 52.0W) Stable", "Great River: Rushgore (29.2S, 55.2W) Stable", 1);
NewEdge("Great River: Brown Lands (31.2S, 52.0W) Stable", "Great River: Stangard (25.6W, 63.5W) Stable", 1);
NewEdge("Great River: Brown Lands (31.2S, 52.0W) Stable", "Great River: Thinglad (21.4S, 63.4W) Stable", 1);
NewEdge("Great River: Brown Lands (31.2S, 52.0W) Stable", "Great River: Wailing Hills (25.6S, 67.0W) Stable", 1);
NewEdge("Great River: Parth Celebrant (26.6S, 53.3W) Stable", "Great River: Brown Lands (31.2S, 52.0W) Stable", 1);
NewEdge("Great River: Parth Celebrant (26.6S, 53.3W) Stable", "Great River: Rushgore (29.2S, 55.2W) Stable", 1);
NewEdge("Great River: Parth Celebrant (26.6S, 53.3W) Stable", "Great River: Stangard (25.6W, 63.5W) Stable", 1);
NewEdge("Great River: Parth Celebrant (26.6S, 53.3W) Stable", "Great River: Thinglad (21.4S, 63.4W) Stable", 1);
NewEdge("Great River: Parth Celebrant (26.6S, 53.3W) Stable", "Great River: Wailing Hills (25.6S, 67.0W) Stable", 1);
NewEdge("Great River: Rushgore (29.2S, 55.2W) Stable", "Great River: Brown Lands (31.2S, 52.0W) Stable", 1);
NewEdge("Great River: Rushgore (29.2S, 55.2W) Stable", "Great River: Parth Celebrant (26.6S, 53.3W) Stable", 1);
NewEdge("Great River: Rushgore (29.2S, 55.2W) Stable", "Great River: Stangard (25.6W, 63.5W) Stable", 1);
NewEdge("Great River: Rushgore (29.2S, 55.2W) Stable", "Great River: Thinglad (21.4S, 63.4W) Stable", 1);
NewEdge("Great River: Rushgore (29.2S, 55.2W) Stable", "Great River: Wailing Hills (25.6S, 67.0W) Stable", 1);
NewEdge("Great River: Stangard (25.6W, 63.5W) Stable", "Great River: Brown Lands (31.2S, 52.0W) Stable", 1);
NewEdge("Great River: Stangard (25.6W, 63.5W) Stable", "Lothlorien: Inner Caras Galadhon (15.1S, 68.2W) Stable", 1);
NewEdge("Great River: Stangard (25.6W, 63.5W) Stable", "Great River: Parth Celebrant (26.6S, 53.3W) Stable", 1);
NewEdge("Great River: Stangard (25.6W, 63.5W) Stable", "Great River: Rushgore (29.2S, 55.2W) Stable", 1);
NewEdge("Great River: Stangard (25.6W, 63.5W) Stable", "Bree-land: South Bree (31.9S, 50.4W) Stable", 1);
NewEdge("Great River: Stangard (25.6W, 63.5W) Stable", "Great River: Thinglad (21.4S, 63.4W) Stable", 1);
NewEdge("Great River: Stangard (25.6W, 63.5W) Stable", "Moria: Twenty-first Hall (5.7S, 105.3W) Stable", 1);
NewEdge("Great River: Stangard (25.6W, 63.5W) Stable", "Great River: Wailing Hills (25.6S, 67.0W) Stable", 1);
NewEdge("Great River: Thinglad (21.4S, 63.4W) Stable", "Great River: Brown Lands (31.2S, 52.0W) Stable", 1);
NewEdge("Great River: Thinglad (21.4S, 63.4W) Stable", "Great River: Parth Celebrant (26.6S, 53.3W) Stable", 1);
NewEdge("Great River: Thinglad (21.4S, 63.4W) Stable", "Great River: Rushgore (29.2S, 55.2W) Stable", 1);
NewEdge("Great River: Thinglad (21.4S, 63.4W) Stable", "Great River: Stangard (25.6W, 63.5W) Stable", 1);
NewEdge("Great River: Thinglad (21.4S, 63.4W) Stable", "Lothlorien: The Vinyards of Lorien (18.3, 64.2W) Stable", 1);
NewEdge("Great River: Thinglad (21.4S, 63.4W) Stable", "Great River: Wailing Hills (25.6S, 67.0W) Stable", 1);
NewEdge("Great River: Wailing Hills (25.6S, 67.0W) Stable", "Great River: Brown Lands (31.2S, 52.0W) Stable", 1);
NewEdge("Great River: Wailing Hills (25.6S, 67.0W) Stable", "Great River: Parth Celebrant (26.6S, 53.3W) Stable", 1);
NewEdge("Great River: Wailing Hills (25.6S, 67.0W) Stable", "Great River: Rushgore (29.2S, 55.2W) Stable", 1);
NewEdge("Great River: Wailing Hills (25.6S, 67.0W) Stable", "Great River: Stangard (25.6W, 63.5W) Stable", 1);
NewEdge("Great River: Wailing Hills (25.6S, 67.0W) Stable", "Great River: Thinglad (21.4S, 63.4W) Stable", 1);
-- Great River Campsites & Horns
NewNode("Great River: Etheburg (31.4S, 52.1W) Camp");
NewEdge("Great River: Brown Lands (31.2S, 52.0W) Stable", "Great River: Etheburg (31.4S, 52.1W) Camp", 3);
NewNode("Great River: Stangard (26.1S, 63.1W) Camp");
NewEdge("Great River: Stangard (25.6W, 63.5W) Stable", "Great River: Stangard (26.1S, 63.1W) Camp", 3);
NewNode("Great River: The Cuthstan (25.8S, 65.9W) Camp");
NewEdge("Great River: Wailing Hills (25.6S, 67.0W) Stable", "Great River: The Cuthstan (25.8S, 65.9W) Camp", 3);
NewNode("Great River: Idmar's Camp (28.5S, 56.8W) Camp/Horn");
NewEdge("Great River: Rushgore (29.2S, 55.2W) Stable", "Great River: Idmar's Camp (28.5S, 56.8W) Camp/Horn", 3);
NewNode("Great River: Parth Celebrant (26.6S, 58.3W) Camp/Horn");
NewEdge("Great River: Parth Celebrant (26.6S, 53.3W) Stable", "Great River: Parth Celebrant (26.6S, 58.3W) Camp/Horn", 3);
NewNode("Great River: Aculf's Camp (29.1S, 55.2W) Camp");
NewEdge("Great River: Rushgore (29.2S, 55.2W) Stable", "Great River: Aculf's Camp (29.1S, 55.2W) Camp", 3);
NewNode("Great River: Woodmen's Camp (28.8S, 53.3W Camp/Horn");
NewEdge("Great River: Rushgore (29.2S, 55.2W) Stable", "Great River: Woodmen's Camp (28.8S, 53.3W Camp/Horn", 3);
NewNode("Great River: Haldirith (21.4S, 63.6W) Camp");
NewEdge("Great River: Thinglad (21.4S, 63.4W) Stable", "Great River: Haldirith (21.4S, 63.6W) Camp", 3);
-- Great River Campsites
NewNode("Great River: Etheburg (31.2S, 52.2W) Milestone");
NewEdge("Great River: Brown Lands (31.2S, 52.0W) Stable", "Great River: Etheburg (31.2S, 52.2W) Milestone", 3);
NewNode("Great River: Stangard (26.3S, 63.8W) Milestone");
NewEdge("Great River: Stangard (25.6W, 63.5W) Stable", "Great River: Stangard (26.3S, 63.8W) Milestone", 3);
NewNode("Great River: The Cuthstan (25.7S, 66.0W) Milestone");
NewEdge("Great River: Wailing Hills (25.6S, 67.0W) Stable", "Great River: The Cuthstan (25.7S, 66.0W) Milestone", 3);
NewNode("Great River: Parth Celebrant (26.6S, 58.3W) Milestone");
NewEdge("Great River: Parth Celebrant (26.6S, 53.3W) Stable", "Great River: Parth Celebrant (26.6S, 58.3W) Milestone", 3);
NewNode("Great River: Aculf's Camp (29.1S, 55.2W) Milestone");
NewEdge("Great River: Rushgore (29.2S, 55.2W) Stable", "Great River: Aculf's Camp (29.1S, 55.2W) Milestone", 3);
NewNode("Great River: Haldirith (21.4S, 63.5W) Milestone");
NewEdge("Great River: Thinglad (21.4S, 63.4W) Stable", "Great River: Haldirith (21.4S, 63.5W) Milestone", 3);

-- Iron Hills Nodes & Paths
NewNode("Iron Hills: Skald's Drop (21.1N, 15.7W) Stable");
NewNode("Iron Hills: Skald's Drop (21.1N, 15.7W) Camp");
NewNode("Iron Hills: Jarnfast (28.4N, 3.7W) Stable");
NewNode("Iron Hills: Jarnfast (28.4N, 3.7W) Milestone");
NewNode("Iron Hills: Hammerstead (30.9N, 12.1W) Stable");
NewNode("Iron Hills: Hammerstead (30.9N, 12.2W) Milestone");
NewEdge("Iron Hills: Skald's Drop (21.1N, 15.7W) Stable", "Eryn Lasgalen: Dale (24.0N, 26.1W) Stable", 1);
NewEdge("Iron Hills: Skald's Drop (21.1N, 15.7W) Stable", "Eryn Lasgalen: Dale (24.0N, 26.1W) Stable", 2);
NewEdge("Iron Hills: Skald's Drop (21.1N, 15.7W) Stable", "Eryn Lasgalen: Erebor (29.1N, 25.7W) Stable", 1);
NewEdge("Iron Hills: Skald's Drop (21.1N, 15.7W) Stable", "Eryn Lasgalen: Erebor (29.1N, 25.7W) Stable", 2);
NewEdge("Iron Hills: Skald's Drop (21.1N, 15.7W) Stable", "Iron Hills: Skald's Drop (21.1N, 15.7W) Camp", 3);
NewEdge("Iron Hills: Jarnfast (28.4N, 3.7W) Stable", "Iron Hills: Jarnfast (28.4N, 3.7W) Milestone", 3);
NewEdge("Iron Hills: Jarnfast (28.4N, 3.7W) Stable", "Bree-land: South Bree (31.9S, 50.4W) Stable", 1);
NewEdge("Iron Hills: Jarnfast (28.4N, 3.7W) Stable", "Dunland: Galtrev (80.0S, 16.7W) Stable", 1);
NewEdge("Iron Hills: Jarnfast (28.4N, 3.7W) Stable", "Moria: Twenty-first Hall (5.7S, 105.3W) Stable", 1);
NewEdge("Iron Hills: Jarnfast (28.4N, 3.7W) Stable", "Old Anorien: Minas Tirith Main Gate (65.8S, 16.8W) Stable", 1);
NewEdge("Iron Hills: Jarnfast (28.4N, 3.7W) Stable", "West Rohan: Aldburg (68.7S, 63.9W) Stable", 1);
NewEdge("Iron Hills: Jarnfast (28.4N, 3.7W) Stable", "Eryn Lasgalen: Dale (24.0N, 26.1W) Stable", 1);
NewEdge("Iron Hills: Jarnfast (28.4N, 3.7W) Stable", "Eryn Lasgalen: Dale (24.0N, 26.1W) Stable", 2);
NewEdge("Iron Hills: Jarnfast (28.4N, 3.7W) Stable", "Eryn Lasgalen: Erebor (29.1N, 25.7W) Stable", 1);
NewEdge("Iron Hills: Jarnfast (28.4N, 3.7W) Stable", "Eryn Lasgalen: Erebor (29.1N, 25.7W) Stable", 2);
NewEdge("Iron Hills: Jarnfast (28.4N, 3.7W) Stable", "Iron Hills: Skald's Drop (21.1N, 15.7W) Stable", 1);
NewEdge("Iron Hills: Jarnfast (28.4N, 3.7W) Stable", "Iron Hills: Skald's Drop (21.1N, 15.7W) Stable", 2);
NewEdge("Iron Hills: Jarnfast (28.4N, 3.7W) Stable", "Western Gondor: Dol Amroth (75.5S, 72.5W) Stable", 1);
NewEdge("Iron Hills: Hammerstead (30.9N, 12.1W) Stable", "Iron Hills: Hammerstead (30.9N, 12.2W) Milestone", 3);
NewEdge("Iron Hills: Hammerstead (30.9N, 12.1W) Stable", "Eryn Lasgalen: Dale (24.0N, 26.1W) Stable", 1);
NewEdge("Iron Hills: Hammerstead (30.9N, 12.1W) Stable", "Eryn Lasgalen: Dale (24.0N, 26.1W) Stable", 2);
NewEdge("Iron Hills: Hammerstead (30.9N, 12.1W) Stable", "Eryn Lasgalen: Erebor (29.1N, 25.7W) Stable", 1);
NewEdge("Iron Hills: Hammerstead (30.9N, 12.1W) Stable", "Eryn Lasgalen: Erebor (29.1N, 25.7W) Stable", 2);
NewEdge("Iron Hills: Hammerstead (30.9N, 12.1W) Stable", "Iron Hills: Jarnfast (28.4N, 3.7W) Stable", 1);
NewEdge("Iron Hills: Hammerstead (30.9N, 12.1W) Stable", "Iron Hills: Jarnfast (28.4N, 3.7W) Stable", 2);
NewEdge("Iron Hills: Hammerstead (30.9N, 12.1W) Stable", "Iron Hills: Skald's Drop (21.1N, 15.7W) Stable", 1);
NewEdge("Iron Hills: Hammerstead (30.9N, 12.1W) Stable", "Iron Hills: Skald's Drop (21.1N, 15.7W) Stable", 2);

-- Lonelands Nodes & Paths
NewNode("Lone Lands: The Forsakken Inn (34.4S, 40.6W) Stable");
NewNode("Lone Lands: Candaith's Encampment (30.1S, 37.9W) Stable");
NewNode("Lone Lands: Ost Guruth (32.1S, 29.8W) Stable");
NewEdge("Lone Lands: Candaith's Encampment (30.1S, 37.9W) Stable", "Lone Lands: The Forsakken Inn (34.4S, 40.6W) Stable", 1);
NewEdge("Lone Lands: Ost Guruth (32.1S, 29.8W) Stable", "Lone Lands: The Forsakken Inn (34.4S, 40.6W) Stable", 2);
NewEdge("Lone Lands: Ost Guruth (32.1S, 29.8W) Stable", "Trollshaws: Thorenhad (31.7S, 15.0W) Stable", 2);
NewEdge("Lone Lands: Ost Guruth (32.1S, 29.8W) Stable", "Trollshaws: Rivendell (29.3S, 6.4W) Stable", 1);
NewEdge("Lone Lands: Ost Guruth (32.1S, 29.8W) Stable", "Bree-land: South Bree (31.9S, 50.4W) Stable", 1);
NewEdge("Lone Lands: Ost Guruth (32.1S, 29.8W) Stable", "Lone Lands: Candaith's Encampment (30.2S, 37.9W) Camp", 3);
NewEdge("Lone Lands: The Forsakken Inn (34.4S, 40.6W) Stable", "Lone Lands: Ost Guruth (32.1S, 29.8W) Stable", 2);
NewEdge("Lone Lands: The Forsakken Inn (34.4S, 40.6W) Stable", "Bree-land: South Bree (31.9S, 50.4W) Stable", 2);
-- Lonelands Campsites & Horns
NewNode("Lone Lands: Candaith's Encampment (30.2S, 37.9W) Camp");
NewEdge("Lone Lands: Candaith's Encampment (30.2S, 37.9W) Camp", "Lone Lands: Candaith's Encampment (30.1S, 37.9W) Stable", 2);
NewEdge("Lone Lands: The Forsakken Inn (34.4S, 40.6W) Stable", "Lone Lands: Candaith's Encampment (30.2S, 37.9W) Camp", 3);
NewNode("Lone Lands: Garth Agarwen, The Outer Gates (28.0S, 25.2W) Camp/Horn");
NewEdge("Lone Lands: Ost Guruth (32.1S, 29.8W) Stable", "Lone Lands: Garth Agarwen, The Outer Gates (28.0S, 25.2W) Camp/Horn", 3);
NewNode("Lone Lands: Minas Eriol (36.0S, 39.5W) Camp");
NewEdge("Lone Lands: The Forsakken Inn (34.4S, 40.6W) Stable", "Lone Lands: Minas Eriol (36.0S, 39.5W) Camp", 3);
NewNode("Lone Lands: Ost Haer (37.6S, 28.0W) Camp");
NewEdge("Lone Lands: Ost Guruth (32.1S, 29.8W) Stable", "Lone Lands: Ost Haer (37.6S, 28.0W) Camp", 3);
-- Lonelands Milestones
NewNode("Lone Lands: Ost Guruth (31.5S, 29.5W) Milestone");
NewEdge("Lone Lands: Ost Guruth (32.1S, 29.8W) Stable", "Lone Lands: Ost Guruth (31.5S, 29.5W) Milestone", 3);
NewNode("Lone Lands: The Forsaken Inn (34.1S, 40.7W) Milestone");
NewEdge("Lone Lands: The Forsakken Inn (34.4S, 40.6W) Stable", "Lone Lands: The Forsaken Inn (34.1S, 40.7W) Milestone", 3);

-- Lothlorien Nodes & Paths
NewNode("Lothlorien: Boat To Mirkwood (17.7S, 64.6W) Boat");
NewNode("Lothlorien: Caras Galadhon (16.8S, 67.5W) Stable");
NewNode("Lothlorien: Cerin Amroth (11.8S, 69.1W) Stable");
NewNode("Lothlorien: Echad Andestel (14.4S, 73.1W) Stable");
NewNode("Lothlorien: Inner Caras Galadhon (15.1S, 68.2W) Stable");
NewNode("Lothlorien: Inner Caras Galadhon Gate (16.1S, 66.9W)");
NewNode("Lothlorien: Mekhem-bizru (11.5S, 67.6W) Stable");
NewNode("Lothlorien: The Vinyards of Lorien (18.3, 64.2W) Stable");
NewNode("Lothlorien to Moria Exit (6.7S, 79.7W)");
NewEdge("Lothlorien: Boat To Mirkwood (17.7S, 64.6W) Boat", "Mirkwood: Boat To Lothlorien (14.9S, 61.8W) Boat", 1);
NewEdge("Lothlorien: Caras Galadhon (16.8S, 67.5W) Stable", "Lothlorien: Inner Caras Galadhon Gate (16.1S, 66.9W)", 1);
NewEdge("Lothlorien: Caras Galadhon (16.8S, 67.5W) Stable", "Lothlorien: Boat To Mirkwood (17.7S, 64.6W) Boat", 1);
NewEdge("Lothlorien: Caras Galadhon (16.8S, 67.5W) Stable", "Lothlorien: Cerin Amroth (11.8S, 69.1W) Stable", 1);
NewEdge("Lothlorien: Caras Galadhon (16.8S, 67.5W) Stable", "Lothlorien: Echad Andestel (14.4S, 73.1W) Stable", 1);
NewEdge("Lothlorien: Caras Galadhon (16.8S, 67.5W) Stable", "Lothlorien: Mekhem-bizru (11.5S, 67.6W) Stable", 1);
NewEdge("Lothlorien: Caras Galadhon (16.8S, 67.5W) Stable", "Lothlorien: The Vinyards of Lorien (18.3, 64.2W) Stable", 1);
NewEdge("Lothlorien: Cerin Amroth (11.8S, 69.1W) Stable", "Lothlorien: Caras Galadhon (16.8S, 67.5W) Stable", 1);
NewEdge("Lothlorien: Cerin Amroth (11.8S, 69.1W) Stable", "Lothlorien: Echad Andestel (14.4S, 73.1W) Stable", 1);
NewEdge("Lothlorien: Cerin Amroth (11.8S, 69.1W) Stable", "Lothlorien: Mekhem-bizru (11.5S, 67.6W) Stable", 1);
NewEdge("Lothlorien: Cerin Amroth (11.8S, 69.1W) Stable", "Lothlorien: The Vinyards of Lorien (18.3, 64.2W) Stable", 1);
NewEdge("Lothlorien: Echad Andestel (14.4S, 73.1W) Stable", "Lothlorien: Caras Galadhon (16.8S, 67.5W) Stable", 1);
NewEdge("Lothlorien: Echad Andestel (14.4S, 73.1W) Stable", "Lothlorien: Cerin Amroth (11.8S, 69.1W) Stable", 1);
NewEdge("Lothlorien: Echad Andestel (14.4S, 73.1W) Stable", "Lothlorien: Mekhem-bizru (11.5S, 67.6W) Stable", 1);
NewEdge("Lothlorien: Echad Andestel (14.4S, 73.1W) Stable", "Lothlorien: The Vinyards of Lorien (18.3, 64.2W) Stable", 1);
NewEdge("Lothlorien: Inner Caras Galadhon (15.1S, 68.2W) Stable", "Dunland: Galtrev (80.0S, 16.7W) Stable", 1);
NewEdge("Lothlorien: Inner Caras Galadhon (15.1S, 68.2W) Stable", "Lothlorien: Inner Caras Galadhon Gate (16.1S, 66.9W)", 1);
NewEdge("Lothlorien: Inner Caras Galadhon (15.1S, 68.2W) Stable", "Enedwaith: Lhanuch (66.9S, 16.9W) Stable", 1);
NewEdge("Lothlorien: Inner Caras Galadhon (15.1S, 68.2W) Stable", "Mirkwood: Ost Galadh (14.3S, 51.2W) Stable", 1);
NewEdge("Lothlorien: Inner Caras Galadhon (15.1S, 68.2W) Stable", "Trollshaws: Rivendell (29.3S, 6.4W) Stable", 1);
NewEdge("Lothlorien: Inner Caras Galadhon (15.1S, 68.2W) Stable", "Great River: Stangard (25.6W, 63.5W) Stable", 1);
NewEdge("Lothlorien: Inner Caras Galadhon (15.1S, 68.2W) Stable", "Moria: Twenty-first Hall (5.7S, 105.3W) Stable", 1);
NewEdge("Lothlorien: Mekhem-bizru (11.5S, 67.6W) Stable", "Lothlorien: Caras Galadhon (16.8S, 67.5W) Stable", 1);
NewEdge("Lothlorien: Mekhem-bizru (11.5S, 67.6W) Stable", "Lothlorien: Cerin Amroth (11.8S, 69.1W) Stable", 1);
NewEdge("Lothlorien: Mekhem-bizru (11.5S, 67.6W) Stable", "Lothlorien: Echad Andestel (14.4S, 73.1W) Stable", 1);
NewEdge("Lothlorien: Mekhem-bizru (11.5S, 67.6W) Stable", "Lothlorien to Moria Exit (6.7S, 79.7W)", 1);
NewEdge("Lothlorien: Mekhem-bizru (11.5S, 67.6W) Stable", "Lothlorien: The Vinyards of Lorien (18.3, 64.2W) Stable", 1);
NewEdge("Lothlorien: The Vinyards of Lorien (18.3, 64.2W) Stable", "Lothlorien: Boat To Mirkwood (17.7S, 64.6W) Boat", 1);
NewEdge("Lothlorien: The Vinyards of Lorien (18.3, 64.2W) Stable", "Lothlorien: Caras Galadhon (16.8S, 67.5W) Stable", 1);
NewEdge("Lothlorien: The Vinyards of Lorien (18.3, 64.2W) Stable", "Lothlorien: Cerin Amroth (11.8S, 69.1W) Stable", 1);
NewEdge("Lothlorien: The Vinyards of Lorien (18.3, 64.2W) Stable", "Lothlorien: Echad Andestel (14.4S, 73.1W) Stable", 1);
NewEdge("Lothlorien: The Vinyards of Lorien (18.3, 64.2W) Stable", "Lothlorien: Mekhem-bizru (11.5S, 67.6W) Stable", 1);
NewEdge("Lothlorien: The Vinyards of Lorien (18.3, 64.2W) Stable", "Great River: Thinglad (21.4S, 63.4W) Stable", 1);
-- Lothlorien Campsites & Horns
NewNode("Lothlorien: Taur Hith (11.4S, 70.6W) Camp");
NewEdge("Lothlorien: Cerin Amroth (11.8S, 69.1W) Stable", "Lothlorien: Taur Hith (11.4S, 70.6W) Camp", 3);
-- Lothlorien Milestones
NewNode("Lothlorien: Caras Galadhon (15.7S, 67.9W) Milestone");
NewEdge("Lothlorien: Caras Galadhon (16.8S, 67.5W) Stable", "Lothlorien: Caras Galadhon (15.7S, 67.9W) Milestone", 3);
NewNode("Lothlorien: Echad Andestel (14.2S, 73.1W) Milestone");
NewEdge("Lothlorien: Echad Andestel (14.4S, 73.1W) Stable", "Lothlorien: Echad Andestel (14.2S, 73.1W) Milestone", 3);
NewNode("Lothlorien: Mekhm-bizru (11.5S, 78.4W) Milestone");
NewEdge("Lothlorien: Mekhem-bizru (11.5S, 67.6W) Stable", "Lothlorien: Mekhm-bizru (11.5S, 78.4W) Milestone", 3);
NewNode("Lothlorien: The Vinyards of Lorien (17.3S, 64.1W) Milestone");
NewEdge("Lothlorien: The Vinyards of Lorien (18.3, 64.2W) Stable", "Lothlorien: The Vinyards of Lorien (17.3S, 64.1W) Milestone", 3);

-- Mirkwood Nodes & Paths
NewNode("Mirkwood: Boat To Lothlorien (14.9S, 61.8W) Boat");
NewNode("Mirkwood: Echad Sirion (15.3S, 61.3W) Stable");
NewNode("Mirkwood: Estolad Mernael (16.8S, 54.5W) Stable");
NewNode("Mirkwood: Helethir (16.1S, 44.5W) Stable");
NewNode("Mirkwood: Mithechad (17.6W, 48.3W) Stable");
NewNode("Mirkwood: Ost Galadh (14.3S, 51.2W) Stable");
NewNode("Mirkwood: The Haunted Inn (13.5S, 56.2W) Stable");
NewNode("Mirkwood: Thangulhad (12.8S, 46.1W) Stable");
NewNode("Mirkwood: Ruins of Dol Guldur (12.7S, 15.1W) Horse");
NewEdge("Eryn Lasgalen: Ruins of Dol Guldur (12.1N, 46.1W) Horse", "Mirkwood: Ruins of Dol Guldur (12.7S, 15.1W) Horse", 3);
NewEdge("Mirkwood: Boat To Lothlorien (14.9S, 61.8W) Boat", "Mirkwood: Echad Sirion (15.3S, 61.3W) Stable", 1);
NewEdge("Mirkwood: Echad Sirion (15.3S, 61.3W) Stable", "Mirkwood: Boat To Lothlorien (14.9S, 61.8W) Boat", 1);
NewEdge("Mirkwood: Echad Sirion (15.3S, 61.3W) Stable", "Mirkwood: Estolad Mernael (16.8S, 54.5W) Stable", 1);
NewEdge("Mirkwood: Echad Sirion (15.3S, 61.3W) Stable", "Mirkwood: Helethir (16.1S, 44.5W) Stable", 1);
NewEdge("Mirkwood: Echad Sirion (15.3S, 61.3W) Stable", "Mirkwood: Mithechad (17.6W, 48.3W) Stable", 1);
NewEdge("Mirkwood: Echad Sirion (15.3S, 61.3W) Stable", "Mirkwood: Ost Galadh (14.3S, 51.2W) Stable", 1);
NewEdge("Mirkwood: Echad Sirion (15.3S, 61.3W) Stable", "Mirkwood: The Haunted Inn (13.5S, 56.2W) Stable", 1);
NewEdge("Mirkwood: Echad Sirion (15.3S, 61.3W) Stable", "Mirkwood: Thangulhad (12.8S, 46.1W) Stable", 1);
NewEdge("Mirkwood: Estolad Mernael (16.8S, 54.5W) Stable", "Mirkwood: Echad Sirion (15.3S, 61.3W) Stable", 1);
NewEdge("Mirkwood: Estolad Mernael (16.8S, 54.5W) Stable", "Mirkwood: Helethir (16.1S, 44.5W) Stable", 1);
NewEdge("Mirkwood: Estolad Mernael (16.8S, 54.5W) Stable", "Mirkwood: Mithechad (17.6W, 48.3W) Stable", 1);
NewEdge("Mirkwood: Estolad Mernael (16.8S, 54.5W) Stable", "Mirkwood: Ost Galadh (14.3S, 51.2W) Stable", 1);
NewEdge("Mirkwood: Estolad Mernael (16.8S, 54.5W) Stable", "Mirkwood: Thangulhad (12.8S, 46.1W) Stable", 1);
NewEdge("Mirkwood: Estolad Mernael (16.8S, 54.5W) Stable", "Mirkwood: The Haunted Inn (13.5S, 56.2W) Stable", 1);
NewEdge("Mirkwood: Helethir (16.1S, 44.5W) Stable", "Mirkwood: Echad Sirion (15.3S, 61.3W) Stable", 1);
NewEdge("Mirkwood: Helethir (16.1S, 44.5W) Stable", "Mirkwood: Estolad Mernael (16.8S, 54.5W) Stable", 1);
NewEdge("Mirkwood: Helethir (16.1S, 44.5W) Stable", "Mirkwood: Mithechad (17.6W, 48.3W) Stable", 1);
NewEdge("Mirkwood: Helethir (16.1S, 44.5W) Stable", "Mirkwood: Ost Galadh (14.3S, 51.2W) Stable", 1);
NewEdge("Mirkwood: Helethir (16.1S, 44.5W) Stable", "Mirkwood: Thangulhad (12.8S, 46.1W) Stable", 1);
NewEdge("Mirkwood: Helethir (16.1S, 44.5W) Stable", "Mirkwood: The Haunted Inn (13.5S, 56.2W) Stable", 1);
NewEdge("Mirkwood: Mithechad (17.6W, 48.3W) Stable", "Mirkwood: Echad Sirion (15.3S, 61.3W) Stable", 1);
NewEdge("Mirkwood: Mithechad (17.6W, 48.3W) Stable", "Mirkwood: Estolad Mernael (16.8S, 54.5W) Stable", 1);
NewEdge("Mirkwood: Mithechad (17.6W, 48.3W) Stable", "Mirkwood: Helethir (16.1S, 44.5W) Stable", 1);
NewEdge("Mirkwood: Mithechad (17.6W, 48.3W) Stable", "Mirkwood: Ost Galadh (14.3S, 51.2W) Stable", 1);
NewEdge("Mirkwood: Mithechad (17.6W, 48.3W) Stable", "Mirkwood: Thangulhad (12.8S, 46.1W) Stable", 1);
NewEdge("Mirkwood: Mithechad (17.6W, 48.3W) Stable", "Mirkwood: The Haunted Inn (13.5S, 56.2W) Stable", 1);
NewEdge("Mirkwood: Ost Galadh (14.3S, 51.2W) Stable", "Eryn Lasgalen: Tham Taerdol (12.1N, 46.1W) Stable", 1);
NewEdge("Mirkwood: Ost Galadh (14.3S, 51.2W) Stable", "Mirkwood: Echad Sirion (15.3S, 61.3W) Stable", 1);
NewEdge("Mirkwood: Ost Galadh (14.3S, 51.2W) Stable", "Mirkwood: Estolad Mernael (16.8S, 54.5W) Stable", 1);
NewEdge("Mirkwood: Ost Galadh (14.3S, 51.2W) Stable", "Lothlorien: Inner Caras Galadhon (15.1S, 68.2W) Stable", 1);
NewEdge("Mirkwood: Ost Galadh (14.3S, 51.2W) Stable", "Mirkwood: Mithechad (17.6W, 48.3W) Stable", 1);
NewEdge("Mirkwood: Ost Galadh (14.3S, 51.2W) Stable", "Mirkwood: Thangulhad (12.8S, 46.1W) Stable", 1);
NewEdge("Mirkwood: Ost Galadh (14.3S, 51.2W) Stable", "Mirkwood: The Haunted Inn (13.5S, 56.2W) Stable", 1);
NewEdge("Mirkwood: Thangulhad (12.8S, 46.1W) Stable", "Eryn Lasgalen: Tham Taerdol (12.1N, 46.1W) Stable", 1);
NewEdge("Mirkwood: Thangulhad (12.8S, 46.1W) Stable", "Mirkwood: Echad Sirion (15.3S, 61.3W) Stable", 1);
NewEdge("Mirkwood: Thangulhad (12.8S, 46.1W) Stable", "Mirkwood: Estolad Mernael (16.8S, 54.5W) Stable", 1);
NewEdge("Mirkwood: Thangulhad (12.8S, 46.1W) Stable", "Mirkwood: Helethir (16.1S, 44.5W) Stable", 1);
NewEdge("Mirkwood: Thangulhad (12.8S, 46.1W) Stable", "Mirkwood: Mithechad (17.6W, 48.3W) Stable", 1);
NewEdge("Mirkwood: Thangulhad (12.8S, 46.1W) Stable", "Mirkwood: Ost Galadh (14.3S, 51.2W) Stable", 1);
NewEdge("Mirkwood: Thangulhad (12.8S, 46.1W) Stable", "Mirkwood: The Haunted Inn (13.5S, 56.2W) Stable", 1);
NewEdge("Mirkwood: The Haunted Inn (13.5S, 56.2W) Stable", "Mirkwood: Echad Sirion (15.3S, 61.3W) Stable", 1);
NewEdge("Mirkwood: The Haunted Inn (13.5S, 56.2W) Stable", "Mirkwood: Estolad Mernael (16.8S, 54.5W) Stable", 1);
NewEdge("Mirkwood: The Haunted Inn (13.5S, 56.2W) Stable", "Mirkwood: Helethir (16.1S, 44.5W) Stable", 1);
NewEdge("Mirkwood: The Haunted Inn (13.5S, 56.2W) Stable", "Mirkwood: Mithechad (17.6W, 48.3W) Stable", 1);
NewEdge("Mirkwood: The Haunted Inn (13.5S, 56.2W) Stable", "Mirkwood: Ost Galadh (14.3S, 51.2W) Stable", 1);
NewEdge("Mirkwood: The Haunted Inn (13.5S, 56.2W) Stable", "Mirkwood: Thangulhad (12.8S, 46.1W) Stable", 1);
-- Mirkwood Campsite Nodes
NewNode("Mirkwood: Echad Mothelan (13.6S, 58.1W) Camp/Horn");
NewEdge("Mirkwood: The Haunted Inn (13.5S, 56.2W) Stable", "Mirkwood: Echad Mothelan (13.6S, 58.1W) Camp/Horn", 3);
NewNode("Mirkwood: Helethir (16.2S, 44.5W) Camp/Horn");
NewEdge("Mirkwood: Helethir (16.1S, 44.5W) Stable", "Mirkwood: Helethir (16.2S, 44.5W) Camp/Horn", 3);
NewNode("Mirkwood: Thangulhad (12.6S, 46.5W) Camp");
NewEdge("Mirkwood: Thangulhad (12.8S, 46.1W) Stable", "Mirkwood: Thangulhad (12.6S, 46.5W) Camp", 3);
-- Mirkwood Milestones
NewNode("Mirkwood: Estolad Mernael (17.0S, 55.0W) Milestone");
NewEdge("Mirkwood: Estolad Mernael (16.8S, 54.5W) Stable", "Mirkwood: Estolad Mernael (17.0S, 55.0W) Milestone", 3);
NewNode("Mirkwood: Mirk-eaves (15.3S, 61.2W) Milestone");
NewEdge("Mirkwood: Echad Sirion (15.3S, 61.3W) Stable", "Mirkwood: Mirk-eaves (15.3S, 61.2W) Milestone", 3);
NewNode("Mirkwood: Mithechad (17.6S, 48.2W) Milestone");
NewEdge("Mirkwood: Mithechad (17.6W, 48.3W) Stable", "Mirkwood: Mithechad (17.6S, 48.2W) Milestone", 3);
NewNode("Mirkwood: Ost Galadh (14.3S, 51.2) Milestone");
NewEdge("Mirkwood: Ost Galadh (14.3S, 51.2W) Stable", "Mirkwood: Ost Galadh (14.3S, 51.2) Milestone", 3);
NewNode("Mirkwood: Thangulhad (12.9S, 46.3W) Milestone");
NewEdge("Mirkwood: Thangulhad (12.8S, 46.1W) Stable", "Mirkwood: Thangulhad (12.9S, 46.3W) Milestone", 3);
NewNode("Mirkwood: The Haunted Inn (13.4S, 56.1W) Milestone");
NewEdge("Mirkwood: The Haunted Inn (13.5S, 56.2W) Stable", "Mirkwood: The Haunted Inn (13.4S, 56.1W) Milestone", 3);

-- Misty Mountains Nodes & Paths
NewNode("Misty Mountains: Gloin's Camp (24.9S, 4.0W) Stable");
NewEdge("Misty Mountains: Gloin's Camp (24.9S, 4.0W) Stable", "Misty Mountains: High Crag (24.6S, 1.3E) Stable", 1);
NewEdge("Misty Mountains: Gloin's Camp (24.9S, 4.0W) Stable", "Misty Mountains: Hrimbarg (24.4S, 7.0E) Stable", 1);
NewEdge("Misty Mountains: Gloin's Camp (24.9S, 4.0W) Stable", "Misty Mountains: Vindurhal (23.3S, 4.3E) Stable", 1);
NewEdge("Misty Mountains: Gloin's Camp (24.9S, 4.0W) Stable", "Trollshaws: Rivendell (29.3S, 6.4W) Stable", 1);
NewEdge("Misty Mountains: Gloin's Camp (24.9S, 4.0W) Stable", "Trollshaws: Rivendell (29.3S, 6.4W) Stable", 2);
NewNode("Misty Mountains: Hrimbarg (24.4S, 7.0E) Stable");
NewEdge("Misty Mountains: Hrimbarg (24.4S, 7.0E) Stable", "Misty Mountains: Gloin's Camp (24.9S, 4.0W) Stable", 1);
NewEdge("Misty Mountains: Hrimbarg (24.4S, 7.0E) Stable", "Misty Mountains: High Crag (24.6S, 1.3E) Stable", 1);
NewEdge("Misty Mountains: Hrimbarg (24.4S, 7.0E) Stable", "Misty Mountains: Vindurhal (23.3S, 4.3E) Stable", 1);
NewEdge("Misty Mountains: Hrimbarg (24.4S, 7.0E) Stable", "Trollshaws: Rivendell (29.3S, 6.4W) Stable", 1);
NewNode("Misty Mountains: High Crag (24.6S, 1.3E) Stable");
NewEdge("Misty Mountains: High Crag (24.6S, 1.3E) Stable", "Misty Mountains: Gloin's Camp (24.9S, 4.0W) Stable", 1);
NewEdge("Misty Mountains: High Crag (24.6S, 1.3E) Stable", "Misty Mountains: Hrimbarg (24.4S, 7.0E) Stable", 1);
NewEdge("Misty Mountains: High Crag (24.6S, 1.3E) Stable", "Misty Mountains: Vindurhal (23.3S, 4.3E) Stable", 1);
NewNode("Misty Mountains: Vindurhal (23.3S, 4.3E) Stable");
NewEdge("Misty Mountains: Vindurhal (23.3S, 4.3E) Stable", "Misty Mountains: Gloin's Camp (24.9S, 4.0W) Stable", 1);
NewEdge("Misty Mountains: Vindurhal (23.3S, 4.3E) Stable", "Misty Mountains: High Crag (24.6S, 1.3E) Stable", 1);
NewEdge("Misty Mountains: Vindurhal (23.3S, 4.3E) Stable", "Misty Mountains: Hrimbarg (24.4S, 7.0E) Stable", 1);

-- Misty Mountains Campsites & Horns
NewNode("Misty Mountains: Bruinen Source East (22.8S, 0.7E) Camp");
NewEdge("Misty Mountains: Gloin's Camp (24.9S, 4.0W) Stable", "Misty Mountains: Bruinen Source East (22.8S, 0.7E) Camp", 3);
NewNode("Misty Mountains: Bruinen Source North (19.1S, 2.9W) Camp/Horn");
NewEdge("Misty Mountains: Gloin's Camp (24.9S, 4.0W) Stable", "Misty Mountains: Bruinen Source North (19.1S, 2.9W) Camp/Horn", 3);
NewNode("Misty Mountains: Giant Halls (29.9S, 2.4E) Camp/Horn");
NewEdge("Misty Mountains: Hrimbarg (24.4S, 7.0E) Stable", "Misty Mountains: Giant Halls (29.9S, 2.4E) Camp/Horn", 3);
NewNode("Misty Mountains: Northern High Pass (21.4S, 5.9E) Camp/Horn");
NewEdge("Misty Mountains: Hrimbarg (24.4S, 7.0E) Stable", "Misty Mountains: Northern High Pass (21.4S, 5.9E) Camp/Horn", 3);
NewNode("Misty Mountains: Northern High Pass (21.4S, 5.9E) Camp");
NewEdge("Misty Mountains: Hrimbarg (24.4S, 7.0E) Stable", "Misty Mountains: Northern High Pass (21.4S, 5.9E) Camp", 3);
NewNode("Misty Mountains: Southern High Pass (27.8S, 7.6E) Camp");
NewEdge("Misty Mountains: Hrimbarg (24.4S, 7.0E) Stable", "Misty Mountains: Southern High Pass (27.8S, 7.6E) Camp", 3);

-- Misty Mountains Milestones
NewNode("Misty Mountains: Gloin's Camp (24.9S, 4.0W) Milestone");
NewEdge("Misty Mountains: Gloin's Camp (24.9S, 4.0W) Stable", "Misty Mountains: Gloin's Camp (24.9S, 4.0W) Milestone", 3);
NewNode("Misty Mountains: Vindurhal (23.3S, 4.3E) Milestone");
NewEdge("Misty Mountains: Vindurhal (23.3S, 4.3E) Stable", "Misty Mountains: Vindurhal (23.3S, 4.3E) Milestone", 3);

-- Mordor Nodes & Paths
NewNode("Mordor: Agarnaith Ranger Camp (56.6S, 26.9E) Stable");
NewNode("Mordor: Agarnaith Ranger Camp (56.5S, 27.0E) Milestone");
NewNode("Mordor: Anglach (39.8S, 5.8E) Camp");
NewNode("Mordor: Barad Angarth, The Wardens Keep (65.5S, 0.7E) Gate");
NewNode("Mordor: Barad Arthir, The Lofty Watch-Fort (67.4S, 1.2E) Gate");
NewNode("Mordor: Barad Elenath, The Star Gazers Spire (66.8S, 0.9E) Gate");
NewNode("Mordor: Barad Orphant, The Tower of the Treegarth (66.4S, 0.6E) Gate");
NewNode("Mordor: Bhol Rudh (54.5S, 32.1E) Milestone");
NewNode("Mordor: Cirith Ungol (617S, 10.5E) Milestone");
NewNode("Mordor: Dath Nethryn (64.2S, 10.7E) Camp");
NewNode("Mordor: Dor Amarth (43.6S, 15.7E) Camp");
NewNode("Mordor: Durthang (49.0S, 2.2E) Camp");
NewNode("Mordor: Echad Taerdim (61.9S, 0.4W) Camp");
NewNode("Mordor: Echad Taerdim (61.9S, 0.4W) Stable");
NewNode("Mordor: Echad Teardim (61.9S, 0.5W) Milestone");
NewNode("Mordor: Estolad Lan (64.5S, 2.2W) Stable");
NewNode("Mordor: Estolad Lan (64.5S, 2.2W) Milestone");
NewNode("Mordor: Echad Uial (65.1S, 4.1E) Milestone");
NewNode("Mordor: Echad Uial (65.1S, 4.2E) Stable");
NewNode("Mordor: Grishbalt (52.0S, 28.1E) Camp");
NewNode("Mordor: Lughash (43.6S, 15.7E) Camp");
NewNode("Mordor: Kala-Murg (50.7S, 6.3E) Milestone");
NewNode("Mordor: Magh Ashtu (53.1S, 10.5E) Stable");
NewNode("Mordor: Magh Ashtu (53.1S, 10.7E) Milestone");
NewNode("Mordor: Minas Morgul (65.4S, 0.7E) Camp");
NewNode("Mordor: Minas Morgul (65.4S, 0.7E) Milestone");
NewNode("Mordor: Minas Morgul (65.4S, 0.7E) Stable");
NewNode("Mordor: Naerband (60.9S, 16.7E) Camp");
NewNode("Mordor: Nargroth (59.9S, 24.2E) Camp");
NewNode("Mordor: Rath Cail (49.7S, 5.9E) Milestone");
NewNode("Mordor: Ruins of Dingarth (48.0S, 8.7E) Stable");
NewNode("Mordor: Ruins of Dingarth (48.1S, 8.6E) Milestone");
NewNode("Mordor: Taen Orwath (66.9S, 5.8E) Stable");
NewNode("Mordor: Taen Orwath (66.9S, 5.8E) Camp");
NewNode("Mordor: Taen Orwath (66.9S, 5.8E) Milestone");
NewNode("Mordor: Talath Urui (59.5S, 24.2E) Milestone");
NewNode("Mordor: Udun Foothold (41.2S, 0.5W) Stable");
NewNode("Mordor: Udun Foothold (41.2S, 0.6W) Milestone");
NewEdge("Mordor: Agarnaith Ranger Camp (56.6S, 26.9E) Stable", "Mordor: Grishbalt (52.0S, 28.1E) Camp", 3);
NewEdge("Mordor: Agarnaith Ranger Camp (56.6S, 26.9E) Stable", "Mordor: Agarnaith Ranger Camp (56.5S, 27.0E) Milestone", 3);
NewEdge("Mordor: Agarnaith Ranger Camp (56.6S, 26.9E) Stable", "Mordor: Bhol Rudh (54.5S, 32.1E) Milestone", 3);
NewEdge("Mordor: Agarnaith Ranger Camp (56.6S, 26.9E) Stable", "Mordor: Talath Urui (59.5S, 24.2E) Milestone", 3);
NewEdge("Mordor: Agarnaith Ranger Camp (56.6S, 26.9E) Stable", "Mordor: Nargroth (59.9S, 24.2E) Camp", 3);
NewEdge("Mordor: Barad Angarth, The Wardens Keep (65.5S, 0.7E) Gate", "Mordor: Minas Morgul (65.4S, 0.7E) Stable", 3); 
NewEdge("Mordor: Barad Angarth, The Wardens Keep (65.5S, 0.7E) Gate", "Mordor: Barad Arthir, The Lofty Watch-Fort (67.4S, 1.2E) Gate", 3);
NewEdge("Mordor: Barad Angarth, The Wardens Keep (65.5S, 0.7E) Gate", "Mordor: Barad Elenath, The Star Gazers Spire (66.8S, 0.9E) Gate",3);
NewEdge("Mordor: Barad Angarth, The Wardens Keep (65.5S, 0.7E) Gate", "Mordor: Barad Orphant, The Tower of the Treegarth (66.4S, 0.6E) Gate", 3);
NewEdge("Mordor: Echad Taerdim (61.9S, 0.4W) Camp", "Mordor: Echad Taerdim (61.9S, 0.4W) Stable", 3);
NewEdge("Mordor: Echad Taerdim (61.9S, 0.4W) Stable", "Mordor: Estolad Lan (64.5S, 2.2W) Stable", 1);
NewEdge("Mordor: Echad Taerdim (61.9S, 0.4W) Stable", "Mordor: Estolad Lan (64.5S, 2.2W) Stable", 2);
NewEdge("Mordor: Echad Teardim (61.9S, 0.5W) Milestone", "Mordor: Echad Taerdim (61.9S, 0.4W) Stable", 3);
NewEdge("Mordor: Echad Uial (65.1S, 4.1E) Milestone", "Mordor: Echad Uial (65.1S, 4.2E) Stable", 3);
NewEdge("Mordor: Echad Uial (65.1S, 4.2E) Stable", "Mordor: Echad Taerdim (61.9S, 0.4W) Stable", 1);
NewEdge("Mordor: Echad Uial (65.1S, 4.2E) Stable", "Mordor: Echad Taerdim (61.9S, 0.4W) Stable", 2);
NewEdge("Mordor: Echad Uial (65.1S, 4.2E) Stable", "Mordor: Estolad Lan (64.5S, 2.2W) Stable", 1);
NewEdge("Mordor: Echad Uial (65.1S, 4.2E) Stable", "Mordor: Estolad Lan (64.5S, 2.2W) Stable", 2);
NewEdge("Mordor: Echad Uial (65.1S, 4.2E) Stable", "Mordor: Magh Ashtu (53.1S, 10.5E) Stable", 1);
NewEdge("Mordor: Echad Uial (65.1S, 4.2E) Stable", "Mordor: Magh Ashtu (53.1S, 10.5E) Stable", 2);
NewEdge("Mordor: Echad Uial (65.1S, 4.2E) Stable", "Mordor: Minas Morgul (65.4S, 0.7E) Stable", 1);
NewEdge("Mordor: Echad Uial (65.1S, 4.2E) Stable", "Mordor: Minas Morgul (65.4S, 0.7E) Stable", 2);
NewEdge("Mordor: Estolad Lan (64.5S, 2.2W) Stable", "Anorien After Battle: Osgiliath (63.0S, 6.5W) Stable", 1); 
NewEdge("Mordor: Estolad Lan (64.5S, 2.2W) Stable", "Anorien After Battle: Osgiliath (63.0S, 6.5W) Stable", 2); 
NewEdge("Mordor: Estolad Lan (64.5S, 2.2W) Milestone", "Mordor: Estolad Lan (64.5S, 2.2W) Stable", 3);
NewEdge("Mordor: Estolad Lan (64.5S, 2.2W) Stable", "North Ithilien: Henneth Annun (48.4S, 6.9W) Stable", 1);
NewEdge("Mordor: Estolad Lan (64.5S, 2.2W) Stable", "North Ithilien: Henneth Annun (48.4S, 6.9W) Stable", 2);
NewEdge("Mordor: Estolad Lan (64.5S, 2.2W) Stable", "Mordor: Echad Taerdim (61.9S, 0.4W) Stable", 1);
NewEdge("Mordor: Estolad Lan (64.5S, 2.2W) Stable", "Mordor: Echad Taerdim (61.9S, 0.4W) Stable", 2);
NewEdge("Mordor: Estolad Lan (64.5S, 2.2W) Stable", "Mordor: Echad Uial (65.1S, 4.2E) Stable", 1);
NewEdge("Mordor: Estolad Lan (64.5S, 2.2W) Stable", "Mordor: Echad Uial (65.1S, 4.2E) Stable", 2);
NewEdge("Mordor: Estolad Lan (64.5S, 2.2W) Stable", "Mordor: Magh Ashtu (53.1S, 10.5E) Stable", 1);
NewEdge("Mordor: Estolad Lan (64.5S, 2.2W) Stable", "Mordor: Minas Morgul (65.4S, 0.7E) Stable", 1);
NewEdge("Mordor: Estolad Lan (64.5S, 2.2W) Stable", "Mordor: Minas Morgul (65.4S, 0.7E) Stable", 2);
NewEdge("Mordor: Estolad Lan (64.5S, 2.2W) Stable", "Mordor: Taen Orwath (66.9S, 5.8E) Stable", 1);
NewEdge("Mordor: Estolad Lan (64.5S, 2.2W) Stable", "Mordor: Taen Orwath (66.9S, 5.8E) Stable", 2);
NewEdge("Mordor: Estolad Lan (64.5S, 2.2W) Stable", "Vales of Anduin: Hultvis (5.4N, 54.6W) Stable", 1);
NewEdge("Mordor: Magh Ashtu (53.1S, 10.5E) Stable", "Mordor: Naerband (60.9S, 16.7E) Camp", 3);
NewEdge("Mordor: Magh Ashtu (53.1S, 10.5E) Stable", "Mordor: Cirith Ungol (617S, 10.5E) Milestone", 3);
NewEdge("Mordor: Magh Ashtu (53.1S, 10.5E) Stable", "Mordor: Magh Ashtu (53.1S, 10.7E) Milestone", 3);
NewEdge("Mordor: Magh Ashtu (53.1S, 10.5E) Stable", "Mordor: Udun Foothold (41.2S, 0.5W) Stable", 1);
NewEdge("Mordor: Magh Ashtu (53.1S, 10.5E) Stable", "Mordor: Udun Foothold (41.2S, 0.5W) Stable", 2);
NewEdge("Mordor: Magh Ashtu (53.1S, 10.5E) Stable", "Mordor: Ruins of Dingarth (48.0S, 8.7E) Stable", 1);
NewEdge("Mordor: Magh Ashtu (53.1S, 10.5E) Stable", "Mordor: Ruins of Dingarth (48.0S, 8.7E) Stable", 2);
NewEdge("Mordor: Magh Ashtu (53.1S, 10.5E) Stable", "Mordor: Agarnaith Ranger Camp (56.6S, 26.9E) Stable", 1);
NewEdge("Mordor: Magh Ashtu (53.1S, 10.5E) Stable", "Mordor: Agarnaith Ranger Camp (56.6S, 26.9E) Stable", 2);
NewEdge("Mordor: Magh Ashtu (53.1S, 10.5E) Stable", "Old Anorien: Minas Tirith Main Gate (65.8S, 16.8W) Stable", 1);
NewEdge("Mordor: Magh Ashtu (53.1S, 10.5E) Stable", "West Rohan: Aldburg (68.7S, 63.9W) Stable", 2);
NewEdge("Mordor: Magh Ashtu (53.1S, 10.5E) Stable", "Western Gondor: Dol Amroth (75.5S, 72.5W) Stable", 2);
NewEdge("Mordor: Magh Ashtu (53.1S, 10.5E) Stable", "Bree-land: South Bree (31.9S, 50.4W) Stable", 2);
NewEdge("Mordor: Magh Ashtu (53.1S, 10.5E) Stable", "Dunland: Galtrev (80.0S, 16.7W) Stable", 2);
NewEdge("Mordor: Magh Ashtu (53.1S, 10.5E) Stable", "Moria: Twenty-first Hall (5.7S, 105.3W) Stable", 2);
NewEdge("Mordor: Magh Ashtu (53.1S, 10.5E) Stable", "Mordor: Dath Nethryn (64.2S, 10.7E) Camp", 3);
NewEdge("Mordor: Minas Morgul (65.4S, 0.7E) Stable", "Mordor: Echad Taerdim (61.9S, 0.4W) Stable", 1);
NewEdge("Mordor: Minas Morgul (65.4S, 0.7E) Stable", "Mordor: Echad Taerdim (61.9S, 0.4W) Stable", 2);
NewEdge("Mordor: Minas Morgul (65.4S, 0.7E) Stable", "Mordor: Estolad Lan (64.5S, 2.2W) Stable", 1);
NewEdge("Mordor: Minas Morgul (65.4S, 0.7E) Stable", "Mordor: Estolad Lan (64.5S, 2.2W) Stable", 2);
NewEdge("Mordor: Minas Morgul (65.4S, 0.7E) Milestone", "Mordor: Minas Morgul (65.4S, 0.7E) Stable", 3);
NewEdge("Mordor: Minas Morgul (65.4S, 0.7E) Camp", "Mordor: Minas Morgul (65.4S, 0.7E) Stable", 3);
NewEdge("Mordor: Ruins of Dingarth (48.0S, 8.7E) Stable", "Mordor: Kala-Murg (50.7S, 6.3E) Milestone", 3);
NewEdge("Mordor: Ruins of Dingarth (48.0S, 8.7E) Stable", "Mordor: Lughash (43.6S, 15.7E) Camp", 3);
NewEdge("Mordor: Ruins of Dingarth (48.0S, 8.7E) Stable", "Mordor: Rath Cail (49.7S, 5.9E) Milestone", 1);
NewEdge("Mordor: Ruins of Dingarth (48.1S, 8.6E) Milestone", "Mordor: Ruins of Dingarth (48.0S, 8.7E) Stable", 1);
NewEdge("Mordor: Ruins of Dingarth (48.0S, 8.7E) Stable", "Mordor: Udun Foothold (41.2S, 0.5W) Stable", 1);
NewEdge("Mordor: Ruins of Dingarth (48.0S, 8.7E) Stable", "Mordor: Udun Foothold (41.2S, 0.5W) Stable", 2);
NewEdge("Mordor: Ruins of Dingarth (48.0S, 8.7E) Stable", "Mordor: Durthang (49.0S, 2.2E) Camp", 3);
NewEdge("Mordor: Ruins of Dingarth (48.0S, 8.7E) Stable", "Mordor: Dor Amarth (43.6S, 15.7E) Camp", 3);
NewEdge("Mordor: Taen Orwath (66.9S, 5.8E) Camp", "Mordor: Taen Orwath (66.9S, 5.8E) Stable", 3);
NewEdge("Mordor: Taen Orwath (66.9S, 5.8E) Milestone", "Mordor: Taen Orwath (66.9S, 5.8E) Stable", 3);
NewEdge("Mordor: Taen Orwath (66.9S, 5.8E) Stable", "Mordor: Minas Morgul (65.4S, 0.7E) Stable", 1);
NewEdge("Mordor: Taen Orwath (66.9S, 5.8E) Stable", "Mordor: Minas Morgul (65.4S, 0.7E) Stable", 2);
NewEdge("Mordor: Taen Orwath (66.9S, 5.8E) Stable", "Mordor: Echad Taerdim (61.9S, 0.4W) Stable", 1);
NewEdge("Mordor: Taen Orwath (66.9S, 5.8E) Stable", "Mordor: Echad Taerdim (61.9S, 0.4W) Stable", 2);
NewEdge("Mordor: Taen Orwath (66.9S, 5.8E) Stable", "Mordor: Echad Uial (65.1S, 4.2E) Stable", 1);
NewEdge("Mordor: Taen Orwath (66.9S, 5.8E) Stable", "Mordor: Echad Uial (65.1S, 4.2E) Stable", 2);
NewEdge("Mordor: Taen Orwath (66.9S, 5.8E) Stable", "Mordor: Estolad Lan (64.5S, 2.2W) Stable", 1);
NewEdge("Mordor: Taen Orwath (66.9S, 5.8E) Stable", "Mordor: Estolad Lan (64.5S, 2.2W) Stable", 2);
NewEdge("Mordor: Udun Foothold (41.2S, 0.6W) Milestone", "Mordor: Udun Foothold (41.2S, 0.5W) Stable", 1);
NewEdge("Mordor: Udun Foothold (41.2S, 0.6W) Milestone", "Mordor: Udun Foothold (41.2S, 0.5W) Stable", 1);
NewEdge("Mordor: Udun Foothold (41.2S, 0.5W) Stable", "Mordor: Agarnaith Ranger Camp (56.6S, 26.9E) Stable", 1);
NewEdge("Mordor: Udun Foothold (41.2S, 0.5W) Stable", "Mordor: Agarnaith Ranger Camp (56.6S, 26.9E) Stable", 2);
NewEdge("Mordor: Udun Foothold (41.2S, 0.5W) Stable", "Mordor: Magh Ashtu (53.1S, 10.5E) Stable", 1);
NewEdge("Mordor: Udun Foothold (41.2S, 0.5W) Stable", "Mordor: Magh Ashtu (53.1S, 10.5E) Stable", 2);
NewEdge("Mordor: Udun Foothold (41.2S, 0.5W) Stable", "Mordor: Ruins of Dingarth (48.0S, 8.7E) Stable", 1);
NewEdge("Mordor: Udun Foothold (41.2S, 0.5W) Stable", "Mordor: Ruins of Dingarth (48.0S, 8.7E) Stable", 2);
NewEdge("Mordor: Udun Foothold (41.2S, 0.5W) Stable", "Mordor: Anglach (39.8S, 5.8E) Camp", 3);

-- Mordor Besieged Nodes & Paths
NewNode("Mordor: Ruins of Dingarth (481,S, 8.7E) Blazon of the Last Alliance");
NewEdge("Mordor: Ruins of Dingarth (481,S, 8.7E) Blazon of the Last Alliance", "Mordor: Ruins of Dingarth (48.0S, 8.7E) Stable", 3);
NewNode("Mordor Besieged: Dingarth (97,7S, 131.3W) Blazon of the Great Alliance");
NewEdge("Mordor Besieged: Dingarth (97,7S, 131.3W) Blazon of the Great Alliance", "Mordor: Ruins of Dingarth (481,S, 8.7E) Blazon of the Last Alliance", 1);
NewNode("Mordor Besieged: Dingarth (97,7S, 131.3W) Stable");
NewEdge("Mordor Besieged: Dingarth (97,7S, 131.3W) Stable", "Mordor Besieged: Dingarth (97,7S, 131.3W) Blazon of the Great Alliance", 3);
NewNode("Mordor Besieged: Dingarth (97,5S, 131.4W) Milestone");
NewEdge("Mordor Besieged: Dingarth (97,5S, 131.4W) Milestone", "Mordor Besieged: Dingarth (97,7S, 131.3W) Stable", 3);
NewNode("Mordor Besieged: Adambel (98.9S, 126.2W) Stable");
NewEdge("Mordor Besieged: Adambel (98.9S, 126.2W) Stable", "Mordor Besieged: Dingarth (97,7S, 131.3W) Stable", 1);
NewEdge("Mordor Besieged: Adambel (98.9S, 126.2W) Stable", "Mordor Besieged: Dingarth (97,7S, 131.3W) Stable", 2);
NewNode("Mordor Besieged: Adambel (98.6S, 126.4W) Milestone");
NewEdge("Mordor Besieged: Adambel (98.6S, 126.4W) Milestone", "Mordor Besieged: Adambel (98.9S, 126.2W) Stable", 3);
NewNode("Mordor Besieged: Adambel (98.9S, 126.2W) Blazon of the Great Alliance");
NewEdge("Mordor Besieged: Adambel (98.9S, 126.2W) Blazon of the Great Alliance", "Mordor Besieged: Adambel (98.9S, 126.2W) Stable", 3);
NewNode("Mordor Besieged: Barhost (95.3S, 119.9W) Stable");
NewEdge("Mordor Besieged: Barhost (95.3S, 119.9W) Stable", "Mordor Besieged: Adambel (98.9S, 126.2W) Stable", 1);
NewEdge("Mordor Besieged: Barhost (95.3S, 119.9W) Stable", "Mordor Besieged: Adambel (98.9S, 126.2W) Stable", 2);
NewEdge("Mordor Besieged: Barhost (95.3S, 119.9W) Stable", "Mordor Besieged: Dingarth (97,7S, 131.3W) Stable", 1);
NewEdge("Mordor Besieged: Barhost (95.3S, 119.9W) Stable", "Mordor Besieged: Dingarth (97,7S, 131.3W) Stable", 2);
NewNode("Mordor Besieged: Barhost (95.3S, 120.0W) Milestone");
NewEdge("Mordor Besieged: Barhost (95.3S, 120.0W) Milestone", "Mordor Besieged: Dingarth (97,7S, 131.3W) Stable", 3);
NewNode("Mordor Besieged: Echad-in-Edhil (96.3S, 127.6W) Stable");
NewEdge("Mordor Besieged: Echad-in-Edhil (96.3S, 127.6W) Stable", "Mordor Besieged: Barhost (95.3S, 120.0W) Milestone", 1);
NewEdge("Mordor Besieged: Echad-in-Edhil (96.3S, 127.6W) Stable", "Mordor Besieged: Barhost (95.3S, 120.0W) Milestone", 2);
NewEdge("Mordor Besieged: Echad-in-Edhil (96.3S, 127.6W) Stable", "Mordor Besieged: Adambel (98.9S, 126.2W) Stable", 1);
NewEdge("Mordor Besieged: Echad-in-Edhil (96.3S, 127.6W) Stable", "Mordor Besieged: Adambel (98.9S, 126.2W) Stable", 2);
NewEdge("Mordor Besieged: Echad-in-Edhil (96.3S, 127.6W) Stable", "Mordor Besieged: Dingarth (97,7S, 131.3W) Stable", 1);
NewEdge("Mordor Besieged: Echad-in-Edhil (96.3S, 127.6W) Stable", "Mordor Besieged: Dingarth (97,7S, 131.3W) Stable", 2);

-- Moria Nodes & Paths
NewNode("Moria: Anazarmekhem (13.22S, 107.96W) Stable");
NewNode("Moria: Chamber of the Crossroads (5.2S, 112.1W) Stable");
NewNode("Moria: Dolven-view (8.4S, 112.4W) Stable");
NewNode("Moria: Durin's Threshold (7.9S, 116.1W) Stable");
NewNode("Moria: Deep Descent (9.8S, 112.5W) Stable");
NewNode("Moria: First Hall (8.0S, 95.3W) Stable");
NewNode("Moria: Jazargund (3.7S, 106.0W) Stable");
NewNode("Moria: Shadowed Refuge (13.0S, 101.6W) Stable");
NewNode("Moria: Tharakh Bazan (3.2S, 108.6W) Stable");
NewNode("Moria: The Fanged Pit (3.5S, 103.3W) Stable");
NewNode("Moria: The Orc-watch (11.1S, 106.9W) Stable");
NewNode("Moria: The Rotting Cellar (15.1S, 111.9W) Stable");
NewNode("Moria: The Vile Maw (17.6S, 116.9W) Stable");
NewNode("Moria: Twenty-first Hall (5.7S, 105.3W) Stable");
NewNode("Moria: Zirakzigil (2.9S, 110.8W) Stable");
NewNode("Moria to Eriador Exit (7.8S, 118.5)");
NewNode("Moria to Lothlorien Exit (8.0S, 93.2W)");
NewNode("Durin's Door Exit (51.9S, 3.4W)");
NewEdge("Durin's Door Exit (51.9S, 3.4W)", "Moria to Eriador Exit (7.8S, 118.5)", 1);
NewEdge("Moria: Anazarmekhem (13.22S, 107.96W) Stable", "Moria: Dolven-view (8.4S, 112.4W) Stable", 2)
NewEdge("Moria: Anazarmekhem (13.22S, 107.96W) Stable", "Moria: The Orc-watch (11.1S, 106.9W) Stable", 2);
NewEdge("Moria: Anazarmekhem (13.22S, 107.96W) Stable", "Moria: The Rotting Cellar (15.1S, 111.9W) Stable", 2)
NewEdge("Moria: Anazarmekhem (13.22S, 107.96W) Stable", "Moria: Twenty-first Hall (5.7S, 105.3W) Stable", 2)
NewEdge("Moria: Chamber of the Crossroads (5.2S, 112.1W) Stable", "Moria: Dolven-view (8.4S, 112.4W) Stable", 2);
NewEdge("Moria: Chamber of the Crossroads (5.2S, 112.1W) Stable", "Moria: Durin's Threshold (7.9S, 116.1W) Stable", 2);
NewEdge("Moria: Chamber of the Crossroads (5.2S, 112.1W) Stable", "Moria: Twenty-first Hall (5.7S, 105.3W) Stable", 1);
NewEdge("Moria: Deep Descent (9.8S, 112.5W) Stable", "Moria: Dolven-view (8.4S, 112.4W) Stable", 2);
NewEdge("Moria: Deep Descent (9.8S, 112.5W) Stable", "Moria: Durin's Threshold (7.9S, 116.1W) Stable", 2);
NewEdge("Moria: Deep Descent (9.8S, 112.5W) Stable", "Moria: The Rotting Cellar (15.1S, 111.9W) Stable", 2);
NewEdge("Moria: Dolven-view (8.4S, 112.4W) Stable", "Moria: Anazarmekhem (13.22S, 107.96W) Stable", 2);
NewEdge("Moria: Dolven-view (8.4S, 112.4W) Stable", "Moria: Chamber of the Crossroads (5.2S, 112.1W) Stable", 2);
NewEdge("Moria: Dolven-view (8.4S, 112.4W) Stable", "Moria: Deep Descent (9.8S, 112.5W) Stable", 2);
NewEdge("Moria: Dolven-view (8.4S, 112.4W) Stable", "Moria: Durin's Threshold (7.9S, 116.1W) Stable", 2);
NewEdge("Moria: Dolven-view (8.4S, 112.4W) Stable", "Moria: First Hall (8.0S, 95.3W) Stable", 1);
NewEdge("Moria: Dolven-view (8.4S, 112.4W) Stable", "Moria: The Orc-watch (11.1S, 106.9W) Stable", 2);
NewEdge("Moria: Dolven-view (8.4S, 112.4W) Stable", "Moria: Twenty-first Hall (5.7S, 105.3W) Stable", 1);
NewEdge("Moria: Durin's Threshold (7.9S, 116.1W) Stable", "Moria: Chamber of the Crossroads (5.2S, 112.1W) Stable", 2);
NewEdge("Moria: Durin's Threshold (7.9S, 116.1W) Stable", "Moria: Deep Descent (9.8S, 112.5W) Stable", 2);
NewEdge("Moria: Durin's Threshold (7.9S, 116.1W) Stable", "Moria: Dolven-view (8.4S, 112.4W) Stable", 2);
NewEdge("Moria: Durin's Threshold (7.9S, 116.1W) Stable", "Moria to Eriador Exit (7.8S, 118.5)", 1);
NewEdge("Moria: First Hall (8.0S, 95.3W) Stable", "Moria: Dolven-view (8.4S, 112.4W) Stable", 1);
NewEdge("Moria: First Hall (8.0S, 95.3W) Stable", "Moria to Lothlorien Exit (8.0S, 93.2W)", 1);
NewEdge("Moria: First Hall (8.0S, 95.3W) Stable", "Moria: Shadowed Refuge (13.0S, 101.6W) Stable", 1);
NewEdge("Moria: First Hall (8.0S, 95.3W) Stable", "Moria: Twenty-first Hall (5.7S, 105.3W) Stable", 1);
NewEdge("Moria: Jazargund (3.7S, 106.0W) Stable", "Moria: Twenty-first Hall (5.7S, 105.3W) Stable", 2);
NewEdge("Moria: Jazargund (3.7S, 106.0W) Stable", "Moria: Zirakzigil (2.9S, 110.8W) Stable", 2);
NewEdge("Moria to Eriador Exit (7.8S, 118.5)", "Durin's Door Exit (51.9S, 3.4W)", 1);
NewEdge("Moria to Eriador Exit (7.8S, 118.5)", "Moria: Durin's Threshold (7.9S, 116.1W) Stable", 1);
NewEdge("Moria to Lothlorien Exit (8.0S, 93.2W)", "Lothlorien to Moria Exit (6.7S, 79.7W)", 1);
NewEdge("Moria: The Fanged Pit (3.5S, 103.3W) Stable", "Moria: Twenty-first Hall (5.7S, 105.3W) Stable", 1);
NewEdge("Moria: The Fanged Pit (3.5S, 103.3W) Stable", "Moria: Zirakzigil (2.9S, 110.8W) Stable", 1);
NewEdge("Moria: The Orc-watch (11.1S, 106.9W) Stable", "Moria: Anazarmekhem (13.22S, 107.96W) Stable", 2);
NewEdge("Moria: The Orc-watch (11.1S, 106.9W) Stable", "Moria: Dolven-view (8.4S, 112.4W) Stable", 2);
NewEdge("Moria: The Orc-watch (11.1S, 106.9W) Stable", "Moria: Shadowed Refuge (13.0S, 101.6W) Stable", 2);
NewEdge("Moria: The Orc-watch (11.1S, 106.9W) Stable", "Moria: The Rotting Cellar (15.1S, 111.9W) Stable", 2);
NewEdge("Moria: The Orc-watch (11.1S, 106.9W) Stable", "Moria: Twenty-first Hall (5.7S, 105.3W) Stable", 2);
NewEdge("Moria: The Rotting Cellar (15.1S, 111.9W) Stable", "Moria: Anazarmekhem (13.22S, 107.96W) Stable", 2);
NewEdge("Moria: The Rotting Cellar (15.1S, 111.9W) Stable", "Moria: Deep Descent (9.8S, 112.5W) Stable", 2);
NewEdge("Moria: The Rotting Cellar (15.1S, 111.9W) Stable", "Moria: The Orc-watch (11.1S, 106.9W) Stable", 2);
NewEdge("Moria: The Rotting Cellar (15.1S, 111.9W) Stable", "Moria: The Vile Maw (17.6S, 116.9W) Stable", 2);
NewEdge("Moria: The Vile Maw (17.6S, 116.9W) Stable", "Moria: The Rotting Cellar (15.1S, 111.9W) Stable", 2);
NewEdge("Moria: Twenty-first Hall (5.7S, 105.3W) Stable", "Moria: Anazarmekhem (13.22S, 107.96W) Stable", 2);
NewEdge("Moria: Twenty-first Hall (5.7S, 105.3W) Stable", "Moria: Chamber of the Crossroads (5.2S, 112.1W) Stable", 1);
NewEdge("Moria: Twenty-first Hall (5.7S, 105.3W) Stable", "Moria: Dolven-view (8.4S, 112.4W) Stable", 1);
NewEdge("Moria: Twenty-first Hall (5.7S, 105.3W) Stable", "Moria: First Hall (8.0S, 95.3W) Stable", 1);
NewEdge("Moria: Twenty-first Hall (5.7S, 105.3W) Stable", "Dunland: Galtrev (80.0S, 16.7W) Stable", 1);
NewEdge("Moria: Twenty-first Hall (5.7S, 105.3W) Stable", "Lothlorien: Inner Caras Galadhon (15.1S, 68.2W) Stable", 1);
NewEdge("Moria: Twenty-first Hall (5.7S, 105.3W) Stable", "Moria: Jazargund (3.7S, 106.0W) Stable", 2);
NewEdge("Moria: Twenty-first Hall (5.7S, 105.3W) Stable", "Moria: Shadowed Refuge (13.0S, 101.6W) Stable", 1);
NewEdge("Moria: Twenty-first Hall (5.7S, 105.3W) Stable", "Great River: Stangard (25.6W, 63.5W) Stable", 1);
NewEdge("Moria: Twenty-first Hall (5.7S, 105.3W) Stable", "Moria: Tharakh Bazan (3.2S, 108.6W) Stable", 1);
NewEdge("Moria: Twenty-first Hall (5.7S, 105.3W) Stable", "Moria: The Fanged Pit (3.5S, 103.3W) Stable", 1);
NewEdge("Moria: Twenty-first Hall (5.7S, 105.3W) Stable", "Moria: The Orc-watch (11.1S, 106.9W) Stable", 2);
NewEdge("Moria: Twenty-first Hall (5.7S, 105.3W) Stable", "Eryn Lasgalen: Dale (24.0N, 26.1W) Stable", 1);

NewEdge("Moria: Shadowed Refuge (13.0S, 101.6W) Stable", "Moria: The Orc-watch (11.1S, 106.9W) Stable", 2);
NewEdge("Moria: Shadowed Refuge (13.0S, 101.6W) Stable", "Moria: Twenty-first Hall (5.7S, 105.3W) Stable", 1);
NewEdge("Moria: Shadowed Refuge (13.0S, 101.6W) Stable", "Moria: First Hall (8.0S, 95.3W) Stable", 1);
NewEdge("Moria: Tharakh Bazan (3.2S, 108.6W) Stable", "Moria: Twenty-first Hall (5.7S, 105.3W) Stable", 1);
NewEdge("Moria: Zirakzigil (2.9S, 110.8W) Stable", "Moria: Jazargund (3.7S, 106.0W) Stable", 2);
NewEdge("Moria: Zirakzigil (2.9S, 110.8W) Stable", "Moria: The Fanged Pit (3.5S, 103.3W) Stable", 1);
-- Moria Campsites & Horns
NewNode("Moria: Tharakh Bazan (3.2S, 108.6W) Camp");
NewEdge("Moria: Tharakh Bazan (3.2S, 108.6W) Stable", "Moria: Tharakh Bazan (3.2S, 108.6W) Camp", 3);
NewNode("Moria: Bridge of Khazad-dum (8.1S, 98.5W) Camp");
NewEdge("Moria: First Hall (8.0S, 95.3W) Stable", "Moria: Bridge of Khazad-dum (8.1S, 98.5W) Camp", 3);
NewNode("Moria: The Sixteenth Hall (11.0S, 101.1W) Camp/Horn");
NewEdge("Moria: First Hall (8.0S, 95.3W) Stable", "Moria: The Sixteenth Hall (11.0S, 101.1W) Camp/Horn", 3);
NewNode("Moria: Durin's Threshold (8.2S, 116.2W) Camp");
NewEdge("Moria: Durin's Threshold (7.9S, 116.1W) Stable", "Moria: Durin's Threshold (8.2S, 116.2W) Camp", 3);
NewNode("Moria: Lamab-dum (7.5S, 113.4W) Camp");
NewEdge("Moria: Durin's Threshold (7.9S, 116.1W) Stable", "Moria: Lamab-dum (7.5S, 113.4W) Camp", 3);
NewNode("Moria: The Grand Stair (10.3S, 103.9W) Camp/Horn");
NewEdge("Moria: The Orc-watch (11.1S, 106.9W) Stable", "Moria: The Grand Stair (10.3S, 103.9W) Camp/Horn", 3);
NewNode("Moria: Fil Gashan (16.4S, 109.6W) Camp/Horn");
NewEdge("Moria: Anazarmekhem (13.22S, 107.96W) Stable", "Moria: Fil Gashan (16.4S, 109.6W) Camp/Horn", 3);
NewNode("Moria: Dark Delvings (15.4S, 97.4W) Camp/Horn");
NewEdge("Moria: Shadowed Refuge (13.0S, 101.6W) Stable", "Moria: Dark Delvings (15.4S, 97.4W) Camp/Horn", 3);
NewNode("Moria: Skumfil (13.4S, 100.4W) Camp/Horn");
NewEdge("Moria: Shadowed Refuge (13.0S, 101.6W) Stable", "Moria: Skumfil (13.4S, 100.4W) Camp/Horn", 3);
NewNode("Moria: Menem-berej (11.0S, 112.1W) Camp/Horn");
NewEdge("Moria: Deep Descent (9.8S, 112.5W) Stable", "Moria: Menem-berej (11.0S, 112.1W) Camp/Horn", 3);
NewNode("Moria: The Forgotten Treasury (11.1S, 112.7W) Camp/Horn");
NewEdge("Moria: Deep Descent (9.8S, 112.5W) Stable", "Moria: The Forgotten Treasury (11.1S, 112.7W) Camp/Horn", 3);
NewNode("Moria: Nala-dum (14.1S, 112.7W) Camp/Horn");
NewEdge("Moria: The Rotting Cellar (15.1S, 111.9W) Stable", "Moria: Nala-dum (14.1S, 112.7W) Camp/Horn", 3);
NewNode("Moria: The Vile Maw (17.6S, 116.9W) Camp/Horn");
NewEdge("Moria: The Vile Maw (17.6S, 116.9W) Stable", "Moria: The Vile Maw (17.6S, 116.9W) Camp/Horn", 3);
NewNode("Moria: Zelem-melek (8.4S, 109.0W) Camp");
NewEdge("Moria: Twenty-first Hall (5.7S, 105.3W) Stable", "Moria: Zelem-melek (8.4S, 109.0W) Camp", 3);
NewNode("Door To Zirakzigil (13.5N, 109.1W)");
NewNode("Door To Durin's Way (13.5N, 102.2W)");
NewEdge("Moria: Zirakzigil (2.9S, 110.8W) Stable", "Door To Zirakzigil (13.5N, 109.1W)", 2);
NewEdge("Door To Zirakzigil (13.5N, 109.1W)", "Door To Durin's Way (13.5N, 102.2W)", 2);
NewNode("Moria: Durin's Bane (15.5N, 108.5W) Camp/Horn");
NewEdge("Door To Durin's Way (13.5N, 102.2W)", "Moria: Durin's Bane (15.5N, 108.5W) Camp/Horn", 3);
-- Moria Milestones
NewNode("Moria: Durin's Threshold (8.1S, 116.1W) Milestone");
NewEdge("Moria: Durin's Threshold (7.9S, 116.1W) Stable", "Moria: Durin's Threshold (8.1S, 116.1W) Milestone", 3);
NewNode("Moria: Dolven-view (8.1S, 116.1) Milestone");
NewEdge("Moria: Dolven-view (8.4S, 112.4W) Stable", "Moria: Dolven-view (8.1S, 116.1) Milestone", 3);
NewNode("Moria: Deep Descent (8.1S, 116.1W) Milestone");
NewEdge("Moria: Deep Descent (9.8S, 112.5W) Stable", "Moria: Deep Descent (8.1S, 116.1W) Milestone", 3);
NewNode("Moria: Chamber of the Crossroads (5.2S, 112.0W) Milestone");
NewEdge("Moria: Chamber of the Crossroads (5.2S, 112.1W) Stable", "Moria: Chamber of the Crossroads (5.2S, 112.0W) Milestone", 3);
NewNode("Moria: Twenty-first Hall (5.8S, 105.2W) Milestone");
NewEdge("Moria: Twenty-first Hall (5.7S, 105.3W) Stable", "Moria: Twenty-first Hall (5.8S, 105.2W) Milestone", 3);
NewNode("Moria: The Rotting Cellar (15.1S, 112.1W) Milestone");
NewEdge("Moria: The Rotting Cellar (15.1S, 111.9W) Stable", "Moria: The Rotting Cellar (15.1S, 112.1W) Milestone", 3);

-- Nan Curunir Nodes & Paths
NewNode("Nan Curunir: Dagoras' Camp (84.9S, 3.4W) Stable");
NewEdge("Nan Curunir: Dagoras' Camp (84.9S, 3.4W) Stable", "Dunland: Galtrev (80.0S, 16.7W) Stable", 1);
NewEdge("Nan Curunir: Dagoras' Camp (84.9S, 3.4W) Stable", "Gap of Rohan: Grimbold's Camp (87.8S, 3.9W) Stable", 1);
NewNode("Nan Curunir: Isengard (47.7S, 89.7W) Stable");
NewEdge("Nan Curunir: Isengard (47.7S, 89.7W) Stable", "West Rohan: Aldburg (68.7S, 63.9W) Stable", 1);
NewEdge("Nan Curunir: Isengard (47.7S, 89.7W) Stable", "West Rohan: Helm's Deep (63.7S, 89.5W) Stable", 1);
-- Nan Curunir Campsites & Horns
NewNode("Nan Curunir: Dagoras' Camp (84.8S, 3.5W) Camp/Horn");
NewEdge("Nan Curunir: Dagoras' Camp (84.9S, 3.4W) Stable", "Nan Curunir: Dagoras' Camp (84.8S, 3.5W) Camp/Horn", 3);
-- Nan Curunir Milestones
NewNode("Nan Curunir: Dagoras' Camp (84.9S, 3.5W) Milestone");
NewEdge("Nan Curunir: Dagoras' Camp (84.9S, 3.4W) Stable", "Nan Curunir: Dagoras' Camp (84.9S, 3.5W) Milestone", 3);

NewNode("Nan Curunir: Huorn (47.5S, 87.8W) Huorn/Waypoint");
NewNode("West Rohan: Entwood (42.5S, 78.6W) Huorn/Waypoint");

NewEdge("Nan Curunir: Huorn (47.5S, 87.8W) Huorn/Waypoint", "Nan Curunir: Dagoras' Camp (84.9S, 3.4W) Stable", 2);
NewEdge("Nan Curunir: Huorn (47.5S, 87.8W) Huorn/Waypoint", "West Rohan: Entwood (42.5S, 78.6W) Huorn/Waypoint", 2);
NewNode("Nan Curunir: Isengard (47.7S, 89.7W) Milestone");
NewEdge("Nan Curunir: Isengard (47.7S, 89.7W) Stable", "Nan Curunir: Isengard (47.7S, 89.7W) Milestone", 3);

NewNode("Nan Curunir: Ox-clan Merchant Camp (79.9S, 0.2E) Milestone");
NewEdge("Nan Curunir: Ox-clan Merchant Camp (79.9S, 0.4E)", "Nan Curunir: Ox-clan Merchant Camp (79.9S, 0.2E) Milestone", 3);

-- North Downs Nodes & Paths
NewNode("North Downs: Amon Raith (12.3S, 52.5W) Stable");
NewNode("North Downs: Othrikar (6.9S, 45.0W) Stable");
NewNode("North Downs: Esteldin (9.7S, 42.1W) Stable");
NewNode("North Downs: Meluinen (13.6S, 44.5W) Stable");
NewNode("North Downs: Trestlebridge (18.0S, 53.6W) Stable");
NewEdge("North Downs: Amon Raith (12.3S, 52.5W) Stable", "North Downs: Trestlebridge (18.0S, 53.6W) Stable", 2);
NewEdge("North Downs: Esteldin (9.7S, 42.1W) Stable", "North Downs: Amon Raith (12.3S, 52.5W) Stable", 2);
NewEdge("North Downs: Esteldin (9.7S, 42.1W) Stable", "Angmar: Aughaire (0.2S, 39.3W) Stable", 2);
NewEdge("North Downs: Esteldin (9.7S, 42.1W) Stable", "Angmar: Gath Forthnir (10.4N, 24.0W) Stable", 1);
NewEdge("North Downs: Esteldin (9.7S, 42.1W) Stable", "North Downs: Meluinen (13.6S, 44.5W) Stable", 2);
NewEdge("North Downs: Esteldin (9.7S, 42.1W) Stable", "Trollshaws: Rivendell (29.3S, 6.4W) Stable", 1);
NewEdge("North Downs: Esteldin (9.7S, 42.1W) Stable", "North Downs: Trestlebridge (18.0S, 53.6W) Stable", 2);
NewEdge("North Downs: Esteldin (9.7S, 42.1W) Stable", "Evendim: Tinnudir (12.4S, 67.2W) Stable", 1);
NewEdge("North Downs: Esteldin (9.7S, 42.1W) Stable", "Bree-land: West Bree (29,5S, 52.6W) Stable", 1);
NewEdge("North Downs: Meluinen (13.6S, 44.5W) Stable", "North Downs: Esteldin (9.7S, 42.1W) Stable", 2);
NewEdge("North Downs: Meluinen (13.6S, 44.5W) Stable", "North Downs: Othrikar (6.9S, 45.0W) Stable", 2);
NewEdge("North Downs: Othrikar (6.9S, 45.0W) Stable", "North Downs: Esteldin (9.7S, 42.1W) Stable", 2);
NewEdge("North Downs: Othrikar (6.9S, 45.0W) Stable", "North Downs: Meluinen (13.6S, 44.5W) Stable", 2);
NewEdge("North Downs: Trestlebridge (18.0S, 53.6W) Stable", "North Downs: Amon Raith (12.3S, 52.5W) Stable", 2);
NewEdge("North Downs: Trestlebridge (18.0S, 53.6W) Stable", "North Downs: Esteldin (9.7S, 42.1W) Stable", 2);
NewEdge("North Downs: Trestlebridge (18.0S, 53.6W) Stable", "Bree-land: Hengstacer Farm (22.3S, 52.3W) Stable", 2);
NewEdge("North Downs: Trestlebridge (18.0S, 53.6W) Stable", "Evendim: Ost Forod (8.2S, 64.3W) Stable", 2);
NewEdge("North Downs: Trestlebridge (18.0S, 53.6W) Stable", "Evendim: Tinnudir (12.4S, 67.2W) Stable", 2);
NewEdge("North Downs: Trestlebridge (18.0S, 53.6W) Stable", "Bree-land: West Bree (29,5S, 52.6W) Stable", 2);
-- North Downs Campsite Nodes
NewNode("North Downs: Amlaith's Scar - Stoneheight (9.9S, 49.5W) Camp/Horn");
NewEdge("North Downs: Amon Raith (12.3S, 52.5W) Stable", "North Downs: Amlaith's Scar - Stoneheight (9.9S, 49.5W) Camp/Horn", 3);
NewNode("North Downs: Fornost (6.1S, 55.3W) Camp/Horn");
NewEdge("North Downs: Amon Raith (12.3S, 52.5W) Stable", "North Downs: Fornost (6.1S, 55.3W) Camp/Horn", 3);
NewNode("North Downs: Nan Wathren Western Pass (14.7S, 50.7W) Camp");
NewEdge("North Downs: Amon Raith (12.3S, 52.5W) Stable", "North Downs: Nan Wathren Western Pass (14.7S, 50.7W) Camp", 3);
NewNode("North Downs: Ost Lagoros (9.4S, 47.3W) Camp");
NewEdge("North Downs: Amon Raith (12.3S, 52.5W) Stable", "North Downs: Ost Lagoros (9.4S, 47.3W) Camp", 3);
NewNode("North Downs: Rhunenlad (12.5S, 37,5W) Camp/Horn");
NewEdge("North Downs: Esteldin (9.7S, 42.1W) Stable", "North Downs: Rhunenlad (12.5S, 37,5W) Camp/Horn", 3);
-- North Downs Milestones
NewNode("North Downs: Esteldin (9.6S, 42.1W) Milestone");
NewEdge("North Downs: Esteldin (9.7S, 42.1W) Stable", "North Downs: Esteldin (9.6S, 42.1W) Milestone", 3);
NewNode("North Downs: Trestlebridge (18.0S, 53.7W) Milestone");
NewEdge("North Downs: Trestlebridge (18.0S, 53.6W) Stable", "North Downs: Trestlebridge (18.0S, 53.7W) Milestone", 3);

-- North Ithilien Nodes & Paths
NewNode("North Ithilien: Henneth Annun (48.4S, 6.9W) Stable");
NewNode("North Ithilien: Slag Hills (34.4S, 3.5W) Stable");
NewEdge("North Ithilien: Slag Hills (34.4S, 3.5W) Stable", "Anorien After Battle: Osgiliath (63.0S, 6.5W) Stable", 1);
NewEdge("North Ithilien: Slag Hills (34.4S, 3.5W) Stable", "Anorien After Battle: Osgiliath (63.0S, 6.5W) Stable", 2);
NewEdge("North Ithilien: Slag Hills (34.4S, 3.5W) Stable", "The Wastes: Camp of the Host (41.0S, 10.5W) Stable", 1);
NewEdge("North Ithilien: Slag Hills (34.4S, 3.5W) Stable", "The Wastes: Camp of the Host (41.0S, 10.5W) Stable", 2);
NewEdge("North Ithilien: Slag Hills (34.4S, 3.5W) Stable", "Mordor: Udun Foothold (41.2S, 0.5W) Stable", 1);
NewEdge("North Ithilien: Slag Hills (34.4S, 3.5W) Stable", "Mordor: Udun Foothold (41.2S, 0.5W) Stable", 2);
NewEdge("North Ithilien: Henneth Annun (48.4S, 6.9W) Stable", "Anorien After Battle: Aragorn's Pavailion (65.6S, 14.8W) Stable", 1);
NewEdge("North Ithilien: Henneth Annun (48.4S, 6.9W) Stable", "Anorien After Battle: Aragorn's Pavailion (65.6S, 14.8W) Stable", 2);
NewEdge("North Ithilien: Henneth Annun (48.4S, 6.9W) Stable", "Anorien After Battle: Minas Tirith (65.6S, 16.9W) Stable", 1);
NewEdge("North Ithilien: Henneth Annun (48.4S, 6.9W) Stable", "Anorien After Battle: Minas Tirith (65.6S, 16.9W) Stable", 2);
NewEdge("North Ithilien: Henneth Annun (48.4S, 6.9W) Stable",  "Anorien After Battle: Osgiliath (63.0S, 6.5W) Stable", 1);
NewEdge("North Ithilien: Henneth Annun (48.4S, 6.9W) Stable",  "Anorien After Battle: Osgiliath (63.0S, 6.5W) Stable", 2);
NewEdge("North Ithilien: Henneth Annun (48.4S, 6.9W) Stable",  "The Wastes: Camp of the Host (41.0S, 10.5W) Stable", 1);
NewEdge("North Ithilien: Henneth Annun (48.4S, 6.9W) Stable",  "The Wastes: Camp of the Host (41.0S, 10.5W) Stable", 2);

-- Old Anorien Nodes & Paths
NewNode("Old Anorien: Minas Tirith Main Gate (65.8S, 16.8W) Stable");
NewNode("Old Anorian: Minas Tirith Soldiers Tier - 2nd Circle - (66.4S, 17.5W) Stable");
NewNode("Old Anorian: Minas Tirith Craftsmens Tier - 3rd Circle - (64.8S, 17.9W) Stable");
NewNode("Old Anorian: Minas Tirith Players Tier - 4th Circle - (66.4S, 184W) Stable");
NewNode("Old Anorian: Minas Tirith Sages Tier - 5th Circle - (65.0S, 18.6W) Stable");
NewNode("Old Anorian: Minas Tirith Masters Tier - 6th Circle - (66.2S, 19.3W) Stable");
NewNode("Old Anorien: Minas Tirith (65.4S, 16.7W) Milestone");
NewNode("Old Anorien: North Gate (59.5S, 17.5W) Stable");
NewNode("Old Anorien: Crithost (54.3S, 16.4W) Milestone");

NewEdge("Old Anorien: Minas Tirith Main Gate (65.8S, 16.8W) Stable", "Anorien After Battle: Osgiliath (63.0S, 6.5W) Stable", 1);

NewEdge("Old Anorien: Minas Tirith Main Gate (65.8S, 16.8W) Stable", "Old Anorian: Minas Tirith Soldiers Tier - 2nd Circle - (66.4S, 17.5W) Stable", 1);
NewEdge("Old Anorien: Minas Tirith Main Gate (65.8S, 16.8W) Stable", "Old Anorian: Minas Tirith Soldiers Tier - 2nd Circle - (66.4S, 17.5W) Stable", 2);
NewEdge("Old Anorien: Minas Tirith Main Gate (65.8S, 16.8W) Stable", "Old Anorian: Minas Tirith Craftsmens Tier - 3rd Circle - (64.8S, 17.9W) Stable", 1);
NewEdge("Old Anorien: Minas Tirith Main Gate (65.8S, 16.8W) Stable", "Old Anorian: Minas Tirith Craftsmens Tier - 3rd Circle - (64.8S, 17.9W) Stable", 2);
NewEdge("Old Anorien: Minas Tirith Main Gate (65.8S, 16.8W) Stable", "Old Anorian: Minas Tirith Players Tier - 4th Circle - (66.4S, 184W) Stable", 1);
NewEdge("Old Anorien: Minas Tirith Main Gate (65.8S, 16.8W) Stable", "Old Anorian: Minas Tirith Players Tier - 4th Circle - (66.4S, 184W) Stable", 2);
NewEdge("Old Anorien: Minas Tirith Main Gate (65.8S, 16.8W) Stable", "Old Anorian: Minas Tirith Sages Tier - 5th Circle - (65.0S, 18.6W) Stable", 1);
NewEdge("Old Anorien: Minas Tirith Main Gate (65.8S, 16.8W) Stable", "Old Anorian: Minas Tirith Sages Tier - 5th Circle - (65.0S, 18.6W) Stable", 2);
NewEdge("Old Anorien: Minas Tirith Main Gate (65.8S, 16.8W) Stable", "Old Anorian: Minas Tirith Masters Tier - 6th Circle - (66.2S, 19.3W) Stable", 1);
NewEdge("Old Anorien: Minas Tirith Main Gate (65.8S, 16.8W) Stable", "Old Anorian: Minas Tirith Masters Tier - 6th Circle - (66.2S, 19.3W) Stable", 2);

NewEdge("Old Anorian: Minas Tirith Soldiers Tier - 2nd Circle - (66.4S, 17.5W) Stable", "Old Anorien: Minas Tirith Main Gate (65.8S, 16.8W) Stable", 1);
NewEdge("Old Anorian: Minas Tirith Soldiers Tier - 2nd Circle - (66.4S, 17.5W) Stable", "Old Anorien: Minas Tirith Main Gate (65.8S, 16.8W) Stable", 2);
NewEdge("Old Anorian: Minas Tirith Soldiers Tier - 2nd Circle - (66.4S, 17.5W) Stable", "Old Anorian: Minas Tirith Craftsmens Tier - 3rd Circle - (64.8S, 17.9W) Stable", 1);
NewEdge("Old Anorian: Minas Tirith Soldiers Tier - 2nd Circle - (66.4S, 17.5W) Stable", "Old Anorian: Minas Tirith Craftsmens Tier - 3rd Circle - (64.8S, 17.9W) Stable", 2);
NewEdge("Old Anorian: Minas Tirith Soldiers Tier - 2nd Circle - (66.4S, 17.5W) Stable", "Old Anorian: Minas Tirith Players Tier - 4th Circle - (66.4S, 184W) Stable", 1);
NewEdge("Old Anorian: Minas Tirith Soldiers Tier - 2nd Circle - (66.4S, 17.5W) Stable", "Old Anorian: Minas Tirith Players Tier - 4th Circle - (66.4S, 184W) Stable", 2);
NewEdge("Old Anorian: Minas Tirith Soldiers Tier - 2nd Circle - (66.4S, 17.5W) Stable", "Old Anorian: Minas Tirith Sages Tier - 5th Circle - (65.0S, 18.6W) Stable", 1);
NewEdge("Old Anorian: Minas Tirith Soldiers Tier - 2nd Circle - (66.4S, 17.5W) Stable", "Old Anorian: Minas Tirith Sages Tier - 5th Circle - (65.0S, 18.6W) Stable", 2);
NewEdge("Old Anorian: Minas Tirith Soldiers Tier - 2nd Circle - (66.4S, 17.5W) Stable", "Old Anorian: Minas Tirith Masters Tier - 6th Circle - (66.2S, 19.3W) Stable", 1);
NewEdge("Old Anorian: Minas Tirith Soldiers Tier - 2nd Circle - (66.4S, 17.5W) Stable", "Old Anorian: Minas Tirith Masters Tier - 6th Circle - (66.2S, 19.3W) Stable", 2);

NewEdge("Old Anorian: Minas Tirith Craftsmens Tier - 3rd Circle - (64.8S, 17.9W) Stable", "Old Anorien: Minas Tirith Main Gate (65.8S, 16.8W) Stable", 1);
NewEdge("Old Anorian: Minas Tirith Craftsmens Tier - 3rd Circle - (64.8S, 17.9W) Stable", "Old Anorien: Minas Tirith Main Gate (65.8S, 16.8W) Stable", 2);
NewEdge("Old Anorian: Minas Tirith Craftsmens Tier - 3rd Circle - (64.8S, 17.9W) Stable", "Old Anorian: Minas Tirith Soldiers Tier - 2nd Circle - (66.4S, 17.5W) Stable", 1);
NewEdge("Old Anorian: Minas Tirith Craftsmens Tier - 3rd Circle - (64.8S, 17.9W) Stable", "Old Anorian: Minas Tirith Soldiers Tier - 2nd Circle - (66.4S, 17.5W) Stable", 2);
NewEdge("Old Anorian: Minas Tirith Craftsmens Tier - 3rd Circle - (64.8S, 17.9W) Stable", "Old Anorian: Minas Tirith Players Tier - 4th Circle - (66.4S, 184W) Stable", 1);
NewEdge("Old Anorian: Minas Tirith Craftsmens Tier - 3rd Circle - (64.8S, 17.9W) Stable", "Old Anorian: Minas Tirith Players Tier - 4th Circle - (66.4S, 184W) Stable", 2);
NewEdge("Old Anorian: Minas Tirith Craftsmens Tier - 3rd Circle - (64.8S, 17.9W) Stable", "Old Anorian: Minas Tirith Sages Tier - 5th Circle - (65.0S, 18.6W) Stable", 1);
NewEdge("Old Anorian: Minas Tirith Craftsmens Tier - 3rd Circle - (64.8S, 17.9W) Stable", "Old Anorian: Minas Tirith Sages Tier - 5th Circle - (65.0S, 18.6W) Stable", 2);
NewEdge("Old Anorian: Minas Tirith Craftsmens Tier - 3rd Circle - (64.8S, 17.9W) Stable", "Old Anorian: Minas Tirith Masters Tier - 6th Circle - (66.2S, 19.3W) Stable", 1);
NewEdge("Old Anorian: Minas Tirith Craftsmens Tier - 3rd Circle - (64.8S, 17.9W) Stable", "Old Anorian: Minas Tirith Masters Tier - 6th Circle - (66.2S, 19.3W) Stable", 2);

NewEdge("Old Anorian: Minas Tirith Players Tier - 4th Circle - (66.4S, 184W) Stable", "Old Anorien: Minas Tirith Main Gate (65.8S, 16.8W) Stable", 1);
NewEdge("Old Anorian: Minas Tirith Players Tier - 4th Circle - (66.4S, 184W) Stable", "Old Anorien: Minas Tirith Main Gate (65.8S, 16.8W) Stable", 2);
NewEdge("Old Anorian: Minas Tirith Players Tier - 4th Circle - (66.4S, 184W) Stable", "Old Anorian: Minas Tirith Soldiers Tier - 2nd Circle - (66.4S, 17.5W) Stable", 1);
NewEdge("Old Anorian: Minas Tirith Players Tier - 4th Circle - (66.4S, 184W) Stable", "Old Anorian: Minas Tirith Soldiers Tier - 2nd Circle - (66.4S, 17.5W) Stable", 2);
NewEdge("Old Anorian: Minas Tirith Players Tier - 4th Circle - (66.4S, 184W) Stable", "Old Anorian: Minas Tirith Craftsmens Tier - 3rd Circle - (64.8S, 17.9W) Stable", 1);
NewEdge("Old Anorian: Minas Tirith Players Tier - 4th Circle - (66.4S, 184W) Stable", "Old Anorian: Minas Tirith Craftsmens Tier - 3rd Circle - (64.8S, 17.9W) Stable", 2);
NewEdge("Old Anorian: Minas Tirith Players Tier - 4th Circle - (66.4S, 184W) Stable", "Old Anorian: Minas Tirith Sages Tier - 5th Circle - (65.0S, 18.6W) Stable", 1);
NewEdge("Old Anorian: Minas Tirith Players Tier - 4th Circle - (66.4S, 184W) Stable", "Old Anorian: Minas Tirith Sages Tier - 5th Circle - (65.0S, 18.6W) Stable", 2);
NewEdge("Old Anorian: Minas Tirith Players Tier - 4th Circle - (66.4S, 184W) Stable", "Old Anorian: Minas Tirith Masters Tier - 6th Circle - (66.2S, 19.3W) Stable", 1);
NewEdge("Old Anorian: Minas Tirith Players Tier - 4th Circle - (66.4S, 184W) Stable", "Old Anorian: Minas Tirith Masters Tier - 6th Circle - (66.2S, 19.3W) Stable", 2);

NewEdge("Old Anorian: Minas Tirith Sages Tier - 5th Circle - (65.0S, 18.6W) Stable", "Old Anorien: Minas Tirith Main Gate (65.8S, 16.8W) Stable", 1);
NewEdge("Old Anorian: Minas Tirith Sages Tier - 5th Circle - (65.0S, 18.6W) Stable", "Old Anorian: Minas Tirith Soldiers Tier - 2nd Circle - (66.4S, 17.5W) Stable", 1);
NewEdge("Old Anorian: Minas Tirith Sages Tier - 5th Circle - (65.0S, 18.6W) Stable", "Old Anorian: Minas Tirith Craftsmens Tier - 3rd Circle - (64.8S, 17.9W) Stable", 1);
NewEdge("Old Anorian: Minas Tirith Sages Tier - 5th Circle - (65.0S, 18.6W) Stable", "Old Anorian: Minas Tirith Players Tier - 4th Circle - (66.4S, 184W) Stable", 1);
NewEdge("Old Anorian: Minas Tirith Sages Tier - 5th Circle - (65.0S, 18.6W) Stable", "Old Anorian: Minas Tirith Masters Tier - 6th Circle - (66.2S, 19.3W) Stable", 1);

NewEdge("Old Anorian: Minas Tirith Masters Tier - 6th Circle - (66.2S, 19.3W) Stable", "Old Anorien: Minas Tirith Main Gate (65.8S, 16.8W) Stable", 1);
NewEdge("Old Anorian: Minas Tirith Masters Tier - 6th Circle - (66.2S, 19.3W) Stable", "Old Anorien: Minas Tirith Main Gate (65.8S, 16.8W) Stable", 2);
NewEdge("Old Anorian: Minas Tirith Masters Tier - 6th Circle - (66.2S, 19.3W) Stable", "Old Anorian: Minas Tirith Soldiers Tier - 2nd Circle - (66.4S, 17.5W) Stable", 1);
NewEdge("Old Anorian: Minas Tirith Masters Tier - 6th Circle - (66.2S, 19.3W) Stable", "Old Anorian: Minas Tirith Soldiers Tier - 2nd Circle - (66.4S, 17.5W) Stable", 2);
NewEdge("Old Anorian: Minas Tirith Masters Tier - 6th Circle - (66.2S, 19.3W) Stable", "Old Anorian: Minas Tirith Craftsmens Tier - 3rd Circle - (64.8S, 17.9W) Stable", 1);
NewEdge("Old Anorian: Minas Tirith Masters Tier - 6th Circle - (66.2S, 19.3W) Stable", "Old Anorian: Minas Tirith Craftsmens Tier - 3rd Circle - (64.8S, 17.9W) Stable", 2);
NewEdge("Old Anorian: Minas Tirith Masters Tier - 6th Circle - (66.2S, 19.3W) Stable", "Old Anorian: Minas Tirith Players Tier - 4th Circle - (66.4S, 184W) Stable", 1);
NewEdge("Old Anorian: Minas Tirith Masters Tier - 6th Circle - (66.2S, 19.3W) Stable", "Old Anorian: Minas Tirith Players Tier - 4th Circle - (66.4S, 184W) Stable", 2);
NewEdge("Old Anorian: Minas Tirith Masters Tier - 6th Circle - (66.2S, 19.3W) Stable", "Old Anorian: Minas Tirith Sages Tier - 5th Circle - (65.0S, 18.6W) Stable", 1);
NewEdge("Old Anorian: Minas Tirith Masters Tier - 6th Circle - (66.2S, 19.3W) Stable", "Old Anorian: Minas Tirith Sages Tier - 5th Circle - (65.0S, 18.6W) Stable", 2);

-- NewEdge("Anorien (After Battle): Osgiliath (63.0S, 6.5W) Stable", 1);
NewEdge("Old Anorien: Minas Tirith Main Gate (65.8S, 16.8W) Stable", "Bree-land: South Bree (31.9S, 50.4W) Stable", 1);
NewEdge("Old Anorien: Minas Tirith Main Gate (65.8S, 16.8W) Stable", "Central Gondor: East Pelargir (82.8S, 31.6W) Stable", 1);
NewEdge("Old Anorien: Minas Tirith Main Gate (65.8S, 16.8W) Stable", "Central Gondor: Ethring (72.2S, 50.1W) Stable", 1);
NewEdge("Old Anorien: Minas Tirith Main Gate (65.8S, 16.8W) Stable", "Central Gondor: Linhir (80.8S, 45.8W) Stable", 1);
NewEdge("Old Anorien: Minas Tirith Main Gate (65.8S, 16.8W) Stable", "Central Gondor: Ost Anglebed (79.1S, 39.0W) Stable", 1);
NewEdge("Old Anorien: Minas Tirith Main Gate (65.8S, 16.8W) Stable", "Central Gondor: West Pelargir (83.0S, 34.8W) Stable", 1);
NewEdge("Old Anorien: Minas Tirith Main Gate (65.8S, 16.8W) Stable", "Eastern Gondor: Arnach (76.3S, 24.4W) Stable", 1);
NewEdge("Old Anorien: Minas Tirith Main Gate (65.8S, 16.8W) Stable", "Eastern Gondor: Bar-Hurin (73.5S, 12.2W) Stable", 1);
NewEdge("Old Anorien: Minas Tirith Main Gate (65.8S, 16.8W) Stable", "Eastern Gondor: Faramir's Lookout (65.0S, 6.1W) Stable", 1);
NewEdge("Old Anorien: Minas Tirith Main Gate (65.8S, 16.8W) Stable", "Eastern Gondor: Glaniath (81.0S, 298W) Stable", 1);
NewEdge("Old Anorien: Minas Tirith Main Gate (65.8S, 16.8W) Stable", "Far Anorien: Ost Rimmon (46.8S, 36.4W) Stable", 1);
NewEdge("Old Anorien: Minas Tirith Main Gate (65.8S, 16.8W) Stable", "Far Anorien: War-Stead of the Rohirrim (45.1S, 29.2W) Stable", 1);
NewEdge("Old Anorien: Minas Tirith Main Gate (65.8S, 16.8W) Stable", "Moria: Twenty-first Hall (5.7S, 105.3W) Stable", 1);
NewEdge("Old Anorien: Minas Tirith Main Gate (65.8S, 16.8W) Stable", "Old Anorien: North Gate (59.5S, 17.5W) Stable", 1);
NewEdge("Old Anorien: Minas Tirith Main Gate (65.8S, 16.8W) Stable", "Old Anorien: North Gate (59.5S, 17.5W) Stable", 2);
NewEdge("Old Anorien: Minas Tirith Main Gate (65.8S, 16.8W) Stable", "West Rohan: Aldburg (68.7S, 63.9W) Stable", 1);
NewEdge("Old Anorien: Minas Tirith Main Gate (65.8S, 16.8W) Stable", "Western Gondor: Calembel (67.2S, 55.1W) Stable", 1);
NewEdge("Old Anorien: Minas Tirith Main Gate (65.8S, 16.8W) Stable", "Western Gondor: Dol Amroth (75.5S, 72.5W) Stable", 1);
NewEdge("Old Anorien: Minas Tirith Main Gate (65.8S, 16.8W) Stable", "Western Gondor: Morlad (56.9S, 67.5W) Stable", 1);
NewEdge("Old Anorien: Minas Tirith Main Gate (65.8S, 16.8W) Stable", "Western Gondor: Tadrent (74.0S, 62.4W) Stable", 1);
NewEdge("Old Anorien: Minas Tirith Main Gate (65.8S, 16.8W) Stable", "Old Anorien: Minas Tirith (65.4S, 16.7W) Milestone", 3);
NewEdge("Old Anorien: North Gate (59.5S, 17.5W) Stable", "Central Gondor: East Pelargir (82.8S, 31.6W) Stable", 1);
NewEdge("Old Anorien: North Gate (59.5S, 17.5W) Stable", "Old Anorien: Minas Tirith Main Gate (65.8S, 16.8W) Stable", 1);
NewEdge("Old Anorien: North Gate (59.5S, 17.5W) Stable", "Old Anorien: Minas Tirith Main Gate (65.8S, 16.8W) Stable", 2);
NewEdge("Old Anorien: North Gate (59.5S, 17.5W) Stable", "Western Gondor: Dol Amroth (75.5S, 72.5W) Stable", 1);
NewEdge("Old Anorien: Crithost (54.3S, 16.4W) Milestone", "Old Anorien: North Gate (59.5S, 17.5W) Stable", 2);

-- Shire Nodes & Paths
NewNode("Shire: Brockenborings (27.5S, 68.1W) Stable");
NewNode("Shire: Hobbiton (31.5S, 71.2W) Stable");
NewNode("Shire: Michel Delving (34.2S, 75.5W) Stable");
NewNode("Shire: Needlehole (27.9S, 76.1W) Stable");
NewNode("Shire: Stock (32.1S, 64.1W) Stable");
NewEdge("Shire: Brockenborings (27.5S, 68.1W) Stable", "Evendim: Oatbarton (23.2S, 67.3W) Stable", 1);
NewEdge("Shire: Brockenborings (27.5S, 68.1W) Stable", "Shire: Hobbiton (31.5S, 71.2W) Stable", 2);
NewEdge("Shire: Brockenborings (27.5S, 68.1W) Stable", "Shire: Stock (32.1S, 64.1W) Stable", 2);
NewEdge("Shire: Hobbiton (31.5S, 71.2W) Stable", "Shire: Brockenborings (27.5S, 68.1W) Stable", 2);
NewEdge("Shire: Hobbiton (31.5S, 71.2W) Stable", "Shire: Michel Delving (34.2S, 75.5W) Stable", 2);
NewEdge("Shire: Hobbiton (31.5S, 71.2W) Stable", "Shire: Needlehole (27.9S, 76.1W) Stable", 2);
NewEdge("Shire: Hobbiton (31.5S, 71.2W) Stable", "Shire: Stock (32.1S, 64.1W) Stable", 2);
NewEdge("Shire: Hobbiton (31.5S, 71.2W) Stable", "Bree-land: West Bree (29,5S, 52.6W) Stable", 2);
NewEdge("Shire: Michel Delving (34.2S, 75.5W) Stable", "Ered Luin: Celondim (28.1S, 92.4W) Stable", 1);
NewEdge("Shire: Michel Delving (34.2S, 75.5W) Stable", "Bree-land: Combe (28,6S, 49.5W) Stable", 1);
NewEdge("Shire: Michel Delving (34.2S, 75.5W) Stable", "Ettenmoors: Glan Vraig (21.S, 13.4W) Stable", 1);
NewEdge("Shire: Michel Delving (34.2S, 75.5W) Stable", "Shire: Hobbiton (31.5S, 71.2W) Stable", 2);
NewEdge("Shire: Michel Delving (34.2S, 75.5W) Stable", "Ered Luin: Thorin's Gate (15.0S, 103.6W) Stable", 1);
NewEdge("Shire: Michel Delving (34.2S, 75.5W) Stable", "Evendim: Tinnudir (12.4S, 67.2W) Stable", 1);
NewEdge("Shire: Michel Delving (34.2S, 75.5W) Stable", "Bree-land: West Bree (29,5S, 52.6W) Stable", 1);
NewEdge("Shire: Needlehole (27.9S, 76.1W) Stable", "Ered Luin: Duillond (24.6S, 93.1W) Stable", 2);
NewEdge("Shire: Needlehole (27.9S, 76.1W) Stable", "Shire: Hobbiton (31.5S, 71.2W) Stable", 2);
NewEdge("Shire: Stock (32.1S, 64.1W) Stable", "Shire: Brockenborings (27.5S, 68.1W) Stable", 2);
NewEdge("Shire: Stock (32.1S, 64.1W) Stable", "Bree-land: Buckland (32.9S, 61.8W) Stable", 2);
NewEdge("Shire: Stock (32.1S, 64.1W) Stable", "Shire: Hobbiton (31.5S, 71.2W) Stable", 2);
-- Shire Campsite Nodes
NewNode("Shire: The Hill (29.9S, 71.1W) Camp");
NewEdge("Shire: Hobbiton (31.5S, 71.2W) Stable", "Shire: The Hill (29.9S, 71.1W) Camp", 3);
-- Shire Milestones
NewNode("Shire: Brockenborings (27.4S, 67.7E) Milestone");
NewEdge("Shire: Brockenborings (27.5S, 68.1W) Stable", "Shire: Brockenborings (27.4S, 67.7E) Milestone", 3);
NewNode("Shire: Budgeford (31.3S, 66.1W) Milestone");
NewEdge("Shire: Stock (32.1S, 64.1W) Stable", "Shire: Budgeford (31.3S, 66.1W) Milestone", 3);
NewNode("Shire: Hobbiton (31.4S, 71.1W) Milestone");
NewEdge("Shire: Hobbiton (31.5S, 71.2W) Stable", "Shire: Hobbiton (31.4S, 71.1W) Milestone", 3);
NewNode("Shire: Little Delving (31.8S, 76.7W) Milestone");
NewEdge("Shire: Michel Delving (34.2S, 75.5W) Stable", "Shire: Little Delving (31.8S, 76.7W) Milestone", 3);
NewNode("Shire: Homesteads (36.5S, 73.1W) Milestone");
NewEdge("Shire: Michel Delving (34.2S, 75.5W) Stable", "Shire: Homesteads (36.5S, 73.1W) Milestone", 3);

-- The Wastes Nodes & Paths
NewNode("The Wastes: Camp of the Host (41.0S, 10.5W) Stable");
NewNode("The Wastes: Slag Hills (34.4S, 3.6W) Stable");
NewNode("The Wastes: Haerondir (36.6S, 8.9W) Milestone");
NewNode("The Wastes: Slag Hills (34.4S, 3.5W) Milestone/Horn");
NewEdge("The Wastes: Camp of the Host (41.0S, 10.5W) Stable", "Anorien After Battle: Aragorn's Pavailion (65.6S, 14.8W) Stable", 1);
NewEdge("The Wastes: Camp of the Host (41.0S, 10.5W) Stable", "Anorien After Battle: Aragorn's Pavailion (65.6S, 14.8W) Stable", 2);
NewEdge("The Wastes: Camp of the Host (41.0S, 10.5W) Stable", "North Ithilien: Henneth Annun (48.4S, 6.9W) Stable", 1);
NewEdge("The Wastes: Camp of the Host (41.0S, 10.5W) Stable", "North Ithilien: Henneth Annun (48.4S, 6.9W) Stable", 2);
NewEdge("The Wastes: Camp of the Host (41.0S, 10.5W) Stable", "Anorien After Battle: Osgiliath (63.0S, 6.5W) Stable", 1);
NewEdge("The Wastes: Camp of the Host (41.0S, 10.5W) Stable", "Anorien After Battle: Osgiliath (63.0S, 6.5W) Stable", 2);
NewEdge("The Wastes: Camp of the Host (41.0S, 10.5W) Stable", "Anorien After Battle: Minas Tirith (65.6S, 16.9W) Stable", 1);
NewEdge("The Wastes: Camp of the Host (41.0S, 10.5W) Stable", "Anorien After Battle: Minas Tirith (65.6S, 16.9W) Stable", 2);
NewEdge("The Wastes: Haerondir (36.6S, 8.9W) Milestone", "The Wastes: Camp of the Host (41.0S, 10.5W) Stable", 2);
NewEdge("The Wastes: Slag Hills (34.4S, 3.5W) Milestone/Horn", "The Wastes: Camp of the Host (41.0S, 10.5W) Stable", 2);
NewEdge("The Wastes: Slag Hills (34.4S, 3.6W) Stable", "Anorien After Battle: Osgiliath (63.0S, 6.5W) Stable", 1);
NewEdge("The Wastes: Slag Hills (34.4S, 3.6W) Stable", "Anorien After Battle: Osgiliath (63.0S, 6.5W) Stable", 2);
NewEdge("The Wastes: Slag Hills (34.4S, 3.6W) Stable", "Mordor: Udun Foothold (41.2S, 0.5W) Stable", 1);
NewEdge("The Wastes: Slag Hills (34.4S, 3.6W) Stable", "Mordor: Udun Foothold (41.2S, 0.5W) Stable", 2);
NewEdge("The Wastes: Slag Hills (34.4S, 3.6W) Stable", "The Wastes: Camp of the Host (41.0S, 10.5W) Stable", 1);
NewEdge("The Wastes: Slag Hills (34.4S, 3.6W) Stable", "The Wastes: Camp of the Host (41.0S, 10.5W) Stable", 2);


-- Special Event Nodes & Paths
NewNode("Special Event: Ered Luin Festival Announcer (18.4S, 98.1W) Stable");
NewNode("Special Event: Breeland Festival Announcer (29.5S, 52.7W) Stable");
NewNode("Special Event: Celondim Festival Announcer (28.1S, 92.4W) Stable");
NewNode("Special Event: Michel Delving Festival Announcer (34.2S, 75.5W) Stable");
NewNode("Special Event: Thorin's Gate Festival Announcer (15.0S, 103.6W) Stable");
NewNode("Special Event: Frostbluff Festival Announcer (11.9N, 95.1W) Stable");

NewEdge("Special Event: Breeland Festival Announcer (29.5S, 52.7W) Stable", "Special Event: Ered Luin Festival Announcer (18.4S, 98.1W) Stable", 1);
NewEdge("Special Event: Celondim Festival Announcer (28.1S, 92.4W) Stable", "Special Event: Ered Luin Festival Announcer (18.4S, 98.1W) Stable", 1);
NewEdge("Special Event: Michel Delving Festival Announcer (34.2S, 75.5W) Stable", "Special Event: Ered Luin Festival Announcer (18.4S, 98.1W) Stable", 1)
NewEdge("Special Event: Thorin's Gate Festival Announcer (15.0S, 103.6W) Stable", "Special Event: Ered Luin Festival Announcer (18.4S, 98.1W) Stable", 1);

NewEdge("Special Event: Breeland Festival Announcer (29.5S, 52.7W) Stable", "Bree-land: West Bree (29,5S, 52.6W) Stable", 2);
NewEdge("Special Event: Celondim Festival Announcer (28.1S, 92.4W) Stable", "Ered Luin: Celondim (28.1S, 92.4W) Stable", 2);
NewEdge("Special Event: Michel Delving Festival Announcer (34.2S, 75.5W) Stable", "Shire: Michel Delving (34.2S, 75.5W) Stable", 2);
NewEdge("Special Event: Thorin's Gate Festival Announcer (15.0S, 103.6W) Stable", "Ered Luin: Thorin's Gate (15.0S, 103.6W) Stable", 2);

NewEdge("Special Event: Breeland Festival Announcer (29.5S, 52.7W) Stable", "Special Event: Frostbluff Festival Announcer (11.9N, 95.1W) Stable", 1);
NewEdge("Special Event: Celondim Festival Announcer (28.1S, 92.4W) Stable", "Special Event: Frostbluff Festival Announcer (11.9N, 95.1W) Stable", 1);
NewEdge("Special Event: Michel Delving Festival Announcer (34.2S, 75.5W) Stable", "Special Event: Frostbluff Festival Announcer (11.9N, 95.1W) Stable", 1)
NewEdge("Special Event: Thorin's Gate Festival Announcer (15.0S, 103.6W) Stable", "Special Event: Frostbluff Festival Announcer (11.9N, 95.1W) Stable", 1);

-- Special Event Campsites
NewNode("Special Event: Ered Luin Treasure Camp (18.7S, 98.2W) Camp/Horn");
NewEdge("Special Event: Ered Luin Treasure Camp (18.7S, 98.2W) Camp/Horn", "Special Event: Ered Luin Festival Announcer (18.4S, 98.1W) Stable", 2);

-- Trollshaws Nodes & Paths
NewNode("Trollshaws: Barachen's Camp (34.0S, 20.2W) Stable");
NewEdge("Trollshaws: Barachen's Camp (34.0S, 20.2W) Stable", "Trollshaws: Thorenhad (31.7S, 15.0W) Stable", 2);
NewEdge("Trollshaws: Barachen's Camp (34.0S, 20.2W) Stable", "Trollshaws: Echad Candelleth (36.8S, 14.3W) Stable", 1);
NewNode("Trollshaws: Echad Candelleth (36.8S, 14.3W) Stable");
NewNode("Trollshaws: Rivendell (29.3S, 6.4W) Stable");
NewNode("Trollshaws: Thorenhad (31.7S, 15.0W) Stable");
NewEdge("Trollshaws: Echad Candelleth (36.8S, 14.3W) Stable", "Eregion: Echad Eregion (47.0S, 12.6W) Stable", 2);
NewEdge("Trollshaws: Echad Candelleth (36.8S, 14.3W) Stable", "Eregion: Gwingris (40.2S, 16.0W) Stable", 2);
NewEdge("Trollshaws: Echad Candelleth (36.8S, 14.3W) Stable", "Trollshaws: Rivendell (29.3S, 6.4W) Stable", 2);
NewEdge("Trollshaws: Echad Candelleth (36.8S, 14.3W) Stable", "Trollshaws: Thorenhad (31.7S, 15.0W) Stable", 2);
NewNode("Trollshaws: Nan Tornaeth (28.2S, 15.3W) Stable")
NewEdge("Trollshaws: Nan Tornaeth (28.2S, 15.3W) Stable", "Trollshaws: Thorenhad (31.7S, 15.0W) Stable", 1);
NewNode("Trollshaws: North Trollshaws (28.6S, 19.5W) Stable");
NewEdge("Trollshaws: North Trollshaws (28.6S, 19.5W) Stable", "Trollshaws: Barachen's Camp (34.0S, 20.2W) Stable", 1);
NewEdge("Trollshaws: Rivendell (29.3S, 6.4W) Stable", "Trollshaws: Echad Candelleth (36.8S, 14.3W) Stable", 2);
NewEdge("Trollshaws: Rivendell (29.3S, 6.4W) Stable", "Eregion: Echad Dunann (50.6S, 7.8W) Stable", 1);
NewEdge("Trollshaws: Rivendell (29.3S, 6.4W) Stable", "Eregion: Echad Eregion (47.0S, 12.6W) Stable", 1);
NewEdge("Trollshaws: Rivendell (29.3S, 6.4W) Stable", "Eregion: Echad Mirobel (52.3S, 17.0W) Stable", 1);
NewEdge("Trollshaws: Rivendell (29.3S, 6.4W) Stable", "North Downs: Esteldin (9.7S, 42.1W) Stable", 1);
NewEdge("Trollshaws: Rivendell (29.3S, 6.4W) Stable", "Ettenmoors: Glan Vraig (21.S, 13.4W) Stable", 1);
NewEdge("Trollshaws: Rivendell (29.3S, 6.4W) Stable", "Angmar: Gath Forthnir (10.4N, 24.0W) Stable", 1);
NewEdge("Trollshaws: Rivendell (29.3S, 6.4W) Stable", "Misty Mountains: Gloin's Camp (24.9S, 4.0W) Stable", 2);
NewEdge("Trollshaws: Rivendell (29.3S, 6.4W) Stable", "Eregion: Gwingris (40.2S, 16.0W) Stable", 1);
NewEdge("Trollshaws: Rivendell (29.3S, 6.4W) Stable", "Misty Mountains: Hrimbarg (24.4S, 7.0E) Stable", 1);
NewEdge("Trollshaws: Rivendell (29.3S, 6.4W) Stable", "Lothlorien: Inner Caras Galadhon (15.1S, 68.2W) Stable", 1);
NewEdge("Trollshaws: Rivendell (29.3S, 6.4W) Stable", "Enedwaith: Lhanuch (66.9S, 16.9W) Stable", 1);
NewEdge("Trollshaws: Rivendell (29.3S, 6.4W) Stable", "Lone Lands: Ost Guruth (32.1S, 29.8W) Stable", 1);
NewEdge("Trollshaws: Rivendell (29.3S, 6.4W) Stable", "Bree-land: South Bree (31.9S, 50.4W) Stable", 1);
NewEdge("Trollshaws: Rivendell (29.3S, 6.4W) Stable", "Forochel: Suri-kyla (19.1N, 70.8W) Stable", 1);
NewEdge("Trollshaws: Rivendell (29.3S, 6.4W) Stable", "Trollshaws: Thorenhad (31.7S, 15.0W) Stable", 2);
NewEdge("Trollshaws: Thorenhad (31.7S, 15.0W) Stable", "Trollshaws: Echad Candelleth (36.8S, 14.3W) Stable", 1);
NewEdge("Trollshaws: Thorenhad (31.7S, 15.0W) Stable", "Trollshaws: Echad Candelleth (36.8S, 14.3W) Stable", 2);
NewEdge("Trollshaws: Thorenhad (31.7S, 15.0W) Stable", "Lone Lands: Ost Guruth (32.1S, 29.8W) Stable", 2);
NewEdge("Trollshaws: Thorenhad (31.7S, 15.0W) Stable", "Trollshaws: Rivendell (29.3S, 6.4W) Stable", 2);
-- Trollshaws Campsites & Horns
NewNode("Trollshaws: Nan Tornaeth (28.2S, 15.3W) Camp");
NewEdge("Trollshaws: Nan Tornaeth (28.2S, 15.3W) Stable", "Trollshaws: Nan Tornaeth (28.2S, 15.3W) Camp", 3);
NewNode("Trollshaws: Ost Chall - Lost Temple (26.9S, 14.2W) Horn");
NewEdge("Trollshaws: Thorenhad (31.7S, 15.0W) Stable", "Trollshaws: Ost Chall - Lost Temple (26.9S, 14.2W) Horn", 2);
NewNode("Trollshaws: Echad Candelleth (37.1S, 14.1W) Camp");
NewEdge("Trollshaws: Echad Candelleth (36.8S, 14.3W) Stable", "Trollshaws: Echad Candelleth (37.1S, 14.1W) Camp", 3);
NewNode("Trollshaws: High Moor - Giant Valley (33.9S, 8.1W) Camp/Horn");
NewEdge("Trollshaws: Echad Candelleth (36.8S, 14.3W) Stable", "Trollshaws: High Moor - Giant Valley (33.9S, 8.1W) Camp/Horn", 3);
-- Trollshaws Milestones
NewNode("Trollshaws: Echad Candelleth (37.2S, 13.9W) Milestone");
NewEdge("Trollshaws: Echad Candelleth (36.8S, 14.3W) Stable", "Trollshaws: Echad Candelleth (37.2S, 13.9W) Milestone", 3);
NewNode("Trollshaws: Rivendell Valley (30.1S, 4.4W) Milestone");
NewEdge("Trollshaws: Rivendell (29.3S, 6.4W) Stable", "Trollshaws: Rivendell Valley (30.1S, 4.4W) Milestone", 3);
NewNode("Trollshaws: Thorenhad (31.7S, 15.0W) Milestone");
NewEdge("Trollshaws: Thorenhad (31.7S, 15.0W) Stable", "Trollshaws: Thorenhad (31.7S, 15.0W) Milestone", 3);

--Vales of Anduin
NewNode("Vales of Anduin: Beorninghus (13.5N, 53.3W) Stable");
NewNode("Vales of Anduin: Beorninghus (13.6N, 53.3W) Milestone");
NewEdge("Vales of Anduin: Beorninghus (13.5N, 53.3W) Stable", "Vales of Anduin: Beorninghus (13.6N, 53.3W) Milestone", 3);
NewEdge("Vales of Anduin: Beorninghus (13.5N, 53.3W) Stable", "Bree-land: South Bree (31.9S, 50.4W) Stable", 1);
NewEdge("Vales of Anduin: Beorninghus (13.5N, 53.3W) Stable", "Eryn Lasgalen: Felegoth (20.3N, 36.9W) Stable", 1);
NewEdge("Vales of Anduin: Beorninghus (13.5N, 53.3W) Stable", "Eryn Lasgalen: Felegoth (20.3N, 36.9W) Stable", 2);
NewNode("Vales of Anduin: The Carrock (13.1N, 58.4W) Eagle");
NewEdge("Vales of Anduin: The Carrock (13.1N, 58.4W) Eagle", "Vales of Anduin: Beorninghus (13.5N, 53.3W) Stable", 3);
NewEdge("Vales of Anduin: The Carrock (13.1N, 58.4W) Eagle", "Wells of Langflood: Lyndelby (26.3N, 66.6W) Fameldir", 1);
NewNode("Vales of Anduin: Vegbar (7.9N, 58.5W) Stable");
NewNode("Vales of Anduin: Vegbar (7.7N, 58.5W) Milestone");
NewEdge("Vales of Anduin: Vegbar (7.9N, 58.5W) Stable", "Vales of Anduin: Beorninghus (13.5N, 53.3W) Stable", 1);
NewEdge("Vales of Anduin: Vegbar (7.9N, 58.5W) Stable", "Vales of Anduin: Beorninghus (13.5N, 53.3W) Stable", 2);
NewEdge("Vales of Anduin: Vegbar (7.9N, 58.5W) Stable", "Vales of Anduin: Vegbar (7.7N, 58.5W) Milestone", 3);
NewEdge("Vales of Anduin: Vegbar (7.9N, 58.5W) Stable", "Misty Mountains: Hrimbarg (24.4S, 7.0E) Stable", 1);
NewEdge("Vales of Anduin: Vegbar (7.9N, 58.5W) Stable", "Misty Mountains: Hrimbarg (24.4S, 7.0E) Stable", 2);
NewEdge("Vales of Anduin: Vegbar (7.9N, 58.5W) Stable", "Trollshaws: Rivendell (29.3S, 6.4W) Stable", 1);
NewNode("Vales of Anduin: Hultvis (5.4N, 54.6W) Stable");
NewEdge("Vales of Anduin: Hultvis (5.4N, 54.6W) Stable", "Vales of Anduin: Beorninghus (13.5N, 53.3W) Stable", 1);
NewEdge("Vales of Anduin: Hultvis (5.4N, 54.6W) Stable", "Vales of Anduin: Beorninghus (13.5N, 53.3W) Stable", 2);
NewEdge("Vales of Anduin: Hultvis (5.4N, 54.6W) Stable", "Vales of Anduin: Vegbar (7.9N, 58.5W) Stable", 1);
NewEdge("Vales of Anduin: Hultvis (5.4N, 54.6W) Stable", "Vales of Anduin: Vegbar (7.9N, 58.5W) Stable", 1);
NewEdge("Vales of Anduin: Hultvis (5.4N, 54.6W) Stable", "Anorien After Battle: Osgiliath (63.0S, 6.5W) Stable", 1);
NewEdge("Vales of Anduin: Hultvis (5.4N, 54.6W) Stable", "Bree-land: South Bree (31.9S, 50.4W) Stable", 1);
NewEdge("Vales of Anduin: Hultvis (5.4N, 54.6W) Stable", "Dunland: Galtrev (80.0S, 16.7W) Stable", 1);
NewEdge("Vales of Anduin: Hultvis (5.4N, 54.6W) Stable", "Mordor: Magh Ashtu (53.1S, 10.5E) Stable", 1);
NewEdge("Vales of Anduin: Hultvis (5.4N, 54.6W) Stable", "Moria: Twenty-first Hall (5.7S, 105.3W) Stable", 1);
NewEdge("Vales of Anduin: Hultvis (5.4N, 54.6W) Stable", "East Rohan: Snowbourn (60.5S, 61.3W) Stable", 1);
NewEdge("Vales of Anduin: Hultvis (5.4N, 54.6W) Stable", "Eryn Lasgalen: Erebor (29.1N, 25.7W) Stable", 1);
NewEdge("Vales of Anduin: Hultvis (5.4N, 54.6W) Stable", "Ered Mithrin: Skarhald (34.7N, 45.4W) Stable", 1);
NewNode("Vales of Anduin: Hultvis (5.0N, 54.7W) Milestone");
NewEdge("Vales of Anduin: Hultvis (5.0N, 54.7W) Milestone", "Vales of Anduin: Hultvis (5.4N, 54.6W) Stable", 3);
NewNode("Vales of Anduin: Blomgard (1.6S, 55.6W) Stable");
NewEdge("Vales of Anduin: Blomgard (1.6S, 55.6W) Stable", "Vales of Anduin: Beorninghus (13.5N, 53.3W) Stable", 1);
NewEdge("Vales of Anduin: Blomgard (1.6S, 55.6W) Stable", "Vales of Anduin: Beorninghus (13.5N, 53.3W) Stable", 2);
NewEdge("Vales of Anduin: Blomgard (1.6S, 55.6W) Stable", "Vales of Anduin: Hultvis (5.4N, 54.6W) Stable", 1);
NewEdge("Vales of Anduin: Blomgard (1.6S, 55.6W) Stable", "Vales of Anduin: Hultvis (5.4N, 54.6W) Stable", 2);
NewEdge("Vales of Anduin: Blomgard (1.6S, 55.6W) Stable", "Vales of Anduin: Vegbar (7.9N, 58.5W) Stable", 1);
NewEdge("Vales of Anduin: Blomgard (1.6S, 55.6W) Stable", "Vales of Anduin: Vegbar (7.9N, 58.5W) Stable", 2);
NewNode("Vales of Anduin: Blomgard (1.6S, 55.2W) Milestone");
NewEdge("Vales of Anduin: Blomgard (1.6S, 55.2W) Milestone", "Vales of Anduin: Blomgard (1.6S, 55.6W) Stable", 3);
NewNode("Vales of Anduin: Arhaim (5.8S, 61.2W) Stable");
NewEdge("Vales of Anduin: Arhaim (5.8S, 61.2W) Stable", "Lothlorien: Inner Caras Galadhon (15.1S, 68.2W) Stable", 1);
NewEdge("Vales of Anduin: Arhaim (5.8S, 61.2W) Stable", "Lothlorien: Inner Caras Galadhon (15.1S, 68.2W) Stable", 2);
NewEdge("Vales of Anduin: Arhaim (5.8S, 61.2W) Stable", "Vales of Anduin: Beorninghus (13.5N, 53.3W) Stable", 1);
NewEdge("Vales of Anduin: Arhaim (5.8S, 61.2W) Stable", "Vales of Anduin: Beorninghus (13.5N, 53.3W) Stable", 2);
NewEdge("Vales of Anduin: Arhaim (5.8S, 61.2W) Stable", "Vales of Anduin: Blomgard (1.6S, 55.6W) Stable", 1);
NewEdge("Vales of Anduin: Arhaim (5.8S, 61.2W) Stable", "Vales of Anduin: Blomgard (1.6S, 55.6W) Stable", 2);
NewEdge("Vales of Anduin: Arhaim (5.8S, 61.2W) Stable", "Vales of Anduin: Hultvis (5.4N, 54.6W) Stable", 1);
NewEdge("Vales of Anduin: Arhaim (5.8S, 61.2W) Stable", "Vales of Anduin: Hultvis (5.4N, 54.6W) Stable", 2);
NewEdge("Vales of Anduin: Arhaim (5.8S, 61.2W) Stable", "Vales of Anduin: Vegbar (7.9N, 58.5W) Stable", 1);
NewEdge("Vales of Anduin: Arhaim (5.8S, 61.2W) Stable", "Vales of Anduin: Vegbar (7.9N, 58.5W) Stable", 2);
NewNode("Vales of Anduin: Arhaim (5.8S, 61.2W) Milestone");
NewEdge("Vales of Anduin: Arhaim (5.8S, 61.2W) Milestone", "Vales of Anduin: Arhaim (5.8S, 61.2W) Stable", 3);

-- Wells of Langflood Nodes & Stablemasters
NewNode("Wells of Langflood: Hlithseld (30.5N, 59.3W) Stable");
NewNode("Wells of Langflood: Hlithseld (30.4N, 59.2W) Milestone");
NewEdge("Wells of Langflood: Hlithseld (30.5N, 59.3W) Stable", "Wells of Langflood: Hlithseld (30.4N, 59.2W) Milestone", 3);
NewEdge("Wells of Langflood: Hlithseld (30.5N, 59.3W) Stable", "Ered Mithrin: Skarhald (34.7N, 45.4W) Stable", 1);
NewEdge("Wells of Langflood: Hlithseld (30.5N, 59.3W) Stable", "Ered Mithrin: Skarhald (34.7N, 45.4W) Stable", 2);
NewEdge("Wells of Langflood: Hlithseld (30.5N, 59.3W) Stable", "Wells of Langflood: Limlok (20.7N, 55.9W) Stable", 1);
NewEdge("Wells of Langflood: Hlithseld (30.5N, 59.3W) Stable", "Wells of Langflood: Limlok (20.7N, 55.9W) Stable", 2);
NewEdge("Wells of Langflood: Hlithseld (30.5N, 59.3W) Stable", "Wells of Langflood: Lyndelby (27.1N, 65.7W) Stable", 1);
NewEdge("Wells of Langflood: Hlithseld (30.5N, 59.3W) Stable", "Wells of Langflood: Thokvist (26.0N, 58.4W) Stable", 1);
NewEdge("Wells of Langflood: Hlithseld (30.5N, 59.3W) Stable", "Wells of Langflood: Thokvist (26.0N, 58.4W) Stable", 2);
NewNode("Wells of Langflood: Limlok (20.7N, 55.9W) Stable");
NewEdge("Wells of Langflood: Limlok (20.7N, 55.9W) Stable", "Vales of Anduin: Beorninghus (13.5N, 53.3W) Stable", 1);
NewEdge("Wells of Langflood: Limlok (20.7N, 55.9W) Stable", "Vales of Anduin: Beorninghus (13.5N, 53.3W) Stable", 2);
NewNode("Wells of Langflood: Limlok (20.9N, 56.0W) Milestone");
NewEdge("Wells of Langflood: Limlok (20.7N, 55.9W) Stable", "Wells of Langflood: Limlok (20.9N, 56.0W) Milestone", 3);
NewEdge("Wells of Langflood: Limlok (20.7N, 55.9W) Stable", "Wells of Langflood: Lyndelby (27.1N, 65.7W) Stable", 1);
NewEdge("Wells of Langflood: Limlok (20.7N, 55.9W) Stable", "Wells of Langflood: Hlithseld (30.5N, 59.3W) Stable", 1);
NewEdge("Wells of Langflood: Limlok (20.7N, 55.9W) Stable", "Wells of Langflood: Hlithseld (30.5N, 59.3W) Stable", 2);
NewEdge("Wells of Langflood: Limlok (20.7N, 55.9W) Stable", "Wells of Langflood: Thokvist (26.0N, 58.4W) Stable", 1);
NewEdge("Wells of Langflood: Limlok (20.7N, 55.9W) Stable", "Wells of Langflood: Thokvist (26.0N, 58.4W) Stable", 2);
NewNode("Wells of Langflood: Lyndelby (27.1N, 65.7W) Stable");
NewNode("Wells of Langflood: Lyndelby (26.6N, 65.4W) Milestone");
NewNode("Wells of Langflood: Lyndelby (26.3N, 66.6W) Fameldir");
NewEdge("Wells of Langflood: Lyndelby (27.1N, 65.7W) Stable", "Wells of Langflood: Lyndelby (26.6N, 65.4W) Milestone", 3);
NewEdge("Wells of Langflood: Lyndelby (27.1N, 65.7W) Stable", "Wells of Langflood: Lyndelby (26.3N, 66.6W) Fameldir", 3);
NewEdge("Wells of Langflood: Lyndelby (27.1N, 65.7W) Stable", "Wells of Langflood: Hlithseld (30.5N, 59.3W) Stable", 1);
NewEdge("Wells of Langflood: Lyndelby (27.1N, 65.7W) Stable", "Wells of Langflood: Limlok (20.7N, 55.9W) Stable", 1);
NewEdge("Wells of Langflood: Lyndelby (27.1N, 65.7W) Stable", "Wells of Langflood: Thokvist (26.0N, 58.4W) Stable", 1);
NewEdge("Wells of Langflood: Lyndelby (26.3N, 66.6W) Fameldir", "Vales of Anduin: The Carrock (13.1N, 58.4W) Eagle", 1);
NewNode("Wells of Langflood: Thokvist (26.0N, 58.4W) Stable");
NewEdge("Wells of Langflood: Thokvist (26.0N, 58.4W) Stable", "Wells of Langflood: Hlithseld (30.5N, 59.3W) Stable", 1);
NewEdge("Wells of Langflood: Thokvist (26.0N, 58.4W) Stable", "Wells of Langflood: Hlithseld (30.5N, 59.3W) Stable", 2);
NewEdge("Wells of Langflood: Thokvist (26.0N, 58.4W) Stable", "Wells of Langflood: Limlok (20.7N, 55.9W) Stable", 1);
NewEdge("Wells of Langflood: Thokvist (26.0N, 58.4W) Stable", "Wells of Langflood: Limlok (20.7N, 55.9W) Stable", 2);
NewEdge("Wells of Langflood: Thokvist (26.0N, 58.4W) Stable", "Wells of Langflood: Lyndelby (27.1N, 65.7W) Stable", 1);
NewNode("Wells of Langflood: Thokvist (26.0N, 58.4W) Milestone");
NewEdge("Wells of Langflood: Thokvist (26.0N, 58.4W) Stable", "Wells of Langflood: Thokvist (26.0N, 58.4W) Milestone", 3);

--Rohan Wildermore Nodes & Stablemasters
NewNode("Wildermore: Writhendowns (33.7S, 60.2W) Stable");
NewEdge("Wildermore: Writhendowns (33.7S, 60.2W) Stable", "East Rohan: Harwick (39.0S, 52.3W) Stable", 1);
NewEdge("Wildermore: Writhendowns (33.7S, 60.2W) Stable", "East Rohan: Harwick (39.0S, 52.3W) Stable", 2);
NewEdge("Wildermore: Writhendowns (33.7S, 60.2W) Stable", "Wildermore: Forlaw (39.4S, 60.9W) Stable", 1);
NewEdge("Wildermore: Writhendowns (33.7S, 60.2W) Stable", "Wildermore: Forlaw (39.4S, 60.9W) Stable", 2);
NewNode("Wildermore: Forlaw (39.4S, 60.9W) Stable");
NewEdge("Wildermore: Forlaw (39.4S, 60.9W) Stable", "Bree-land: South Bree (31.9S, 50.4W) Stable", 1);
NewEdge("Wildermore: Forlaw (39.4S, 60.9W) Stable", "Moria: Twenty-first Hall (5.7S, 105.3W) Stable", 1);
NewEdge("Wildermore: Forlaw (39.4S, 60.9W) Stable", "East Rohan: Harwick (39.0S, 52.3W) Stable", 1);
NewEdge("Wildermore: Forlaw (39.4S, 60.9W) Stable", "East Rohan: Snowbourn (60.5S, 61.3W) Stable", 1);
NewEdge("Wildermore: Forlaw (39.4S, 60.9W) Stable", "Wildermore: Balewood (35.4S, 69.9W) Stable", 1);
NewEdge("Wildermore: Forlaw (39.4S, 60.9W) Stable", "Wildermore: Balewood (35.4S, 69.9W) Stable", 2);
NewEdge("Wildermore: Forlaw (39.4S, 60.9W) Stable", "Wildermore: High Knolls (33.0S, 66.6W) Stable", 1);
NewEdge("Wildermore: Forlaw (39.4S, 60.9W) Stable", "Wildermore: High Knolls (33.0S, 66.6W) Stable", 2);
NewEdge("Wildermore: Forlaw (39.4S, 60.9W) Stable", "Wildermore: Whitshaws (38.7S, 67.2W) Stable", 1);
NewEdge("Wildermore: Forlaw (39.4S, 60.9W) Stable", "Wildermore: Whitshaws (38.7S, 67.2W) Stable", 2);
NewEdge("Wildermore: Forlaw (39.4S, 60.9W) Stable", "Wildermore: Writhendowns (33.7S, 60.2W) Stable", 1);
NewEdge("Wildermore: Forlaw (39.4S, 60.9W) Stable", "Wildermore: Writhendowns (33.7S, 60.2W) Stable", 2);
NewNode("Wildermore: Balewood (35.4S, 69.9W) Stable");
NewEdge("Wildermore: Balewood (35.4S, 69.9W) Stable", "Wildermore: Forlaw (39.4S, 60.9W) Stable", 1);
NewEdge("Wildermore: Balewood (35.4S, 69.9W) Stable", "Wildermore: Forlaw (39.4S, 60.9W) Stable", 2);
NewEdge("Wildermore: Balewood (35.4S, 69.9W) Stable", "Wildermore: High Knolls (33.0S, 66.6W) Stable", 1);
NewEdge("Wildermore: Balewood (35.4S, 69.9W) Stable", "Wildermore: High Knolls (33.0S, 66.6W) Stable", 2);
NewEdge("Wildermore: Balewood (35.4S, 69.9W) Stable", "Wildermore: High Knolls (33.0S, 66.6W) Stable", 1);
NewEdge("Wildermore: Balewood (35.4S, 69.9W) Stable", "Wildermore: High Knolls (33.0S, 66.6W) Stable", 2);
NewNode("Wildermore: High Knolls (33.0S, 66.6W) Stable");
NewEdge("Wildermore: High Knolls (33.0S, 66.6W) Stable", "Wildermore: Balewood (35.4S, 69.9W) Stable", 1);
NewEdge("Wildermore: High Knolls (33.0S, 66.6W) Stable", "Wildermore: Balewood (35.4S, 69.9W) Stable", 2);
NewEdge("Wildermore: High Knolls (33.0S, 66.6W) Stable", "Wildermore: Forlaw (39.4S, 60.9W) Stable", 1);
NewEdge("Wildermore: High Knolls (33.0S, 66.6W) Stable", "Wildermore: Forlaw (39.4S, 60.9W) Stable", 2);
NewEdge("Wildermore: High Knolls (33.0S, 66.6W) Stable", "Wildermore: Whitshaws (38.7S, 67.2W) Stable", 1);
NewEdge("Wildermore: High Knolls (33.0S, 66.6W) Stable", "Wildermore: Whitshaws (38.7S, 67.2W) Stable", 2);
NewNode("Wildermore: Whitshaws (38.7S, 67.2W) Stable");
NewEdge("Wildermore: Whitshaws (38.7S, 67.2W) Stable", "Wildermore: Balewood (35.4S, 69.9W) Stable", 1);
NewEdge("Wildermore: Whitshaws (38.7S, 67.2W) Stable", "Wildermore: Balewood (35.4S, 69.9W) Stable", 2);
NewEdge("Wildermore: Whitshaws (38.7S, 67.2W) Stable", "Wildermore: Forlaw (39.4S, 60.9W) Stable", 1);
NewEdge("Wildermore: Whitshaws (38.7S, 67.2W) Stable", "Wildermore: Forlaw (39.4S, 60.9W) Stable", 2);
NewEdge("Wildermore: Whitshaws (38.7S, 67.2W) Stable", "Wildermore: Forlaw (39.4S, 60.9W) Stable", 1);
NewEdge("Wildermore: Whitshaws (38.7S, 67.2W) Stable", "Wildermore: Forlaw (39.4S, 60.9W) Stable", 2);
-- Wildermore Milestones
NewNode("Wildermore: Forlaw (39.5S, 60.8W) Milestone");
NewEdge("Wildermore: Forlaw (39.5S, 60.8W) Milestone", "Wildermore: Forlaw (39.4S, 60.9W) Stable", 2);
NewNode("Wildermore: Balewood (35.4S, 69.8W) Milestone");
NewEdge("Wildermore: Balewood (35.4S, 69.8W) Milestone", "Wildermore: Balewood (35.4S, 69.9W) Stable", 2);
NewNode("Wildermore: Writhendowns (33.8S, 60.1W) Milestone");
NewEdge("Wildermore: Writhendowns (33.8S, 60.1W) Milestone", "Wildermore: Writhendowns (33.7S, 60.2W) Stable", 2);

-- Western Gondor Nodes & Paths
NewNode("Western Gondor: Calembel (67.2S, 55.1W) Stable");
NewNode("Western Gondor: Dol Amroth (75.5S, 72.5W) Stable");
NewNode("Western Gondor: Morlad (56.9S, 67.5W) Stable");
NewNode("Western Gondor: Tadrent (74.0S, 62.4W) Stable");
NewEdge("Western Gondor: Dol Amroth (75.5S, 72.5W) Stable", "Western Gondor: Calembel (67.2S, 55.1W) Stable", 1);
NewEdge("Western Gondor: Dol Amroth (75.5S, 72.5W) Stable", "Western Gondor: Calembel (67.2S, 55.1W) Stable", 2);
NewEdge("Western Gondor: Dol Amroth (75.5S, 72.5W) Stable", "Western Gondor: Morlad (56.9S, 67.5W) Stable", 1);
NewEdge("Western Gondor: Dol Amroth (75.5S, 72.5W) Stable", "Western Gondor: Morlad (56.9S, 67.5W) Stable", 2);
NewEdge("Western Gondor: Dol Amroth (75.5S, 72.5W) Stable", "Western Gondor: Tadrent (74.0S, 62.4W) Stable", 1);
NewEdge("Western Gondor: Dol Amroth (75.5S, 72.5W) Stable", "Western Gondor: Tadrent (74.0S, 62.4W) Stable", 2);
NewEdge("Western Gondor: Dol Amroth (75.5S, 72.5W) Stable", "Bree-land: South Bree (31.9S, 50.4W) Stable", 1);
NewEdge("Western Gondor: Dol Amroth (75.5S, 72.5W) Stable", "Moria: Twenty-first Hall (5.7S, 105.3W) Stable", 1);
NewEdge("Western Gondor: Dol Amroth (75.5S, 72.5W) Stable", "West Rohan: Aldburg (68.7S, 63.9W) Stable", 1);
NewEdge("Western Gondor: Morlad (56.9S, 67.5W) Stable", "West Rohan: Underharrow (67.3S, 73.7W) Stable", 1);
NewEdge("Western Gondor: Morlad (56.9S, 67.5W) Stable", "Western Gondor: Calembel (67.2S, 55.1W) Stable", 1);
NewEdge("Western Gondor: Morlad (56.9S, 67.5W) Stable", "Western Gondor: Calembel (67.2S, 55.1W) Stable", 2);
NewEdge("Western Gondor: Morlad (56.9S, 67.5W) Stable", "Western Gondor: Tadrent (74.0S, 62.4W) Stable", 1);
NewEdge("Western Gondor: Morlad (56.9S, 67.5W) Stable", "Western Gondor: Tadrent (74.0S, 62.4W) Stable", 2);
-- Western Gondor Campsites
NewNode("Western Gondor: Calembel (70.3S, 57.8W) Camp");
NewNode("Western Gondor: Edhellond (70.5S, 66.6W) Camp");
NewNode("Western Gondor: Morlad (61.0S, 69.6W) Camp");
NewEdge("Western Gondor: Morlad (61.0S, 69.6W) Camp", "Western Gondor: Morlad (56.9S, 67.5W) Stable", 2);
NewEdge("Western Gondor: Edhellond (70.5S, 66.6W) Camp", "Western Gondor: Tadrent (74.0S, 62.4W) Stable", 2);
NewEdge("Western Gondor: Calembel (70.3S, 57.8W) Camp", "Western Gondor: Calembel (67.2S, 55.1W) Stable", 2);
-- Western Gondor Milestones
NewNode("Western Gondor: Calembel (67.0S, 55.9W) Milestone");
NewEdge("Western Gondor: Calembel (67.0S, 55.9W) Milestone",  "Western Gondor: Calembel (67.2S, 55.1W) Stable", 2);
NewNode("Western Gondor: Blackroot Vale/Morlad (56.9S, 67.5W) Milestone");
NewEdge("Western Gondor: Blackroot Vale/Morlad (56.9S, 67.5W) Milestone", "Western Gondor: Morlad (56.9S, 67.5W) Stable", 2);
NewNode("Western Gondor: Blackroot Vale (58.6S, 68.6W) Milestone");
NewEdge("Western Gondor: Blackroot Vale (58.6S, 68.6W) Milestone", "Western Gondor: Morlad (56.9S, 67.5W) Stable", 2);
NewNode("Western Gondor: Blackroot Vale (58.2S, 63.0W) Milestone");
NewEdge("Western Gondor: Blackroot Vale (58.2S, 63.0W) Milestone", "Western Gondor: Morlad (56.9S, 67.5W) Stable", 2);
NewNode("Western Gondor: Dol Amroth (75.4S, 72.1W) Milestone");
NewEdge("Western Gondor: Dol Amroth (75.4S, 72.1W) Milestone", "Western Gondor: Dol Amroth (75.5S, 72.5W) Stable", 2);
NewNode("Western Gondor: Tadrent (74.1S, 62.3W) Milestone");
NewEdge("Western Gondor: Tadrent (74.1S, 62.3W) Milestone", "Western Gondor: Tadrent (74.0S, 62.4W) Stable", 2);
-- Western Gondor Travel to Homestead
NewNode("Western Gondor: Cape of Belfalas (84.1S, 69.2W) Travel To Dol Amroth");
NewNode("Western Gondor: Dol Amroth (75.5S, 72.4W) Travel To Cape of Belfalas");
NewEdge("Western Gondor: Dol Amroth (75.5S, 72.5W) Stable", "Western Gondor: Dol Amroth (75.5S, 72.4W) Travel To Cape of Belfalas", 1);
NewEdge("Western Gondor: Cape of Belfalas (84.1S, 69.2W) Travel To Dol Amroth", "Western Gondor: Dol Amroth (75.5S, 72.4W) Travel To Cape of Belfalas", 1);

-- West Rohan Nodes & Paths
NewNode("West Rohan: Aldburg (68.7S, 63.9W) Stable");
NewEdge("West Rohan: Aldburg (68.7S, 63.9W) Stable", "Bree-land: South Bree (31.9S, 50.4W) Stable", 1);
NewEdge("West Rohan: Aldburg (68.7S, 63.9W) Stable", "Moria: Twenty-first Hall (5.7S, 105.3W) Stable", 1);
NewEdge("West Rohan: Aldburg (68.7S, 63.9W) Stable", "West Rohan: Beaconwatch (69.6S, 57.4W) Stable", 1);
NewEdge("West Rohan: Aldburg (68.7S, 63.9W) Stable", "West Rohan: Beaconwatch (69.6S, 57.4W) Stable", 2);
NewEdge("West Rohan: Aldburg (68.7S, 63.9W) Stable", "West Rohan: Edoras (60.8S, 74.2W) Stable", 1);
NewEdge("West Rohan: Aldburg (68.7S, 63.9W) Stable", "West Rohan: Edoras (60.8S, 74.2W) Stable", 2);
NewEdge("West Rohan: Aldburg (68.7S, 63.9W) Stable", "West Rohan: Fenmarch (66.5S, 57.8W) Stable", 1);
NewEdge("West Rohan: Aldburg (68.7S, 63.9W) Stable", "West Rohan: Fenmarch (66.5S, 57.8W) Stable", 2);
NewEdge("West Rohan: Aldburg (68.7S, 63.9W) Stable", "West Rohan: Helm's Deep (63.7S, 89.5W) Stable", 1);
NewEdge("West Rohan: Aldburg (68.7S, 63.9W) Stable", "West Rohan: Helm's Deep (63.7S, 89.5W) Stable", 2);
NewEdge("West Rohan: Aldburg (68.7S, 63.9W) Stable", "West Rohan: Stoke (49.3S, 69.6W) Stable", 1);
NewEdge("West Rohan: Aldburg (68.7S, 63.9W) Stable", "West Rohan: Stoke (49.3S, 69.6W) Stable", 2);
NewEdge("West Rohan: Aldburg (68.7S, 63.9W) Stable", "West Rohan: Woodhurst (47.6S, 79.1W) Stable", 1);
NewEdge("West Rohan: Aldburg (68.7S, 63.9W) Stable", "West Rohan: Woodhurst (47.6S, 79.1W) Stable", 2);
NewEdge("West Rohan: Aldburg (68.7S, 63.9W) Stable", "Nan Curunir: Isengard (47.7S, 89.7W) Stable", 1);
NewNode("West Rohan: Beaconwatch (69.6S, 57.4W) Stable");
NewEdge("West Rohan: Beaconwatch (69.6S, 57.4W) Stable", "West Rohan: Aldburg (68.7S, 63.9W) Stable", 1);
NewEdge("West Rohan: Beaconwatch (69.6S, 57.4W) Stable", "West Rohan: Aldburg (68.7S, 63.9W) Stable", 2);
NewEdge("West Rohan: Beaconwatch (69.6S, 57.4W) Stable", "West Rohan: Fenmarch (66.5S, 57.8W) Stable", 1);
NewEdge("West Rohan: Beaconwatch (69.6S, 57.4W) Stable", "West Rohan: Fenmarch (66.5S, 57.8W) Stable", 2);
NewNode("West Rohan: Brockbridge (50.8S, 77.7W) Stable");
NewEdge("West Rohan: Brockbridge (50.8S, 77.7W) Stable", "West Rohan: Gapholt (53.7S, 83.7W) Stable", 1);
NewEdge("West Rohan: Brockbridge (50.8S, 77.7W) Stable", "West Rohan: Gapholt (53.7S, 83.7W) Stable", 2);
NewEdge("West Rohan: Brockbridge (50.8S, 77.7W) Stable", "West Rohan: Woodhurst (47.6S, 79.1W) Stable", 1);
NewEdge("West Rohan: Brockbridge (50.8S, 77.7W) Stable", "West Rohan: Woodhurst (47.6S, 79.1W) Stable", 2);
NewNode("West Rohan: Entwade (50.0S, 65.8W) Stable");
NewEdge("West Rohan: Entwade (50.0S, 65.8W) Stable", "East Rohan: Snowbourn (60.5S, 61.3W) Stable", 1);
NewEdge("West Rohan: Entwade (50.0S, 65.8W) Stable", "East Rohan: Snowbourn (60.5S, 61.3W) Stable", 2);
NewEdge("West Rohan: Entwade (50.0S, 65.8W) Stable", "West Rohan: Edoras (60.8S, 74.2W) Stable", 1);
NewEdge("West Rohan: Entwade (50.0S, 65.8W) Stable", "West Rohan: Edoras (60.8S, 74.2W) Stable", 2);
NewEdge("West Rohan: Entwade (50.0S, 65.8W) Stable", "West Rohan: Middlemead (53.7S, 72.5W) Stable", 1);
NewEdge("West Rohan: Entwade (50.0S, 65.8W) Stable", "West Rohan: Middlemead (53.7S, 72.5W) Stable", 2);
NewEdge("West Rohan: Entwade (50.0S, 65.8W) Stable", "West Rohan: Underharrow (67.3S, 73.7W) Stable", 1);
NewEdge("West Rohan: Entwade (50.0S, 65.8W) Stable", "West Rohan: Underharrow (67.3S, 73.7W) Stable", 2);
NewNode("West Rohan: Edoras (60.8S, 74.2W) Stable")
NewEdge("West Rohan: Edoras (60.8S, 74.2W) Stable", "West Rohan: Entwade (50.0S, 65.8W) Stable", 1);
NewEdge("West Rohan: Edoras (60.8S, 74.2W) Stable", "West Rohan: Entwade (50.0S, 65.8W) Stable", 2);
NewEdge("West Rohan: Edoras (60.8S, 74.2W) Stable", "West Rohan: Helm's Deep (63.7S, 89.5W) Stable", 1);
NewEdge("West Rohan: Edoras (60.8S, 74.2W) Stable", "West Rohan: Helm's Deep (63.7S, 89.5W) Stable", 2);
NewEdge("West Rohan: Edoras (60.8S, 74.2W) Stable", "West Rohan: Middlemead (53.7S, 72.5W) Stable", 1);
NewEdge("West Rohan: Edoras (60.8S, 74.2W) Stable", "West Rohan: Middlemead (53.7S, 72.5W) Stable", 2);
NewEdge("West Rohan: Edoras (60.8S, 74.2W) Stable", "West Rohan: Aldburg (68.7S, 63.9W) Stable", 1);
NewEdge("West Rohan: Edoras (60.8S, 74.2W) Stable", "West Rohan: Aldburg (68.7S, 63.9W) Stable", 2);
NewEdge("West Rohan: Edoras (60.8S, 74.2W) Stable", "West Rohan: Stoke (49.3S, 69.6W) Stable", 1);
NewEdge("West Rohan: Edoras (60.8S, 74.2W) Stable", "West Rohan: Stoke (49.3S, 69.6W) Stable", 2);
NewEdge("West Rohan: Edoras (60.8S, 74.2W) Stable", "West Rohan: Underharrow (67.3S, 73.7W) Stable", 1);
NewEdge("West Rohan: Edoras (60.8S, 74.2W) Stable", "West Rohan: Underharrow (67.3S, 73.7W) Stable", 2);
NewEdge("West Rohan: Edoras (60.8S, 74.2W) Stable", "West Rohan: Woodhurst (47.6S, 79.1W) Stable", 1);
NewEdge("West Rohan: Edoras (60.8S, 74.2W) Stable", "West Rohan: Woodhurst (47.6S, 79.1W) Stable", 2);
NewNode("West Rohan: Fenmarch (66.5S, 57.8W) Stable");
NewEdge("West Rohan: Fenmarch (66.5S, 57.8W) Stable", "West Rohan: Aldburg (68.7S, 63.9W) Stable", 1);
NewEdge("West Rohan: Fenmarch (66.5S, 57.8W) Stable", "West Rohan: Aldburg (68.7S, 63.9W) Stable", 2);
NewEdge("West Rohan: Fenmarch (66.5S, 57.8W) Stable", "West Rohan: Beaconwatch (69.6S, 57.4W) Stable", 1);
NewEdge("West Rohan: Fenmarch (66.5S, 57.8W) Stable", "West Rohan: Beaconwatch (69.6S, 57.4W) Stable", 2);
NewNode("West Rohan: Gapholt (53.7S, 83.7W) Stable");
NewEdge("West Rohan: Gapholt (53.7S, 83.7W) Stable", "West Rohan: Brockbridge (50.8S, 77.7W) Stable", 1);
NewEdge("West Rohan: Gapholt (53.7S, 83.7W) Stable", "West Rohan: Brockbridge (50.8S, 77.7W) Stable", 2);
NewNode("West Rohan: Grimslade (62.3S, 82.0W) Stable");
NewEdge("West Rohan: Grimslade (62.3S, 82.0W) Stable", "West Rohan: Helm's Deep (63.7S, 89.5W) Stable", 1);
NewEdge("West Rohan: Grimslade (62.3S, 82.0W) Stable", "West Rohan: Helm's Deep (63.7S, 89.5W) Stable", 2);
NewNode("West Rohan: Helm's Deep (63.7S, 89.5W) Stable");
NewEdge("West Rohan: Helm's Deep (63.7S, 89.5W) Stable", "Bree-land: South Bree (31.9S, 50.4W) Stable", 1);
NewEdge("West Rohan: Helm's Deep (63.7S, 89.5W) Stable", "Moria: Twenty-first Hall (5.7S, 105.3W) Stable", 1);
NewEdge("West Rohan: Helm's Deep (63.7S, 89.5W) Stable", "West Rohan: Aldburg (68.7S, 63.9W) Stable", 1);
NewEdge("West Rohan: Helm's Deep (63.7S, 89.5W) Stable", "West Rohan: Aldburg (68.7S, 63.9W) Stable", 2);
NewEdge("West Rohan: Helm's Deep (63.7S, 89.5W) Stable", "West Rohan: Edoras (60.8S, 74.2W) Stable", 1);
NewEdge("West Rohan: Helm's Deep (63.7S, 89.5W) Stable", "West Rohan: Edoras (60.8S, 74.2W) Stable", 2);
NewEdge("West Rohan: Helm's Deep (63.7S, 89.5W) Stable", "West Rohan: Grimslade (62.3S, 82.0W) Stable", 1);
NewEdge("West Rohan: Helm's Deep (63.7S, 89.5W) Stable", "West Rohan: Grimslade (62.3S, 82.0W) Stable", 2);
NewEdge("West Rohan: Helm's Deep (63.7S, 89.5W) Stable", "West Rohan: Stoke (49.3S, 69.6W) Stable", 1);
NewEdge("West Rohan: Helm's Deep (63.7S, 89.5W) Stable", "West Rohan: Stoke (49.3S, 69.6W) Stable", 2);
NewEdge("West Rohan: Helm's Deep (63.7S, 89.5W) Stable", "West Rohan: Woodhurst (47.6S, 79.1W) Stable", 1);
NewEdge("West Rohan: Helm's Deep (63.7S, 89.5W) Stable", "West Rohan: Woodhurst (47.6S, 79.1W) Stable", 2);
NewEdge("West Rohan: Helm's Deep (63.7S, 89.5W) Stable", "Nan Curunir: Isengard (47.7S, 89.7W) Stable", 1);
NewNode("West Rohan: Middlemead (53.7S, 72.5W) Stable");
NewEdge("West Rohan: Middlemead (53.7S, 72.5W) Stable", "West Rohan: Entwade (50.0S, 65.8W) Stable", 1);
NewEdge("West Rohan: Middlemead (53.7S, 72.5W) Stable", "West Rohan: Entwade (50.0S, 65.8W) Stable", 2);
NewEdge("West Rohan: Middlemead (53.7S, 72.5W) Stable", "West Rohan: Edoras (60.8S, 74.2W) Stable", 1);
NewEdge("West Rohan: Middlemead (53.7S, 72.5W) Stable", "West Rohan: Edoras (60.8S, 74.2W) Stable", 2);
NewEdge("West Rohan: Middlemead (53.7S, 72.5W) Stable", "West Rohan: Underharrow (67.3S, 73.7W) Stable", 1);
NewEdge("West Rohan: Middlemead (53.7S, 72.5W) Stable", "West Rohan: Underharrow (67.3S, 73.7W) Stable", 2);
NewNode("West Rohan: Oserley (46.0S, 67.0W) Stable");
NewEdge("West Rohan: Oserley (46.0S, 67.0W) Stable", "West Rohan: Stoke (49.3S, 69.6W) Stable", 1);
NewEdge("West Rohan: Oserley (46.0S, 67.0W) Stable", "West Rohan: Stoke (49.3S, 69.6W) Stable", 2);
NewNode("West Rohan: Stoke (49.3S, 69.6W) Stable");
NewEdge("West Rohan: Stoke (49.3S, 69.6W) Stable", "West Rohan: Aldburg (68.7S, 63.9W) Stable", 1);
NewEdge("West Rohan: Stoke (49.3S, 69.6W) Stable", "West Rohan: Aldburg (68.7S, 63.9W) Stable", 2);
NewEdge("West Rohan: Stoke (49.3S, 69.6W) Stable", "West Rohan: Edoras (60.8S, 74.2W) Stable", 1);
NewEdge("West Rohan: Stoke (49.3S, 69.6W) Stable", "West Rohan: Edoras (60.8S, 74.2W) Stable", 2);
NewEdge("West Rohan: Stoke (49.3S, 69.6W) Stable", "West Rohan: Helm's Deep (63.7S, 89.5W) Stable", 1);
NewEdge("West Rohan: Stoke (49.3S, 69.6W) Stable", "West Rohan: Helm's Deep (63.7S, 89.5W) Stable", 2);
NewEdge("West Rohan: Stoke (49.3S, 69.6W) Stable", "West Rohan: Oserley (46.0S, 67.0W) Stable", 1);
NewEdge("West Rohan: Stoke (49.3S, 69.6W) Stable", "West Rohan: Oserley (46.0S, 67.0W) Stable", 2);
NewEdge("West Rohan: Stoke (49.3S, 69.6W) Stable", "West Rohan: Woodhurst (47.6S, 79.1W) Stable", 1);
NewEdge("West Rohan: Stoke (49.3S, 69.6W) Stable", "West Rohan: Woodhurst (47.6S, 79.1W) Stable", 2);
NewNode("West Rohan: Underharrow (67.3S, 73.7W) Stable");
NewEdge("West Rohan: Underharrow (67.3S, 73.7W) Stable", "West Rohan: Entwade (50.0S, 65.8W) Stable", 1);
NewEdge("West Rohan: Underharrow (67.3S, 73.7W) Stable", "West Rohan: Entwade (50.0S, 65.8W) Stable", 2);
NewEdge("West Rohan: Underharrow (67.3S, 73.7W) Stable", "West Rohan: Edoras (60.8S, 74.2W) Stable", 1);
NewEdge("West Rohan: Underharrow (67.3S, 73.7W) Stable", "West Rohan: Edoras (60.8S, 74.2W) Stable", 2);
NewEdge("West Rohan: Underharrow (67.3S, 73.7W) Stable", "West Rohan: Middlemead (53.7S, 72.5W) Stable", 1);
NewEdge("West Rohan: Underharrow (67.3S, 73.7W) Stable", "West Rohan: Middlemead (53.7S, 72.5W) Stable", 2);
NewNode("West Rohan: Woodhurst (47.6S, 79.1W) Stable");
NewEdge("West Rohan: Woodhurst (47.6S, 79.1W) Stable", "West Rohan: Aldburg (68.7S, 63.9W) Stable", 1);
NewEdge("West Rohan: Woodhurst (47.6S, 79.1W) Stable", "West Rohan: Aldburg (68.7S, 63.9W) Stable", 2);
NewEdge("West Rohan: Woodhurst (47.6S, 79.1W) Stable", "West Rohan: Brockbridge (50.8S, 77.7W) Stable", 1);
NewEdge("West Rohan: Woodhurst (47.6S, 79.1W) Stable", "West Rohan: Brockbridge (50.8S, 77.7W) Stable", 2);
NewEdge("West Rohan: Woodhurst (47.6S, 79.1W) Stable", "West Rohan: Edoras (60.8S, 74.2W) Stable", 1);
NewEdge("West Rohan: Woodhurst (47.6S, 79.1W) Stable", "West Rohan: Edoras (60.8S, 74.2W) Stable", 2);
NewEdge("West Rohan: Woodhurst (47.6S, 79.1W) Stable", "West Rohan: Gapholt (53.7S, 83.7W) Stable", 1);
NewEdge("West Rohan: Woodhurst (47.6S, 79.1W) Stable", "West Rohan: Gapholt (53.7S, 83.7W) Stable", 2);
NewEdge("West Rohan: Woodhurst (47.6S, 79.1W) Stable", "West Rohan: Helm's Deep (63.7S, 89.5W) Stable", 1);
NewEdge("West Rohan: Woodhurst (47.6S, 79.1W) Stable", "West Rohan: Helm's Deep (63.7S, 89.5W) Stable", 2);
NewEdge("West Rohan: Woodhurst (47.6S, 79.1W) Stable", "West Rohan: Stoke (49.3S, 69.6W) Stable", 1);
NewEdge("West Rohan: Woodhurst (47.6S, 79.1W) Stable", "West Rohan: Stoke (49.3S, 69.6W) Stable", 2);
-- West Rohan Milestones
NewNode("West Rohan: Aldburg (68.7S, 63.9W) Milestone");
NewEdge("West Rohan: Aldburg (68.7S, 63.9W) Milestone", "West Rohan: Aldburg (68.7S, 63.9W) Stable", 2);
NewNode("West Rohan: Beaconwatch (69.5S, 57.1W) Milestone");
NewEdge("West Rohan: Beaconwatch (69.5S, 57.1W) Milestone", "West Rohan: Beaconwatch (69.6S, 57.4W) Stable", 2);
NewNode("West Rohan: Grimslade (62.5S, 82,1W) Milestone");
NewNode("West Rohan: Dunharrow (70.3S, 71.5W) Milestone");
NewEdge("West Rohan: Dunharrow (70.3S, 71.5W) Milestone", "West Rohan: Underharrow (67.3S, 73.7W) Stable", 2);
NewEdge("West Rohan: Grimslade (62.5S, 82,1W) Milestone", "West Rohan: Grimslade (62.3S, 82.0W) Stable", 2);
NewNode("West Rohan: Grimslade (63.3S, 82.1W) Milestone");
NewEdge("West Rohan: Grimslade (63.3S, 82.1W) Milestone", "West Rohan: Grimslade (62.3S, 82.0W) Stable", 2);
NewNode("West Rohan: Helm's Deep (63.8S, 89.4W) Milestone");
NewEdge("West Rohan: Helm's Deep (63.8S, 89.4W) Milestone", "West Rohan: Helm's Deep (63.7S, 89.5W) Stable", 2);
NewNode("West Rohan: Upbourn (65.5S, 73.1W) Milestone");
NewEdge("West Rohan: Upbourn (65.5S, 73.1W) Milestone", "West Rohan: Underharrow (67.3S, 73.7W) Stable", 2);
NewNode("West Rohan: Underharrow (67.3S, 73.7W) Milestone");
NewEdge("West Rohan: Underharrow (67.3S, 73.7W) Milestone", "West Rohan: Underharrow (67.3S, 73.7W) Stable", 2);
-- West Rohan Campsites
NewNode("West Rohan: Dunharrow (70.3S, 71.4W) Camp");
NewEdge("West Rohan: Dunharrow (70.3S, 71.4W) Camp", "West Rohan: Underharrow (67.3S, 73.7W) Stable", 2);
NewNode("West Rohan: Eastfold (66.4S, 60.8W) Camp");
NewEdge("West Rohan: Eastfold (66.4S, 60.8W) Camp", "West Rohan: Fenmarch (66.5S, 57.8W) Stable", 2);
-- West Rohan Warbands
NewNode("West Rohan: Bethan (56.9S, 882.W) Warband");
NewEdge("West Rohan: Bethan (56.9S, 882.W) Warband", "West Rohan: Grimslade (62.3S, 82.0W) Stable", 2);
NewNode("West Rohan: Bosnauk (57.7S, 72,4W) Warband");
NewEdge("West Rohan: Bosnauk (57.7S, 72,4W) Warband", "West Rohan: Grimslade (62.3S, 82.0W) Stable", 2);
NewNode("West Rohan: Burzash (66S, 58W) Warband");
NewEdge("West Rohan: Burzash (66S, 58W) Warband", "West Rohan: Fenmarch (66.5S, 57.8W) Stable", 2);
NewNode("West Rohan: Cledwun (48.1S, 71.7W) Warband");
NewEdge("West Rohan: Cledwun (48.1S, 71.7W) Warband", "West Rohan: Stoke (49.3S, 69.6W) Stable", 2);
NewNode("West Rohan: Darkheart (68S, 54W) Warband");
NewEdge("West Rohan: Darkheart (68S, 54W) Warband", "West Rohan: Beaconwatch (69.6S, 57.4W) Stable", 2);
NewNode("West Rohan: Felljaw (69.6S, 62.4W) Warband");
NewEdge("West Rohan: Felljaw (69.6S, 62.4W) Warband", "West Rohan: Beaconwatch (69.6S, 57.4W) Stable", 2);
NewNode("West Rohan: Geralht (53.6S, 76.0) Warband");
NewEdge("West Rohan: Geralht (53.6S, 76.0) Warband", "West Rohan: Brockbridge (50.8S, 77.7W) Stable", 2);
NewNode("West Rohan: Glendower (54S, 66W) Warband");
NewEdge("West Rohan: Glendower (54S, 66W) Warband", "West Rohan: Middlemead (53.7S, 72.5W) Stable", 2);
NewNode("West Rohan: Inras (58S, 78.4W) Warband");
NewEdge("West Rohan: Inras (58S, 78.4W) Warband", "West Rohan: Gapholt (53.7S, 83.7W) Stable", 2);
NewNode("West Rohan: Krupu (59.2S, 78.2W) Warband");
NewEdge("West Rohan: Krupu (59.2S, 78.2W) Warband", "West Rohan: Edoras (60.8S, 74.2W) Stable", 2);
NewNode("West Rohan: Neivion (49.6S, 76.8W) Warband");
NewEdge("West Rohan: Neivion (49.6S, 76.8W) Warband", "West Rohan: Brockbridge (50.8S, 77.7W) Stable", 2);
NewNode("West Rohan: Nudit (54S, 66W) Warband");
NewEdge("West Rohan: Nudit (54S, 66W) Warband", "West Rohan: Entwade (50.0S, 65.8W) Stable", 2);
NewNode("West Rohan: Ognir (50S, 77W) Warband");
NewEdge("West Rohan: Ognir (50S, 77W) Warband", "West Rohan: Brockbridge (50.8S, 77.7W) Stable", 2);
NewNode("West Rohan: Ora (61.5S, 64.9W) Warband");
NewEdge("West Rohan: Ora (61.5S, 64.9W) Warband", "West Rohan: Entwade (50.0S, 65.8W) Stable", 2);
NewNode("West Rohan: Patarshan (63S, 79W) Warband");
NewEdge("West Rohan: Patarshan (63S, 79W) Warband", "West Rohan: Grimslade (62.3S, 82.0W) Stable", 2);
NewNode("West Rohan: Rog-votak (56.0S, 78.4W) Warband");
NewEdge("West Rohan: Rog-votak (56.0S, 78.4W) Warband", "West Rohan: Brockbridge (50.8S, 77.7W) Stable", 2);
NewNode("West Rohan: Scion the Great Bear (70.5S, 60.2W) Warband");
NewEdge("West Rohan: Scion the Great Bear (70.5S, 60.2W) Warband", "West Rohan: Beaconwatch (69.6S, 57.4W) Stable", 2);
NewNode("West Rohan: Snapfang (54S, 66W) Warband");
NewEdge("West Rohan: Snapfang (54S, 66W) Warband", "West Rohan: Entwade (50.0S, 65.8W) Stable", 2);
NewNode("West Rohan: Voraut (54S, 87W) Warband");
NewEdge("West Rohan: Voraut (54S, 87W) Warband", "West Rohan: Grimslade (62.3S, 82.0W) Stable", 2);


-- Angmar Raid Nodes
NewNode("Angmar: Carn Dum (11.1N, 33.8W)");
NewEdge("Angmar: Gath Forthnir (10.4N, 24.0W) Stable", "Angmar: Carn Dum (11.1N, 33.8W)", 2);
NewNode("Angmar: The Rift of Nurz Ghashu (11.5N, 15.3W)");
NewEdge("Angmar: Gath Forthnir (10.4N, 24.0W) Stable", "Angmar: The Rift of Nurz Ghashu (11.5N, 15.3W)",2);
NewNode("Angmar: Urugarth (9.9N, 32.6W)");
NewNode("Angmar: Gates of Carn Dum (12.1N, 29.5W)");
NewEdge("Angmar: Gath Forthnir (10.4N, 24.0W) Stable", "Angmar: Gates of Carn Dum (12.1N, 29.5W)", 2);
NewEdge("Angmar: Gates of Carn Dum (12.1N, 29.5W)", "Angmar: Urugarth (9.9N, 32.6W)", 2);

-- Annuminas Raid Nodes
NewNode("Annuminas: Glinghant (19.3S, 68.9W)");
NewEdge("Evendim: Annuminas (19.1S, 70.9W) Stable", "Annuminas: Glinghant (19.3S, 68.9W)", 2);
NewNode("Annuminas: Haudh Valandil (16.2S, 69.6W)");
NewEdge("Evendim: Annuminas (19.1S, 70.9W) Stable", "Annuminas: Haudh Valandil (16.2S, 69.6W)", 2);
NewNode("Annuminas: Ost Elendil (16.2S, 69.6W)");
NewEdge("Evendim: Annuminas (19.1S, 70.9W) Stable", "Annuminas: Ost Elendil (16.2S, 69.6W)", 2);

-- Dol Guldur Raid Nodes
NewNode("Angmar: Barad Gularan (6.6N, 21.8W)");
NewEdge("Angmar: Gath Forthnir (10.4N, 24.0W) Stable", "Angmar: Barad Gularan (6.6N, 21.8W)", 2);
NewNode("Dol Guldur: Barad Guldur (13.9S, 42.2W)");
NewEdge("Mirkwood: Helethir (16.1S, 44.5W) Stable", "Dol Guldur: Barad Guldur (13.9S, 42.2W)", 2);
NewNode("Dol Guldur: Dungeons of Dol Guldur (13.1S, 46.4W)");
NewEdge("Mirkwood: Thangulhad (12.8S, 46.1W) Stable", "Dol Guldur: Dungeons of Dol Guldur (13.1S, 46.4W)", 2);
NewNode("Dol Guldur: Sammath Gul (13.5S, 42.1W)");
NewEdge("Mirkwood: Helethir (16.1S, 44.5W) Stable", "Dol Guldur: Sammath Gul (13.5S, 42.1W)", 2);
NewNode("Dol Guldur: Sword Hall of Dol Guldur (14.8S, 42.2W)");
NewEdge("Mirkwood: Helethir (16.1S, 44.5W) Stable", "Dol Guldur: Sword Hall of Dol Guldur (14.8S, 42.2W)", 2);
NewNode("Dol Guldur: Warg-pens of Dol Guldur (14.9S, 44.3W)");
NewEdge("Mirkwood: Helethir (16.1S, 44.5W) Stable", "Dol Guldur: Warg-pens of Dol Guldur (14.9S, 44.3W)", 2);

-- Enedwaith Raid Nodes
NewNode("Draigoch's Lair (67.2S, 6.6W)");
NewEdge("Draigoch's Lair (67.2S, 6.6W)", "Enedwaith: Harndirion (69.4S, 13.7W) Stable", 1);

-- Fornost Raid Nodes
NewNode("Fornost (6.0S, 55.2W)");
NewEdge("North Downs: Amon Raith (12.3S, 52.5W) Stable", "Fornost (6.0S, 55.2W)", 2);

-- Garth Arwen Raid Nodes
NewNode("Garth Arwen: Arboretum (29.2S, 24.8W)");
NewEdge("Lone Lands: Ost Guruth (32.1S, 29.8W) Stable", "Garth Arwen: Arboretum (29.2S, 24.8W)", 2);
NewNode("Garth Arwen: Barrows (28.8S, 24.4W)");
NewEdge("Lone Lands: Ost Guruth (32.1S, 29.8W) Stable", "Garth Arwen: Barrows (28.8S, 24.4W)", 2);
NewNode("Garth Arwen: Fortress (28.8S, 24.4W)");
NewEdge("Lone Lands: Ost Guruth (32.1S, 29.8W) Stable", "Garth Arwen: Fortress (28.8S, 24.4W)", 2);

-- Great Barrow Raid Nodes
NewNode("Great Barrow (33.8S, 55.8W)");
NewEdge("Bree-land: Adso's Camp (29.2S, 56.6W) Stable", "Great Barrow (33.8S, 55.8W)", 2);

-- Helegrod Raid Nodes
NewNode("Helegrod (17.9S, 2.2W)");
NewEdge("Misty Mountains: Gloin's Camp (24.9S, 4.0W) Stable", "Helegrod (17.9S, 2.2W)", 2);

-- In Their Absence Raid Nodes
NewNode("In Their Absence: Lost Temple (26.6S, 14.1W)");
NewEdge("Trollshaws: Thorenhad (31.7S, 15.0W) Stable", "In Their Absence: Lost Temple (26.6S, 14.1W)", 2);
NewNode("In Their Absence: Ost Dunhoth (75.1S, 19.7W)");
NewEdge("Enedwaith: Harndirion (69.4S, 13.7W) Stable", "In Their Absence: Ost Dunhoth (75.1S, 19.7W)", 2);
NewNode("In Their Absence: Sari-surma (20.1N, 78.8W)");
NewEdge("Forochel: Kuru-leiri (19.5N, 83.7W) Stable", "In Their Absence: Sari-surma (20.1N, 78.8W)", 2);
NewNode("In Their Absence: Stoneheight (9.5S, 50.1W)");
NewEdge("North Downs: Amon Raith (12.3S, 52.5W) Stable", "In Their Absence: Stoneheight (9.5S, 50.1W)", 2);
NewNode("In Their Absence: The Northcotton Farm (22.9S, 68.0W)");
NewEdge("Evendim: Oatbarton (23.2S, 67.3W) Stable", "In Their Absence: The Northcotton Farm (22.9S, 68.0W)", 2);

-- Isengard Raid Nodes
NewNode("Nan Curunir: Ox-clan Merchant Camp (79.9S, 0.4E)");
NewEdge("Nan Curunir: Dagoras' Camp (84.9S, 3.4W) Stable", "Nan Curunir: Ox-clan Merchant Camp (79.9S, 0.4E)", 2);
NewNode("Isengard: Dargnakh Unleashed (79.9S, 0.4E)");
NewEdge("Nan Curunir: Ox-clan Merchant Camp (79.9S, 0.4E)", "Isengard: Dargnakh Unleashed (79.9S, 0.4E)", 2);
NewNode("Isengard: Draigoch's Lair (67.2S, 6.6W)");
NewEdge("Enedwaith: Harndirion (69.4S, 13.7W) Stable", "Isengard: Draigoch's Lair (67.2S, 6.6W)", 2);
NewNode("Isengard: Fangorn's Edge (79.9S, 0.4E)");
NewEdge("Nan Curunir: Ox-clan Merchant Camp (79.9S, 0.4E)", "Isengard: Fangorn's Edge (79.9S, 0.4E)", 2);
NewNode("Isengard: Pits of Isengard (79.9S, 0.4E)");
NewEdge("Nan Curunir: Ox-clan Merchant Camp (79.9S, 0.4E)", "Isengard: Pits of Isengard (79.9S, 0.4E)", 2);
NewNode("Isengard: Roots of Fangorn (28.7S, 72.2W)");
NewEdge("Great River: Wailing Hills (25.6S, 67.0W) Stable", "Isengard: Roots of Fangorn (28.7S, 72.2W)", 2);
NewNode("Isengard: The Foundry (79.9S, 0.4E)");
NewEdge("Nan Curunir: Ox-clan Merchant Camp (79.9S, 0.4E)", "Isengard: The Foundry (79.9S, 0.4E)", 2);
NewNode("Isengard: The Tower of Orthanc (79.9S, 0.4E)");
NewEdge("Nan Curunir: Ox-clan Merchant Camp (79.9S, 0.4E)", "Isengard: The Tower of Orthanc (79.9S, 0.4E)", 2);

-- Lothlorien Raid Nodes
NewNode("Lothlorien: Dar Narbugud (16.4S, 96.8W)");
NewEdge("Moria: Shadowed Refuge (13.0S, 101.6W) Stable", "Lothlorien: Dar Narbugud (16.4S, 96.8W)", 2);
NewNode("Lothlorien: Halls of Crafting (16.9S, 109.4W)");
NewEdge("Moria: Anazarmekhem (13.22S, 107.96W) Stable", "Lothlorien: Halls of Crafting (16.9S, 109.4W)", 2);
NewNode("Lothlorien: The Mirror Halls of Lumal-nar (15.4N, 108.5W)");
NewNode("Door To Zirakzigil (2.8S, 110.8W)");
NewNode("Door To Durin's Way (13.5N, 109.1W)");
NewEdge("Moria: Zirakzigil (2.9S, 110.8W) Stable", "Door To Zirakzigil (2.8S, 110.8W)", 2);
NewEdge("Door To Zirakzigil (2.8S, 110.8W)", "Door To Durin's Way (13.5N, 109.1W)", 2);
NewEdge("Door To Durin's Way (13.5N, 109.1W)", "Lothlorien: The Mirror Halls of Lumal-nar (15.4N, 108.5W)", 2);
NewNode("Lothlorien: The Water Wheels: Nala-dum (14.2S, 112.7W)");
NewEdge("Moria: The Rotting Cellar (15.1S, 111.9W) Stable", "Lothlorien: The Water Wheels: Nala-dum (14.2S, 112.7W)", 2);

-- Moria Raid Nodes
NewNode("Moria: Dark Delvings (15.4S, 97.4W)");
NewEdge("Moria: Shadowed Refuge (13.0S, 101.6W) Stable", "Moria: Dark Delvings (15.4S, 97.4W)", 2);
NewNode("Moria: Fil Gashan (17.1S, 109.6W)");
NewEdge("Moria: Anazarmekhem (13.22S, 107.96W) Stable", "Moria: Fil Gashan (17.1S, 109.6W)", 2);
NewNode("Moria: Filikul (16.4S, 113.7W)");
NewEdge("Moria: The Rotting Cellar (15.1S, 111.9W) Stable", "Moria: Filikul (16.4S, 113.7W)", 2);
NewNode("Moria: Skumfil (13.2S, 100.4W)");
NewEdge("Moria: Shadowed Refuge (13.0S, 101.6W) Stable", "Moria: Skumfil (13.2S, 100.4W)", 2);
NewNode("Moria: The Forges of Khazad Dum (17.0S, 109.7W)");
NewEdge("Moria: Anazarmekhem (13.22S, 107.96W) Stable", "Moria: The Forges of Khazad Dum (17.0S, 109.7W)", 2);
NewNode("Moria: Forgotten Treasury (11.1S, 112.6W)");
NewEdge("Moria: Deep Descent (9.8S, 112.5W) Stable", "Moria: Forgotten Treasury (11.1S, 112.6W)", 2);
NewNode("Moria: The Grand Stair (10.2S, 103.9W)");
NewEdge("Moria: The Orc-watch (11.1S, 106.9W) Stable", "Moria: The Grand Stair (10.2S, 103.9W)", 2);
NewNode("Moria: The Sixteenth Hall (11.1S, 101.0W)");
NewEdge("Moria: First Hall (8.0S, 95.3W) Stable", "Moria: The Sixteenth Hall (11.1S, 101.0W)", 2);
NewNode("Moria: The Vile Maw (17.9S, 116.9W)");
NewEdge("Moria: The Vile Maw (17.6S, 116.9W) Stable", "Moria: The Vile Maw (17.9S, 116.9W)", 2);

-- Other Raid Nodes
NewNode("Other: Goblin-town Throne Room (20.8S, 6.2E)");
NewEdge("Misty Mountains: Northern High Pass (21.4S, 5.9E) Camp", "Other: Goblin-town Throne Room (20.8S, 6.2E)", 2);
NewNode("Other: Halls of Night (0.4N, 37.6W)");
NewEdge("Angmar: Aughaire (0.2S, 39.3W) Stable", "Other: Halls of Night (0.4N, 37.6W)", 2);
NewNode("Other: Inn of the Forsaken (34.0S, 40.7W)");
NewEdge("Lone Lands: Ost Guruth (32.1S, 29.8W) Stable", "Other: Inn of the Forsaken (34.0S, 40.7W)", 2);
NewNode("Other: School at Tham Mirdain (53.9S, 17.5W)");
NewEdge("Eregion: Echad Mirobel (52.3S, 17.0W) Stable", "Other: School at Tham Mirdain (53.9S, 17.5W)", 2);
NewNode("Other: Library at Tham Mirdain (53.9S, 17.5W)");
NewEdge("Eregion: Echad Mirobel (52.3S, 17.0W) Stable", "Other: Library at Tham Mirdain (53.9S, 17.5W)", 2);

NewNode("Osgiliath: Sunken Labyrinth (62.7S, 8.9W)");
NewNode("Osgiliath: The Ruined City (62.7S, 8.9W)");
NewNode("Osgiliath: The Dome Of Stars (62.7S, 8.9W)");
NewEdge("Eastern Gondor: Faramir's Lookout (65.0S, 6.1W) Stable", "Osgiliath: Sunken Labyrinth (62.7S, 8.9W)", 2);
NewEdge("Eastern Gondor: Faramir's Lookout (65.0S, 6.1W) Stable", "Osgiliath: The Ruined City (62.7S, 8.9W)", 2);
NewEdge("Eastern Gondor: Faramir's Lookout (65.0S, 6.1W) Stable", "Osgiliath: The Dome Of Stars (62.7S, 8.9W)", 2);

-- Warbands
NewNode("Entwash Vale: Bensengan (43.4S, 65.1W) Warband");
NewEdge("Entwash Vale: Bensengan (43.4S, 65.1W) Warband", "East Rohan: Eaworth (47.7S, 63.6W) Stable", 2);
NewNode("Entwash Vale: Dal (52.1S, 61.6W) Warband");
NewEdge("Entwash Vale: Dal (52.1S, 61.6W) Warband", "East Rohan: Eaworth (47.7S, 63.6W) Stable", 2);
NewNode("Entwash Vale: Fearhorn (50.3S, 62.0W) Warband");
NewEdge("Entwash Vale: Fearhorn (50.3S, 62.0W) Warband", "East Rohan: Eaworth (47.7S, 63.6W) Stable", 2);
NewNode("Entwash Vale: Mathum (43.6S, 64.9W) Warband");
NewEdge("Entwash Vale: Mathum (43.6S, 64.9W) Warband", "East Rohan: Thornhope (42.5S, 67.5W) Stable", 2);
NewNode("Entwash Vale: Mirz (44.2S, 63.5W) Warband");
NewEdge("Entwash Vale: Mirz (44.2S, 63.5W) Warband", "East Rohan: Thornhope (42.5S, 67.5W) Stable", 2);
NewNode("Entwash Vale: Urgai (50.8S, 60.6W) Warband");
NewEdge("Entwash Vale: Urgai (50.8S, 60.6W) Warband", "East Rohan: Eaworth (47.7S, 63.6W) Stable", 2);

NewNode("Norcrofts: Dahamab (45.0S, 58.0W) Warband");
NewEdge("Norcrofts: Dahamab (45.0S, 58.0W) Warband", "East Rohan: Cliving (43.3S, 56.6W) Stable", 2);
NewNode("Norcrofts: Haglob (46.2S, 54.1W) Warband");
NewEdge("Norcrofts: Haglob (46.2S, 54.1W) Warband", "East Rohan: Cliving (43.3S, 56.6W) Stable", 2);
NewNode("Norcrofts: Skutog (502.2S, 55.4W) Warband");
NewEdge("Norcrofts: Skutog (502.2S, 55.4W) Warband", "East Rohan: Elthengels (48.9S, 52.9W) Stable", 2);
NewNode("Norcrofts: Swertriper (53.1S, 54.3W) Warband");
NewEdge("Norcrofts: Swertriper (53.1S, 54.3W) Warband", "East Rohan: Faldham (54.8S, 57.2W) Stable", 2);

NewNode("Sutcrofts: Gundal (56.2S, 60.0W) Warband");
NewEdge("Sutcrofts: Gundal (56.2S, 60.0W) Warband", "East Rohan: Garsfeld (54.7S, 61.8W) Stable", 2);
NewNode("Sutcrofts: Kramp (59.0S, 59.9W) Warband");
NewEdge("Sutcrofts: Kramp (59.0S, 59.9W) Warband", "East Rohan: Snowbourn (60.5S, 61.3W) Stable", 2);
NewNode("Sutcrofts: Bugud (59.8S, 56.9W) Warband");
NewEdge("Sutcrofts: Bugud (59.8S, 56.9W) Warband", "East Rohan: Snowbourn (60.5S, 61.3W) Stable", 2);

NewNode("The Wold: Bughrakh (46.0S, 47.9W) Warband");
NewEdge("The Wold: Bughrakh (46.0S, 47.9W) Warband", "East Rohan: Floodwend (45.3S, 48.2W) Stable", 2);
NewNode("The Wold: Cinder (40.1S, 53.7W) Warband");
NewEdge("The Wold: Cinder (40.1S, 53.7W) Warband", "East Rohan: Harwick (39.0S, 52.3W) Stable", 2);
NewNode("The Wold: Hanrun (43.3S, 50.9W) Warband");
NewEdge("The Wold: Hanrun (43.3S, 50.9W) Warband", "East Rohan: Floodwend (45.3S, 48.2W) Stable", 2);
NewNode("The Wold: Urush (42.7S, 47.4W) Warband");
NewEdge("The Wold: Urush (42.7S, 47.4W) Warband", "East Rohan: Floodwend (45.3S, 48.2W) Stable", 2);

NewNode("Wildermore: Arataus (42.2S, 56.6W) Warband");
NewEdge("Wildermore: Arataus (42.2S, 56.6W) Warband", "Wildermore: Forlaw (39.4S, 60.9W) Stable", 2);
NewNode("Wildermore: Balcharan (35.3S, 60.4W) Warband");
NewEdge("Wildermore: Balcharan (35.3S, 60.4W) Warband", "Wildermore: Writhendowns (33.7S, 60.2W) Stable", 2);
NewNode("Wildermore: Conog (40.5S, 63.9W) Warband");
NewEdge("Wildermore: Conog (40.5S, 63.9W) Warband", "Wildermore: Forlaw (39.4S, 60.9W) Stable", 2);
NewNode("Wildermore: Foulwing (37.3S, 57.1W) Warband");
NewEdge("Wildermore: Foulwing (37.3S, 57.1W) Warband", "Wildermore: Forlaw (39.4S, 60.9W) Stable", 2);
NewNode("Wildermore: Gimtog (36.4S, 65.0W) Warband");
NewEdge("Wildermore: Gimtog (36.4S, 65.0W) Warband", "Wildermore: High Knolls (33.0S, 66.6W) Stable", 2);
NewNode("Wildermore: High Knolls Blizzard (31.3S, 65.7W) Warband");
NewEdge("Wildermore: High Knolls Blizzard (31.3S, 65.7W) Warband", "Wildermore: High Knolls (33.0S, 66.6W) Stable", 2);
NewNode("Wildermore: Karkas (30.8S, 63.2W) Warband");
NewEdge("Wildermore: Karkas (30.8S, 63.2W) Warband", "Wildermore: High Knolls (33.0S, 66.6W) Stable", 2);
NewNode("Wildermore: Rottenheart (34.8S, 71.5W) Warband");
NewEdge("Wildermore: Rottenheart (34.8S, 71.5W) Warband", "Wildermore: Balewood (35.4S, 69.9W) Stable", 2);
NewNode("Wildermore: Shaguk (40.8S, 58.1W) Warband");
NewEdge("Wildermore: Shaguk (40.8S, 58.1W) Warband", "Wildermore: Forlaw (39.4S, 60.9W) Stable", 2);
NewNode("Wildermore: Shum (43.3S, 58.9W) Warband");
NewEdge("Wildermore: Shum (43.3S, 58.9W) Warband", "Wildermore: Forlaw (39.4S, 60.9W) Stable", 2);
NewNode("Wildermore: Varg (34.3S, 69.5W) Warband");
NewEdge("Wildermore: Varg (34.3S, 69.5W) Warband", "Wildermore: Balewood (35.4S, 69.9W) Stable", 2);
NewNode("Wildermore: Voz (39.3S, 59.6W) Warband");
NewEdge("Wildermore: Voz (39.3S, 59.6W) Warband", "Wildermore: Forlaw (39.4S, 60.9W) Stable", 2);
NewNode("Wildermore: Zovarr (43.3S, 60.8W) Warband");
NewEdge("Wildermore: Zovarr (43.3S, 60.8W) Warband", "Wildermore: Forlaw (39.4S, 60.9W) Stable", 2);

-- Places of Interest
NewNode("Bree-land: Homesteads (34.8S, 46.1W)");
NewEdge("Bree-land: South Bree (31.9S, 50.4W) Stable", "Bree-land: Homesteads (34.8S, 46.1W)", 2);
NewNode("Bree-land: Home of Radicus, 4 Long St, Raddon, Breeland");
NewEdge("Bree-land: Homesteads (34.8S, 46.1W)", "Bree-land: Home of Radicus, 4 Long St, Raddon, Breeland", 3);
NewNode("Bree-land: The Prancing Pony (29.7S, 51.3W)");
NewEdge("Bree-land: The Prancing Pony (29.7S, 51.3W)", "Bree-land: West Bree (29,5S, 52.6W) Stable", 3);
NewNode("Rivendell: The Last Homely House (29.6S, 3.3W)");
NewEdge("Trollshaws: Rivendell (29.3S, 6.4W) Stable", "Rivendell: The Last Homely House (29.6S, 3.3W)", 3);
NewNode("Bree-land: Festival Grounds (24.7S, 51.5W)");
NewEdge("Bree-land: Hengstacer Farm (22.3S, 52.3W) Stable", "Bree-land: Festival Grounds (24.7S, 51.5W)", 3);
NewNode("North Downs: Mysterious Relic (10.2S, 46.9W)");
NewEdge("North Downs: Mysterious Relic (10.2S, 46.9W)", "North Downs: Othrikar (6.9S, 45.0W) Stable", 3);

-- Start Show Route
	SetStartNode(s);
	Dijkstras();
	local MyPath = {};
	GetPathTo(d,MyPath);
	local size=#MyPath;
	for i=1,size,1 do
		Turbine.Shell.WriteLine("<rgb=#55aaaa>".. i .. ".</rgb> " .. MyPath[i]);
	end
end


